pub enum CompressedMessage {
Unchained(CompressedUnchainedMessage),
Chained(CompressedChainedMessage),
}Expand description
SMB2 compression transform header variants for compressed messages.
Used by client or server when sending compressed messages in SMB 3.1.1 dialect. The variant is determined by the compression flags.
MS-SMB2 2.2.42
Variants
Unchained(CompressedUnchainedMessage)
Chained(CompressedChainedMessage)
Implementations
Sourceimpl CompressedMessage
impl CompressedMessage
Sourcepub fn total_size(&self) -> usize
pub fn total_size(&self) -> usize
Calculates the total size of the compressed message including headers and data.