Module create

Module create 

Create & Close (files) requests and responses.

Structs

AllocationSize
Specifies the allocation size for a newly created or overwritten file.
AppInstanceId
Application instance identifier (SMB 3.x dialect family only).
AppInstanceVersion
Application instance version (SMB 3.1.1 dialect only).
CloseFlags
Flags indicating how to process the CLOSE operation.
CloseRequest
The SMB2 CLOSE Request packet is used by the client to close an instance of a file that was opened previously with a successful SMB2 CREATE Request.
CloseResponse
The SMB2 CLOSE Response packet is sent by the server to indicate that an SMB2 CLOSE Request was processed successfully.
CreateContextRequest
The common definition that wrap around all create contexts, for both request and response. Create contexts are used to pass additional information to the server or receive additional information from the server in the CREATE request and response.
CreateContextResponse
The common definition that wrap around all create contexts, for both request and response. Create contexts are used to pass additional information to the server or receive additional information from the server in the CREATE request and response.
CreateOptions
Options to be applied when creating or opening the file.
CreateRequest
The SMB2 CREATE Request packet is sent by a client to request either creation of or access to a file. In case of a named pipe or printer, the server creates a new file.
CreateResponse
The SMB2 CREATE Response packet is sent by the server to notify the client of the status of its SMB2 CREATE Request.
CreateResponseFlags
Response flags indicating properties of the opened file. Only valid for SMB 3.x dialect family.
DH2QResp
Response for SMB 3.x durable or persistent handle request. Indicates successful creation of a durable/persistent handle.
DurableHandleReconnect
Request to reestablish a durable open after being disconnected.
DurableHandleReconnectV2
Request to reestablish a durable open (SMB 3.x dialect family only).
DurableHandleRequest
Request for a durable handle that can survive brief network disconnections.
DurableHandleRequestV2
Request for a durable or persistent handle (SMB 3.x dialect family only).
DurableHandleResponse
Response indicating the server has marked the open as durable.
DurableHandleV2Flags
Flags for durable handle v2 requests.
FileId
2.2.14.1: SMB2_FILEID
LeaseFlags
Flags for lease requests and responses.
QueryMaximalAccessRequest
Request for the server to retrieve maximal access information.
QueryMaximalAccessResponse
QueryOnDiskIdReq
Request for the server to return an identifier for the open file.
QueryOnDiskIdResp
Response containing disk file and volume identifiers for the opened file.
RequestLeaseV1
Version 1 lease request and response (SMB 2.1 and 3.x dialect family). Contains the lease key, state, flags, and duration.
RequestLeaseV2
Version 2 lease request and response (SMB 3.x dialect family only). Includes parent lease key and epoch tracking for lease state changes.
ShareAccessFlags
Specifies the sharing mode for the open.
SvhdxOpenDeviceContextV1
Version 1 context for opening a shared virtual disk file.
SvhdxOpenDeviceContextV2
Version 2 context for opening a shared virtual disk file.
TimewarpToken
Request to open a version of the file at a previous point in time.

Enums

CreateAction
The action taken in establishing the open.
CreateContextRequestData
The CreateRequest Context data enum.
CreateContextResponseData
The CreateResponse Context data enum.
CreateContextType
This enum contains all the types of create contexts.
CreateDisposition
Defines the action the server must take if the file already exists. For opening named pipes, this field can be set to any value and is ignored by the server.
ImpersonationLevel
The impersonation level requested by the application issuing the create request.
RequestLease
Request for the server to return a lease on a file or directory. Also used by the server to respond with a granted lease.
SvhdxOpenDeviceContext
Context for opening a shared virtual disk file.

Traits

CreateContextDataRequestValue
This trait is automatically implemented for all CreateRequest create context values.
CreateContextDataResponseValue
This trait is automatically implemented for all CreateResponse create context values.