pub enum CreateDisposition {
Superseded = 0,
Open = 1,
Create = 2,
OpenIf = 3,
Overwrite = 4,
OverwriteIf = 5,
}Expand description
Defines the action the server must take if the file already exists. For opening named pipes, this field can be set to any value and is ignored by the server.
Reference: MS-SMB2 2.2.13
Variants
Superseded = 0
If the file already exists, supersede it. Otherwise, create the file
Open = 1
If the file already exists, return success; otherwise, fail the operation
Create = 2
If the file already exists, fail the operation; otherwise, create the file
OpenIf = 3
Open the file if it already exists; otherwise, create the file
Overwrite = 4
Overwrite the file if it already exists; otherwise, fail the operation
OverwriteIf = 5
Overwrite the file if it already exists; otherwise, create the file