pub enum RequestLease {
RqLsReqv1(RequestLeaseV1),
RqLsReqv2(RequestLeaseV2),
}Expand description
Request for the server to return a lease on a file or directory. Also used by the server to respond with a granted lease.
Reference: MS-SMB2 2.2.13.2.8, 2.2.13.2.10, 2.2.14.2.10, 2.2.14.2.11
Variants
RqLsReqv1(RequestLeaseV1)
RqLsReqv2(RequestLeaseV2)