CloseFlags

Struct CloseFlags 

pub struct CloseFlags { /* private fields */ }
Flags indicating how to process the CLOSE operation.

Reference: MS-SMB2 2.2.15, 2.2.16

Implementations

Source

impl CloseFlags

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl CloseFlags

pub const fn into_bytes(self) -> [u8; 2]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 2]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl CloseFlags

pub fn postquery_attrib(&self) -> <bool as Specifier>::InOut

Returns the value of postquery_attrib. If set in request, the server MUST set the attribute fields in the response to valid values. If set in response, the client MUST use the attribute fields that are returned.

pub fn postquery_attrib_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of postquery_attrib.

#Errors

If the returned value contains an invalid bit pattern for postquery_attrib. If set in request, the server MUST set the attribute fields in the response to valid values. If set in response, the client MUST use the attribute fields that are returned.

pub fn with_postquery_attrib(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of postquery_attrib set to the given value.

#Panics

If the given value is out of bounds for postquery_attrib. If set in request, the server MUST set the attribute fields in the response to valid values. If set in response, the client MUST use the attribute fields that are returned.

pub fn with_postquery_attrib_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of postquery_attrib set to the given value.

#Errors

If the given value is out of bounds for postquery_attrib. If set in request, the server MUST set the attribute fields in the response to valid values. If set in response, the client MUST use the attribute fields that are returned.

pub fn set_postquery_attrib(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of postquery_attrib to the given value.

#Panics

If the given value is out of bounds for postquery_attrib. If set in request, the server MUST set the attribute fields in the response to valid values. If set in response, the client MUST use the attribute fields that are returned.

pub fn set_postquery_attrib_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of postquery_attrib to the given value.

#Errors

If the given value is out of bounds for postquery_attrib. If set in request, the server MUST set the attribute fields in the response to valid values. If set in response, the client MUST use the attribute fields that are returned.