pub struct CloseResponse {
pub flags: CloseFlags,
pub creation_time: FileTime,
pub last_access_time: FileTime,
pub last_write_time: FileTime,
pub change_time: FileTime,
pub allocation_size: u64,
pub endof_file: u64,
pub file_attributes: FileAttributes,
}Expand description
The SMB2 CLOSE Response packet is sent by the server to indicate that an SMB2 CLOSE Request was processed successfully.
Reference: MS-SMB2 2.2.16
Fields
flags: CloseFlagscreation_time: FileTimeThe time when the file was created
last_access_time: FileTimeThe time when the file was last accessed
last_write_time: FileTimeThe time when data was last written to the file
change_time: FileTimeThe time when the file was last modified
allocation_size: u64The size, in bytes, of the data that is allocated to the file
endof_file: u64The size, in bytes, of the file
file_attributes: FileAttributesThe attributes of the file