pub struct CreateContext<T>{
pub name: Vec<u8>,
pub data: T,
}Expand description
The common definition that wrap around all create contexts, for both request and response.
This is meant to be used within a ChainedItemList<T>!
Fields
name: Vec<u8>data: TTrait Implementations
Sourceimpl<T> BinRead for CreateContext<T>
impl<T> BinRead for CreateContext<T>
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl<T> BinWrite for CreateContext<T>
impl<T> BinWrite for CreateContext<T>
Sourcefn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<()>
fn write_options<W: Write + Seek>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<()>
Sourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming big-endian byte order. Read moreSourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming little-endian byte order. Read moreSourcefn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming native-endian byte order. Read moreSourcefn write_be_args<W>(
&self,
writer: &mut W,
args: Self::Args<'_>,
) -> Result<(), Error>
fn write_be_args<W>( &self, writer: &mut W, args: Self::Args<'_>, ) -> Result<(), Error>
Write
Self to the writer, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl<T> Debug for CreateContext<T>
impl<T> Debug for CreateContext<T>
Sourceimpl From<AllocationSize> for CreateContext<CreateContextRequestData>
impl From<AllocationSize> for CreateContext<CreateContextRequestData>
Sourcefn from(req: AllocationSize) -> Self
fn from(req: AllocationSize) -> Self
Converts to this type from the input type.
Sourceimpl From<AppInstanceId> for CreateContext<CreateContextRequestData>
impl From<AppInstanceId> for CreateContext<CreateContextRequestData>
Sourcefn from(req: AppInstanceId) -> Self
fn from(req: AppInstanceId) -> Self
Converts to this type from the input type.
Sourceimpl From<AppInstanceId> for CreateContext<CreateContextResponseData>
impl From<AppInstanceId> for CreateContext<CreateContextResponseData>
Sourcefn from(req: AppInstanceId) -> Self
fn from(req: AppInstanceId) -> Self
Converts to this type from the input type.
Sourceimpl From<AppInstanceVersion> for CreateContext<CreateContextRequestData>
impl From<AppInstanceVersion> for CreateContext<CreateContextRequestData>
Sourcefn from(req: AppInstanceVersion) -> Self
fn from(req: AppInstanceVersion) -> Self
Converts to this type from the input type.
Sourceimpl From<AppInstanceVersion> for CreateContext<CreateContextResponseData>
impl From<AppInstanceVersion> for CreateContext<CreateContextResponseData>
Sourcefn from(req: AppInstanceVersion) -> Self
fn from(req: AppInstanceVersion) -> Self
Converts to this type from the input type.
Sourceimpl From<ChainedItemList<ChainedItemList<FileFullEaInformationInner, 4>>> for CreateContext<CreateContextRequestData>
impl From<ChainedItemList<ChainedItemList<FileFullEaInformationInner, 4>>> for CreateContext<CreateContextRequestData>
Sourcefn from(req: ChainedItemList<FileFullEaInformation>) -> Self
fn from(req: ChainedItemList<FileFullEaInformation>) -> Self
Converts to this type from the input type.
Sourceimpl From<DurableHandleReconnect> for CreateContext<CreateContextRequestData>
impl From<DurableHandleReconnect> for CreateContext<CreateContextRequestData>
Sourcefn from(req: DurableHandleReconnect) -> Self
fn from(req: DurableHandleReconnect) -> Self
Converts to this type from the input type.
Sourceimpl From<DurableHandleReconnectV2> for CreateContext<CreateContextRequestData>
impl From<DurableHandleReconnectV2> for CreateContext<CreateContextRequestData>
Sourcefn from(req: DurableHandleReconnectV2) -> Self
fn from(req: DurableHandleReconnectV2) -> Self
Converts to this type from the input type.
Sourceimpl From<DurableHandleRequest> for CreateContext<CreateContextRequestData>
impl From<DurableHandleRequest> for CreateContext<CreateContextRequestData>
Sourcefn from(req: DurableHandleRequest) -> Self
fn from(req: DurableHandleRequest) -> Self
Converts to this type from the input type.
Sourceimpl From<DurableHandleRequestV2> for CreateContext<CreateContextRequestData>
impl From<DurableHandleRequestV2> for CreateContext<CreateContextRequestData>
Sourcefn from(req: DurableHandleRequestV2) -> Self
fn from(req: DurableHandleRequestV2) -> Self
Converts to this type from the input type.
Sourceimpl From<DurableHandleResponse> for CreateContext<CreateContextResponseData>
impl From<DurableHandleResponse> for CreateContext<CreateContextResponseData>
Sourcefn from(req: DurableHandleResponse) -> Self
fn from(req: DurableHandleResponse) -> Self
Converts to this type from the input type.
Sourceimpl From<QueryMaximalAccessRequest> for CreateContext<CreateContextRequestData>
impl From<QueryMaximalAccessRequest> for CreateContext<CreateContextRequestData>
Sourcefn from(req: QueryMaximalAccessRequest) -> Self
fn from(req: QueryMaximalAccessRequest) -> Self
Converts to this type from the input type.
Sourceimpl From<QueryMaximalAccessResponse> for CreateContext<CreateContextResponseData>
impl From<QueryMaximalAccessResponse> for CreateContext<CreateContextResponseData>
Sourcefn from(req: QueryMaximalAccessResponse) -> Self
fn from(req: QueryMaximalAccessResponse) -> Self
Converts to this type from the input type.
Sourceimpl From<QueryOnDiskIdReq> for CreateContext<CreateContextRequestData>
impl From<QueryOnDiskIdReq> for CreateContext<CreateContextRequestData>
Sourcefn from(req: QueryOnDiskIdReq) -> Self
fn from(req: QueryOnDiskIdReq) -> Self
Converts to this type from the input type.
Sourceimpl From<QueryOnDiskIdResp> for CreateContext<CreateContextResponseData>
impl From<QueryOnDiskIdResp> for CreateContext<CreateContextResponseData>
Sourcefn from(req: QueryOnDiskIdResp) -> Self
fn from(req: QueryOnDiskIdResp) -> Self
Converts to this type from the input type.
Sourceimpl From<RequestLease> for CreateContext<CreateContextRequestData>
impl From<RequestLease> for CreateContext<CreateContextRequestData>
Sourcefn from(req: RequestLease) -> Self
fn from(req: RequestLease) -> Self
Converts to this type from the input type.
Sourceimpl From<RequestLease> for CreateContext<CreateContextResponseData>
impl From<RequestLease> for CreateContext<CreateContextResponseData>
Sourcefn from(req: RequestLease) -> Self
fn from(req: RequestLease) -> Self
Converts to this type from the input type.
Sourceimpl From<SecurityDescriptor> for CreateContext<CreateContextRequestData>
impl From<SecurityDescriptor> for CreateContext<CreateContextRequestData>
Sourcefn from(req: SecurityDescriptor) -> Self
fn from(req: SecurityDescriptor) -> Self
Converts to this type from the input type.
Sourceimpl From<SvhdxOpenDeviceContext> for CreateContext<CreateContextRequestData>
impl From<SvhdxOpenDeviceContext> for CreateContext<CreateContextRequestData>
Sourcefn from(req: SvhdxOpenDeviceContext) -> Self
fn from(req: SvhdxOpenDeviceContext) -> Self
Converts to this type from the input type.
Sourceimpl From<SvhdxOpenDeviceContext> for CreateContext<CreateContextResponseData>
impl From<SvhdxOpenDeviceContext> for CreateContext<CreateContextResponseData>
Sourcefn from(req: SvhdxOpenDeviceContext) -> Self
fn from(req: SvhdxOpenDeviceContext) -> Self
Converts to this type from the input type.
Sourceimpl From<TimewarpToken> for CreateContext<CreateContextRequestData>
impl From<TimewarpToken> for CreateContext<CreateContextRequestData>
Sourcefn from(req: TimewarpToken) -> Self
fn from(req: TimewarpToken) -> Self
Converts to this type from the input type.
Sourceimpl<T> PartialEq for CreateContext<T>
impl<T> PartialEq for CreateContext<T>
Sourceimpl TryInto<AllocationSize> for CreateContext<CreateContextRequestData>
impl TryInto<AllocationSize> for CreateContext<CreateContextRequestData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<AllocationSize, SmbMsgError>
fn try_into(self) -> Result<AllocationSize, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<AppInstanceId> for CreateContext<CreateContextRequestData>
impl TryInto<AppInstanceId> for CreateContext<CreateContextRequestData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<AppInstanceId, SmbMsgError>
fn try_into(self) -> Result<AppInstanceId, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<AppInstanceId> for CreateContext<CreateContextResponseData>
impl TryInto<AppInstanceId> for CreateContext<CreateContextResponseData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<AppInstanceId, SmbMsgError>
fn try_into(self) -> Result<AppInstanceId, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<AppInstanceVersion> for CreateContext<CreateContextRequestData>
impl TryInto<AppInstanceVersion> for CreateContext<CreateContextRequestData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<AppInstanceVersion, SmbMsgError>
fn try_into(self) -> Result<AppInstanceVersion, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<AppInstanceVersion> for CreateContext<CreateContextResponseData>
impl TryInto<AppInstanceVersion> for CreateContext<CreateContextResponseData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<AppInstanceVersion, SmbMsgError>
fn try_into(self) -> Result<AppInstanceVersion, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<ChainedItemList<ChainedItemList<FileFullEaInformationInner, 4>>> for CreateContext<CreateContextRequestData>
impl TryInto<ChainedItemList<ChainedItemList<FileFullEaInformationInner, 4>>> for CreateContext<CreateContextRequestData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<ChainedItemList<FileFullEaInformation>, SmbMsgError>
fn try_into(self) -> Result<ChainedItemList<FileFullEaInformation>, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<DH2QResp> for CreateContext<CreateContextResponseData>
impl TryInto<DH2QResp> for CreateContext<CreateContextResponseData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourceimpl TryInto<DurableHandleReconnect> for CreateContext<CreateContextRequestData>
impl TryInto<DurableHandleReconnect> for CreateContext<CreateContextRequestData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<DurableHandleReconnect, SmbMsgError>
fn try_into(self) -> Result<DurableHandleReconnect, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<DurableHandleReconnectV2> for CreateContext<CreateContextRequestData>
impl TryInto<DurableHandleReconnectV2> for CreateContext<CreateContextRequestData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<DurableHandleReconnectV2, SmbMsgError>
fn try_into(self) -> Result<DurableHandleReconnectV2, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<DurableHandleRequest> for CreateContext<CreateContextRequestData>
impl TryInto<DurableHandleRequest> for CreateContext<CreateContextRequestData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<DurableHandleRequest, SmbMsgError>
fn try_into(self) -> Result<DurableHandleRequest, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<DurableHandleRequestV2> for CreateContext<CreateContextRequestData>
impl TryInto<DurableHandleRequestV2> for CreateContext<CreateContextRequestData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<DurableHandleRequestV2, SmbMsgError>
fn try_into(self) -> Result<DurableHandleRequestV2, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<DurableHandleResponse> for CreateContext<CreateContextResponseData>
impl TryInto<DurableHandleResponse> for CreateContext<CreateContextResponseData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<DurableHandleResponse, SmbMsgError>
fn try_into(self) -> Result<DurableHandleResponse, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<QueryMaximalAccessRequest> for CreateContext<CreateContextRequestData>
impl TryInto<QueryMaximalAccessRequest> for CreateContext<CreateContextRequestData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<QueryMaximalAccessRequest, SmbMsgError>
fn try_into(self) -> Result<QueryMaximalAccessRequest, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<QueryMaximalAccessResponse> for CreateContext<CreateContextResponseData>
impl TryInto<QueryMaximalAccessResponse> for CreateContext<CreateContextResponseData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<QueryMaximalAccessResponse, SmbMsgError>
fn try_into(self) -> Result<QueryMaximalAccessResponse, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<QueryOnDiskIdReq> for CreateContext<CreateContextRequestData>
impl TryInto<QueryOnDiskIdReq> for CreateContext<CreateContextRequestData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<QueryOnDiskIdReq, SmbMsgError>
fn try_into(self) -> Result<QueryOnDiskIdReq, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<QueryOnDiskIdResp> for CreateContext<CreateContextResponseData>
impl TryInto<QueryOnDiskIdResp> for CreateContext<CreateContextResponseData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<QueryOnDiskIdResp, SmbMsgError>
fn try_into(self) -> Result<QueryOnDiskIdResp, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<RequestLease> for CreateContext<CreateContextRequestData>
impl TryInto<RequestLease> for CreateContext<CreateContextRequestData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<RequestLease, SmbMsgError>
fn try_into(self) -> Result<RequestLease, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<RequestLease> for CreateContext<CreateContextResponseData>
impl TryInto<RequestLease> for CreateContext<CreateContextResponseData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<RequestLease, SmbMsgError>
fn try_into(self) -> Result<RequestLease, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<SecurityDescriptor> for CreateContext<CreateContextRequestData>
impl TryInto<SecurityDescriptor> for CreateContext<CreateContextRequestData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<SecurityDescriptor, SmbMsgError>
fn try_into(self) -> Result<SecurityDescriptor, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<SvhdxOpenDeviceContext> for CreateContext<CreateContextRequestData>
impl TryInto<SvhdxOpenDeviceContext> for CreateContext<CreateContextRequestData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<SvhdxOpenDeviceContext, SmbMsgError>
fn try_into(self) -> Result<SvhdxOpenDeviceContext, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<SvhdxOpenDeviceContext> for CreateContext<CreateContextResponseData>
impl TryInto<SvhdxOpenDeviceContext> for CreateContext<CreateContextResponseData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<SvhdxOpenDeviceContext, SmbMsgError>
fn try_into(self) -> Result<SvhdxOpenDeviceContext, SmbMsgError>
Performs the conversion.
Sourceimpl TryInto<TimewarpToken> for CreateContext<CreateContextRequestData>
impl TryInto<TimewarpToken> for CreateContext<CreateContextRequestData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<TimewarpToken, SmbMsgError>
fn try_into(self) -> Result<TimewarpToken, SmbMsgError>
Performs the conversion.
impl<T> Eq for CreateContext<T>
impl<T> StructuralPartialEq for CreateContext<T>