CreateContextResponse

Struct CreateContextResponse 

pub struct CreateContextResponse {
    pub name: Vec<u8>,
    pub data: CreateContextResponseData,
}
The common definition that wrap around all create contexts, for both request and response. Create contexts are used to pass additional information to the server or receive additional information from the server in the CREATE request and response.

This is meant to be used within a ChainedItemList<T>!

Reference: MS-SMB2 2.2.13, 2.2.14

Fields

name: Vec<u8>

The name of the create context

data: CreateContextResponseData

The data payload of the create context