CreateRequest

Struct CreateRequest 

pub struct CreateRequest {
    pub requested_oplock_level: OplockLevel,
    pub impersonation_level: ImpersonationLevel,
    pub desired_access: FileAccessMask,
    pub file_attributes: FileAttributes,
    pub share_access: ShareAccessFlags,
    pub create_disposition: CreateDisposition,
    pub create_options: CreateOptions,
    pub name: SizedWideString,
    pub contexts: ChainedItemList<CreateContextRequest, 8>,
}
The SMB2 CREATE Request packet is sent by a client to request either creation of or access to a file. In case of a named pipe or printer, the server creates a new file.

Reference: MS-SMB2 2.2.13

Fields

requested_oplock_level: OplockLevel

The requested oplock level for this file open

impersonation_level: ImpersonationLevel

The impersonation level requested by the application issuing the create request

desired_access: FileAccessMask

The level of access required for the file or pipe

file_attributes: FileAttributes

File attributes to be applied when creating or opening the file

share_access: ShareAccessFlags

Specifies the sharing mode for the open

create_disposition: CreateDisposition

Defines the action the server must take if the file already exists

create_options: CreateOptions

Options to be applied when creating or opening the file

name: SizedWideString

The Unicode file name to be created or opened

contexts: ChainedItemList<CreateContextRequest, 8>

The list of create contexts sent in this request. Use the CreateContextRequestData::first_... function family to get the first context of a specific type.