pub struct CreateResponse {
pub oplock_level: OplockLevel,
pub flags: CreateResponseFlags,
pub create_action: CreateAction,
pub creation_time: FileTime,
pub last_access_time: FileTime,
pub last_write_time: FileTime,
pub change_time: FileTime,
pub allocation_size: u64,
pub endof_file: u64,
pub file_attributes: FileAttributes,
pub file_id: FileId,
pub create_contexts: ChainedItemList<CreateContextResponse, 8>,
}Expand description
The SMB2 CREATE Response packet is sent by the server to notify the client of the status of its SMB2 CREATE Request.
Reference: MS-SMB2 2.2.14
Fields
oplock_level: OplockLevelThe oplock level that is granted to the client for this open
flags: CreateResponseFlagsResponse flags indicating properties of the opened file
create_action: CreateActionThe action taken in establishing the open
creation_time: FileTimeThe time when the file was created
last_access_time: FileTimeThe time the file was last accessed
last_write_time: FileTimeThe time when data was last written to the file
change_time: FileTimeThe time when the file was last modified
allocation_size: u64The size, in bytes, of the data that is allocated to the file
endof_file: u64The size, in bytes, of the file
file_attributes: FileAttributesThe attributes of the file
file_id: FileIdThe identifier of the open to a file or pipe that was established
create_contexts: ChainedItemList<CreateContextResponse, 8>The list of create contexts returned in this response.
Use the CreateContextResponseData::first_... function family to get the first context of a specific type.