CreateResponseFlags

Struct CreateResponseFlags 

pub struct CreateResponseFlags { /* private fields */ }
Response flags indicating properties of the opened file. Only valid for SMB 3.x dialect family.

Reference: MS-SMB2 2.2.14

Implementations

Source

impl CreateResponseFlags

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl CreateResponseFlags

pub const fn into_bytes(self) -> [u8; 1]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 1]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl CreateResponseFlags

pub fn reparsepoint(&self) -> <bool as Specifier>::InOut

Returns the value of reparsepoint. When set, indicates the last portion of the file path is a reparse point

pub fn reparsepoint_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of reparsepoint.

#Errors

If the returned value contains an invalid bit pattern for reparsepoint. When set, indicates the last portion of the file path is a reparse point

pub fn with_reparsepoint(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of reparsepoint set to the given value.

#Panics

If the given value is out of bounds for reparsepoint. When set, indicates the last portion of the file path is a reparse point

pub fn with_reparsepoint_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of reparsepoint set to the given value.

#Errors

If the given value is out of bounds for reparsepoint. When set, indicates the last portion of the file path is a reparse point

pub fn set_reparsepoint(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of reparsepoint to the given value.

#Panics

If the given value is out of bounds for reparsepoint. When set, indicates the last portion of the file path is a reparse point

pub fn set_reparsepoint_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of reparsepoint to the given value.

#Errors

If the given value is out of bounds for reparsepoint. When set, indicates the last portion of the file path is a reparse point