pub struct DurableHandleResponse {}Trait Implementations
Sourceimpl BinRead for DurableHandleResponse
impl BinRead for DurableHandleResponse
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl BinWrite for DurableHandleResponse
impl BinWrite for DurableHandleResponse
Sourcefn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<()>
fn write_options<W: Write + Seek>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<()>
Sourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming big-endian byte order. Read moreSourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming little-endian byte order. Read moreSourcefn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming native-endian byte order. Read moreSourcefn write_be_args<W>(
&self,
writer: &mut W,
args: Self::Args<'_>,
) -> Result<(), Error>
fn write_be_args<W>( &self, writer: &mut W, args: Self::Args<'_>, ) -> Result<(), Error>
Write
Self to the writer, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl CreateContextDataRespValue for DurableHandleResponse
impl CreateContextDataRespValue for DurableHandleResponse
const CONTEXT_NAME: &'static [u8] = CreateContextType::DHNQ_NAME
Sourceimpl Debug for DurableHandleResponse
impl Debug for DurableHandleResponse
Sourceimpl Default for DurableHandleResponse
impl Default for DurableHandleResponse
Sourcefn default() -> DurableHandleResponse
fn default() -> DurableHandleResponse
Returns the “default value” for a type. Read more
Sourceimpl From<DurableHandleResponse> for CreateContext<CreateContextRespData>
impl From<DurableHandleResponse> for CreateContext<CreateContextRespData>
Sourcefn from(req: DurableHandleResponse) -> Self
fn from(req: DurableHandleResponse) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for DurableHandleResponse
impl PartialEq for DurableHandleResponse
Sourceimpl TryInto<DurableHandleResponse> for CreateContext<CreateContextRespData>
impl TryInto<DurableHandleResponse> for CreateContext<CreateContextRespData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<DurableHandleResponse, SmbMsgError>
fn try_into(self) -> Result<DurableHandleResponse, SmbMsgError>
Performs the conversion.
impl Eq for DurableHandleResponse
impl StructuralPartialEq for DurableHandleResponse