pub struct DurableHandleV2Flags { /* private fields */ }Implementations
Sourceimpl DurableHandleV2Flags
impl DurableHandleV2Flags
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl DurableHandleV2Flags
impl DurableHandleV2Flags
Sourcepub fn persistent(&self) -> <bool as Specifier>::InOut
pub fn persistent(&self) -> <bool as Specifier>::InOut
Returns the value of persistent.
Sourcepub fn persistent_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn persistent_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of persistent.
#Errors
If the returned value contains an invalid bit pattern for persistent.
Sourcepub fn with_persistent(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_persistent(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of persistent set to the given value.
#Panics
If the given value is out of bounds for persistent.
Sourcepub fn with_persistent_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_persistent_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of persistent set to the given value.
#Errors
If the given value is out of bounds for persistent.
Sourcepub fn set_persistent(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_persistent(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of persistent to the given value.
#Panics
If the given value is out of bounds for persistent.
Sourcepub fn set_persistent_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_persistent_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of persistent to the given value.
#Errors
If the given value is out of bounds for persistent.