FileId

Struct FileId 

pub struct FileId {
    pub persistent: u64,
    pub volatile: u64,
}
2.2.14.1: SMB2_FILEID

Fields

persistent: u64volatile: u64

Implementations

Source

impl FileId

pub const EMPTY: FileId

pub const FULL: FileId

A file ID that is used to indicate that the file ID is not valid, with setting all bits to 1 - {0xFFFFFFFFFFFFFFFF, 0xFFFFFFFFFFFFFFFF}.