pub struct QueryMaximalAccessRequest {
pub timestamp: Option<FileTime>,
}Fields
timestamp: Option<FileTime>Trait Implementations
Sourceimpl BinRead for QueryMaximalAccessRequest
impl BinRead for QueryMaximalAccessRequest
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl BinWrite for QueryMaximalAccessRequest
impl BinWrite for QueryMaximalAccessRequest
Sourcefn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<()>
fn write_options<W: Write + Seek>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<()>
Sourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming big-endian byte order. Read moreSourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming little-endian byte order. Read moreSourcefn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming native-endian byte order. Read moreSourcefn write_be_args<W>(
&self,
writer: &mut W,
args: Self::Args<'_>,
) -> Result<(), Error>
fn write_be_args<W>( &self, writer: &mut W, args: Self::Args<'_>, ) -> Result<(), Error>
Write
Self to the writer, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl CreateContextDataReqValue for QueryMaximalAccessRequest
impl CreateContextDataReqValue for QueryMaximalAccessRequest
const CONTEXT_NAME: &'static [u8] = CreateContextType::MXAC_NAME
Sourceimpl Debug for QueryMaximalAccessRequest
impl Debug for QueryMaximalAccessRequest
Sourceimpl Default for QueryMaximalAccessRequest
impl Default for QueryMaximalAccessRequest
Sourcefn default() -> QueryMaximalAccessRequest
fn default() -> QueryMaximalAccessRequest
Returns the “default value” for a type. Read more
Sourceimpl From<QueryMaximalAccessRequest> for CreateContext<CreateContextReqData>
impl From<QueryMaximalAccessRequest> for CreateContext<CreateContextReqData>
Sourcefn from(req: QueryMaximalAccessRequest) -> Self
fn from(req: QueryMaximalAccessRequest) -> Self
Converts to this type from the input type.
Sourceimpl TryInto<QueryMaximalAccessRequest> for CreateContext<CreateContextReqData>
impl TryInto<QueryMaximalAccessRequest> for CreateContext<CreateContextReqData>
Sourcetype Error = SmbMsgError
type Error = SmbMsgError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<QueryMaximalAccessRequest, SmbMsgError>
fn try_into(self) -> Result<QueryMaximalAccessRequest, SmbMsgError>
Performs the conversion.
impl Eq for QueryMaximalAccessRequest
impl StructuralPartialEq for QueryMaximalAccessRequest