pub struct QueryMaximalAccessResponse {
pub query_status: Status,
pub maximal_access: FileAccessMask,
}Fields
query_status: StatusUse is_success() to check if the query was successful.
maximal_access: FileAccessMaskThe maximal access mask for the opened file.
Use maximal_access() to get the access mask if the query was successful.
Implementations
Sourceimpl QueryMaximalAccessResponse
impl QueryMaximalAccessResponse
Sourcepub fn is_success(&self) -> bool
pub fn is_success(&self) -> bool
Returns true if the query was successful.
Sourcepub fn maximal_access(&self) -> Option<FileAccessMask>
pub fn maximal_access(&self) -> Option<FileAccessMask>
Returns the maximal access mask if the query was successful.