pub struct SvhdxOpenDeviceContextV2 {Show 13 fields
pub version: u32,
pub has_initiator_id: Boolean,
pub initiator_id: Guid,
pub flags: u32,
pub originator_flags: u32,
pub open_request_id: u64,
pub initiator_host_name_length: u16,
pub initiator_host_name: [u16; 63],
pub virtual_disk_properties_initialized: u32,
pub server_service_version: u32,
pub virtual_sector_size: u32,
pub physical_sector_size: u32,
pub virtual_size: u64,
}Fields
version: u32has_initiator_id: Booleaninitiator_id: Guidflags: u32originator_flags: u32open_request_id: u64initiator_host_name_length: u16initiator_host_name: [u16; 63]virtual_disk_properties_initialized: u32server_service_version: u32virtual_sector_size: u32physical_sector_size: u32virtual_size: u64Trait Implementations
Sourceimpl BinRead for SvhdxOpenDeviceContextV2
impl BinRead for SvhdxOpenDeviceContextV2
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl BinWrite for SvhdxOpenDeviceContextV2
impl BinWrite for SvhdxOpenDeviceContextV2
Sourcefn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<()>
fn write_options<W: Write + Seek>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<()>
Sourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming big-endian byte order. Read moreSourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming little-endian byte order. Read moreSourcefn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming native-endian byte order. Read moreSourcefn write_be_args<W>(
&self,
writer: &mut W,
args: Self::Args<'_>,
) -> Result<(), Error>
fn write_be_args<W>( &self, writer: &mut W, args: Self::Args<'_>, ) -> Result<(), Error>
Write
Self to the writer, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl Debug for SvhdxOpenDeviceContextV2
impl Debug for SvhdxOpenDeviceContextV2
Sourceimpl PartialEq for SvhdxOpenDeviceContextV2
impl PartialEq for SvhdxOpenDeviceContextV2
impl Eq for SvhdxOpenDeviceContextV2
impl StructuralPartialEq for SvhdxOpenDeviceContextV2