Module dfsc

Module dfsc 

Distributed File System Referral Protocol (MS-DFSC) messages.

MS-DFSC

Structs

DfsRequestData
RequestData is part of the REQ_GET_DFS_REFERRAL_EX message (section 2.2.3).
DfsRequestFlags
EntryV3DCRefs
2.2.5.3.2 NameListReferral Flag Set to 1
EntryV3V4DfsPaths
2.2.5.3.1 NameListReferral Flag Set to 0
ReferralEntry
ReferralEntryFlags
ReferralEntryValueV1
ReferralEntryValueV2
DO NOT use this struct directly when bin read/writing. Use an instance of ReferralEntry instead.
ReferralEntryValueV3
ReferralEntryValueV4
ReferralHeaderFlags
ReqGetDfsReferral
MS-DFSC 2.2.2: DFS referral requests are sent in the form of an REQ_GET_DFS_REFERRAL message, by using an appropriate transport as specified in section 2.1.
ReqGetDfsReferralEx
RespGetDfsReferral
NOTE: This struct currently implements BinWrite only as a placeholder (calling it will panic). BinRead is implemented and can be used to read DFS referral responses.

Enums

DfsServerType
Type of server hosting the target
EntryV3Value
ReferralEntryValue
ReferralLevel
The DFS referral version supported by the client. See ReqGetDfsReferral::max_referral_level.