pub struct DfsRequestFlags { /* private fields */ }Implementations
Sourceimpl DfsRequestFlags
impl DfsRequestFlags
Sourcepub const fn into_bytes(self) -> [u8; 2]
pub const fn into_bytes(self) -> [u8; 2]
Sourcepub const fn from_bytes(bytes: [u8; 2]) -> Self
pub const fn from_bytes(bytes: [u8; 2]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl DfsRequestFlags
impl DfsRequestFlags
Sourcepub fn site_name(&self) -> <bool as Specifier>::InOut
pub fn site_name(&self) -> <bool as Specifier>::InOut
Returns the value of site_name. SiteName present: The SiteName bit MUST be set to 1 if the packet contains the site name of the client.
Sourcepub fn site_name_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn site_name_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of site_name.
#Errors
If the returned value contains an invalid bit pattern for site_name. SiteName present: The SiteName bit MUST be set to 1 if the packet contains the site name of the client.
Sourcepub fn with_site_name(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_site_name(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of site_name set to the given value.
#Panics
If the given value is out of bounds for site_name. SiteName present: The SiteName bit MUST be set to 1 if the packet contains the site name of the client.
Sourcepub fn with_site_name_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_site_name_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of site_name set to the given value.
#Errors
If the given value is out of bounds for site_name. SiteName present: The SiteName bit MUST be set to 1 if the packet contains the site name of the client.
Sourcepub fn set_site_name(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_site_name(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of site_name to the given value.
#Panics
If the given value is out of bounds for site_name. SiteName present: The SiteName bit MUST be set to 1 if the packet contains the site name of the client.
Sourcepub fn set_site_name_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_site_name_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of site_name to the given value.
#Errors
If the given value is out of bounds for site_name. SiteName present: The SiteName bit MUST be set to 1 if the packet contains the site name of the client.