pub struct ReferralHeaderFlags { /* private fields */ }Implementations
Sourceimpl ReferralHeaderFlags
impl ReferralHeaderFlags
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl ReferralHeaderFlags
impl ReferralHeaderFlags
Sourcepub fn referral_servers(&self) -> <bool as Specifier>::InOut
pub fn referral_servers(&self) -> <bool as Specifier>::InOut
Returns the value of referral_servers. Whether all of the targets in the referral entries returned are DFS root targets capable of handling DFS referral requests.
Sourcepub fn referral_servers_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn referral_servers_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of referral_servers.
#Errors
If the returned value contains an invalid bit pattern for referral_servers. Whether all of the targets in the referral entries returned are DFS root targets capable of handling DFS referral requests.
Sourcepub fn with_referral_servers(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_referral_servers(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of referral_servers set to the given value.
#Panics
If the given value is out of bounds for referral_servers. Whether all of the targets in the referral entries returned are DFS root targets capable of handling DFS referral requests.
Sourcepub fn with_referral_servers_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_referral_servers_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of referral_servers set to the given value.
#Errors
If the given value is out of bounds for referral_servers. Whether all of the targets in the referral entries returned are DFS root targets capable of handling DFS referral requests.
Sourcepub fn set_referral_servers(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_referral_servers(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of referral_servers to the given value.
#Panics
If the given value is out of bounds for referral_servers. Whether all of the targets in the referral entries returned are DFS root targets capable of handling DFS referral requests.
Sourcepub fn set_referral_servers_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_referral_servers_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of referral_servers to the given value.
#Errors
If the given value is out of bounds for referral_servers. Whether all of the targets in the referral entries returned are DFS root targets capable of handling DFS referral requests.
Sourcepub fn storage_servers(&self) -> <bool as Specifier>::InOut
pub fn storage_servers(&self) -> <bool as Specifier>::InOut
Returns the value of storage_servers. Whether all of the targets in the referral response can be accessed without requiring further referral requests.
Sourcepub fn storage_servers_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn storage_servers_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of storage_servers.
#Errors
If the returned value contains an invalid bit pattern for storage_servers. Whether all of the targets in the referral response can be accessed without requiring further referral requests.
Sourcepub fn with_storage_servers(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_storage_servers(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of storage_servers set to the given value.
#Panics
If the given value is out of bounds for storage_servers. Whether all of the targets in the referral response can be accessed without requiring further referral requests.
Sourcepub fn with_storage_servers_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_storage_servers_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of storage_servers set to the given value.
#Errors
If the given value is out of bounds for storage_servers. Whether all of the targets in the referral response can be accessed without requiring further referral requests.
Sourcepub fn set_storage_servers(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_storage_servers(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of storage_servers to the given value.
#Panics
If the given value is out of bounds for storage_servers. Whether all of the targets in the referral response can be accessed without requiring further referral requests.
Sourcepub fn set_storage_servers_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_storage_servers_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of storage_servers to the given value.
#Errors
If the given value is out of bounds for storage_servers. Whether all of the targets in the referral response can be accessed without requiring further referral requests.
Sourcepub fn target_failbacl(&self) -> <bool as Specifier>::InOut
pub fn target_failbacl(&self) -> <bool as Specifier>::InOut
Returns the value of target_failbacl. Whether DFS client target failback is enabled for all targets in this referral response. This value used only in version 4.
Sourcepub fn target_failbacl_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn target_failbacl_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of target_failbacl.
#Errors
If the returned value contains an invalid bit pattern for target_failbacl. Whether DFS client target failback is enabled for all targets in this referral response. This value used only in version 4.
Sourcepub fn with_target_failbacl(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_target_failbacl(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of target_failbacl set to the given value.
#Panics
If the given value is out of bounds for target_failbacl. Whether DFS client target failback is enabled for all targets in this referral response. This value used only in version 4.
Sourcepub fn with_target_failbacl_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_target_failbacl_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of target_failbacl set to the given value.
#Errors
If the given value is out of bounds for target_failbacl. Whether DFS client target failback is enabled for all targets in this referral response. This value used only in version 4.
Sourcepub fn set_target_failbacl(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_target_failbacl(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of target_failbacl to the given value.
#Panics
If the given value is out of bounds for target_failbacl. Whether DFS client target failback is enabled for all targets in this referral response. This value used only in version 4.
Sourcepub fn set_target_failbacl_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_target_failbacl_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of target_failbacl to the given value.
#Errors
If the given value is out of bounds for target_failbacl. Whether DFS client target failback is enabled for all targets in this referral response. This value used only in version 4.