ReqGetDfsReferral

Struct ReqGetDfsReferral 

pub struct ReqGetDfsReferral {
    pub max_referral_level: ReferralLevel,
    pub request_file_name: NullWideString,
}
MS-DFSC 2.2.2: DFS referral requests are sent in the form of an REQ_GET_DFS_REFERRAL message, by using an appropriate transport as specified in section 2.1.

Fields

max_referral_level: ReferralLevel

An integer that indicates the highest DFS referral version understood by the client. The DFS referral versions specified by this document are 1 through 4 inclusive. A DFS client MUST support DFS referral version 1 through the version number set in this field. The referral response messages are referral version dependent and are specified in sections 2.2.5.1 through 2.2.5.4.

request_file_name: NullWideString

A null-terminated Unicode string specifying the path to be resolved. The specified path MUST NOT be case-sensitive. Its format depends on the type of referral request, as specified in section 3.1.4.2.