ReqGetDfsReferralEx

Struct ReqGetDfsReferralEx 

pub struct ReqGetDfsReferralEx {
    pub max_referral_level: u16,
    pub request_flags: DfsRequestFlags,
    pub request_data: DfsRequestData,
    /* private fields */
}

Fields

max_referral_level: u16

An integer that indicates the highest DFS referral version understood by the client. The DFS referral versions specified by this document are 1 through 4 inclusive. A DFS client MUST support DFS referral version 1 through the version number set in this field. The referral response messages are referral version dependent and are specified in sections 2.2.5.1 through 2.2.5.4.

request_flags: DfsRequestFlagsrequest_data: DfsRequestData