Module encrypted

Module encrypted 

Encrypted message and header implementation.

Structs

EncryptedHeader
This header is used by the client or server when sending encrypted messages
EncryptedMessage
An entirely encrypted SMB2 message, that includes both the encrypted header and the encrypted message.

Type Aliases

EncryptionNonce
The nonce used for encryption. Depending on the encryption algorithm, the nonce may be trimmed to a smaller size when used, or padded with zeroes to match the required size. When transmitted, the full 16 bytes are used.