pub struct EncryptedHeader {
pub signature: u128,
pub nonce: EncryptionNonce,
pub original_message_size: u32,
pub session_id: u64,
}Expand description
This header is used by the client or server when sending encrypted messages
Fields
signature: u128The 16-byte signature of the message generated using negotiated encryption algorithm
nonce: EncryptionNonceAn implementation-specific value assigned for every encrypted message. This MUST NOT be reused for all encrypted messages within a session.
original_message_size: u32The size, in bytes, of the SMB2 message.
session_id: u64Uniquely identifies the established session for the command.
Implementations
Sourceimpl EncryptedHeader
impl EncryptedHeader
pub const STRUCTURE_SIZE: usize = 52usize
Sourcepub fn aead_bytes(&self) -> [u8; 32]
pub fn aead_bytes(&self) -> [u8; 32]
The bytes to use as the additional data for the AEAD out of this header. Make sure to call it after all fields (except signature) are finalized.
Returns (according to MS-SMB2) the bytes of the header, excluding the magic and the signature.