pub enum SmbMsgError {
MissingErrorCodeDefinition(u32),
MissingFsctlDefinition(u32),
UnexpectedContent {
actual: &'static str,
expected: &'static str,
},
InvalidData(String),
InvalidDialect(NegotiateDialect),
BinRWError(Error),
}Expand description
SMB Message related errors
Variants
MissingErrorCodeDefinition(u32)
MissingFsctlDefinition(u32)
UnexpectedContent
This error is returned when trying to get inner value of certain enum variant, but the actual variant is different.
InvalidData(String)
InvalidDialect(NegotiateDialect)
BinRWError(Error)