Error response message
Structs
- Error
Response - The SMB2 ERROR Response packet is sent by the server to respond to a request that has failed or encountered an error.
- Error
Response Context - For SMB dialect 3.1.1, error data is formatted as an array of SMB2 ERROR Context structures. Each error context contains an identifier for the error context followed by the error data. Each context must start at an 8-byte aligned boundary relative to the start of the SMB2 ERROR Response.
Enums
- ErrorId
- An identifier for the error context in SMB2 ERROR Context structures.