pub struct ErrorResponse {
pub error_data: Vec<ErrorResponseContext>,
}Expand description
The SMB2 ERROR Response packet is sent by the server to respond to a request that has failed or encountered an error.
Reference: MS-SMB2 2.2.2
Fields
error_data: Vec<ErrorResponseContext>Variable-length data field that contains extended error information. For SMB 3.1.1 with nonzero ErrorContextCount, formatted as SMB2 ERROR Context structures.
Implementations
Sourceimpl ErrorResponse
impl ErrorResponse
Sourcepub fn find_context(&self, id: ErrorId) -> Option<&ErrorResponseContext>
pub fn find_context(&self, id: ErrorId) -> Option<&ErrorResponseContext>
Locates a context by its ID, returning a reference to it if found.