pub struct WriteRequest {
pub length: u32,
pub offset: u64,
pub file_id: FileId,
pub flags: WriteFlags,
/* private fields */
}Expand description
Zero-copy write request.
i.e. the data is not included in the message, but is sent separately.
note: it is currently assumed that the data is sent immediately after the message.
Fields
length: u32Length of data to write.
offset: u64Offset in file to write to.
file_id: FileIdflags: WriteFlagsImplementations
Sourceimpl WriteRequest
impl WriteRequest