HeaderFlags

Struct HeaderFlags 

pub struct HeaderFlags { /* private fields */ }
SMB2 header flags.

Indicates how to process the operation.

Reference: MS-SMB2 2.2.1.2

Implementations

Source

impl HeaderFlags

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl HeaderFlags

pub const fn into_bytes(self) -> [u8; 4]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 4]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl HeaderFlags

pub fn server_to_redir(&self) -> <bool as Specifier>::InOut

Returns the value of server_to_redir. Message is a server response (set in responses).

pub fn server_to_redir_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of server_to_redir.

#Errors

If the returned value contains an invalid bit pattern for server_to_redir. Message is a server response (set in responses).

pub fn with_server_to_redir(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of server_to_redir set to the given value.

#Panics

If the given value is out of bounds for server_to_redir. Message is a server response (set in responses).

pub fn with_server_to_redir_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of server_to_redir set to the given value.

#Errors

If the given value is out of bounds for server_to_redir. Message is a server response (set in responses).

pub fn set_server_to_redir(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of server_to_redir to the given value.

#Panics

If the given value is out of bounds for server_to_redir. Message is a server response (set in responses).

pub fn set_server_to_redir_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of server_to_redir to the given value.

#Errors

If the given value is out of bounds for server_to_redir. Message is a server response (set in responses).

pub fn async_command(&self) -> <bool as Specifier>::InOut

Returns the value of async_command. Message is part of an asynchronous operation.

pub fn async_command_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of async_command.

#Errors

If the returned value contains an invalid bit pattern for async_command. Message is part of an asynchronous operation.

pub fn with_async_command(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of async_command set to the given value.

#Panics

If the given value is out of bounds for async_command. Message is part of an asynchronous operation.

pub fn with_async_command_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of async_command set to the given value.

#Errors

If the given value is out of bounds for async_command. Message is part of an asynchronous operation.

pub fn set_async_command(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of async_command to the given value.

#Panics

If the given value is out of bounds for async_command. Message is part of an asynchronous operation.

pub fn set_async_command_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of async_command to the given value.

#Errors

If the given value is out of bounds for async_command. Message is part of an asynchronous operation.

pub fn related_operations(&self) -> <bool as Specifier>::InOut

Returns the value of related_operations. Request is a related operation in a compounded chain.

pub fn related_operations_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of related_operations.

#Errors

If the returned value contains an invalid bit pattern for related_operations. Request is a related operation in a compounded chain.

Returns a copy of the bitfield with the value of related_operations set to the given value.

#Panics

If the given value is out of bounds for related_operations. Request is a related operation in a compounded chain.

Returns a copy of the bitfield with the value of related_operations set to the given value.

#Errors

If the given value is out of bounds for related_operations. Request is a related operation in a compounded chain.

Sets the value of related_operations to the given value.

#Panics

If the given value is out of bounds for related_operations. Request is a related operation in a compounded chain.

Sets the value of related_operations to the given value.

#Errors

If the given value is out of bounds for related_operations. Request is a related operation in a compounded chain.

pub fn signed(&self) -> <bool as Specifier>::InOut

Returns the value of signed. Message is signed.

pub fn signed_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of signed.

#Errors

If the returned value contains an invalid bit pattern for signed. Message is signed.

pub fn with_signed(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of signed set to the given value.

#Panics

If the given value is out of bounds for signed. Message is signed.

pub fn with_signed_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of signed set to the given value.

#Errors

If the given value is out of bounds for signed. Message is signed.

pub fn set_signed(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of signed to the given value.

#Panics

If the given value is out of bounds for signed. Message is signed.

pub fn set_signed_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of signed to the given value.

#Errors

If the given value is out of bounds for signed. Message is signed.

pub fn priority_mask(&self) -> <B3 as Specifier>::InOut

Returns the value of priority_mask. Priority mask for quality of service.

pub fn priority_mask_or_err( &self, ) -> Result<<B3 as Specifier>::InOut, InvalidBitPattern<<B3 as Specifier>::Bytes>>

Returns the value of priority_mask.

#Errors

If the returned value contains an invalid bit pattern for priority_mask. Priority mask for quality of service.

pub fn with_priority_mask(self, new_val: <B3 as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of priority_mask set to the given value.

#Panics

If the given value is out of bounds for priority_mask. Priority mask for quality of service.

pub fn with_priority_mask_checked( self, new_val: <B3 as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of priority_mask set to the given value.

#Errors

If the given value is out of bounds for priority_mask. Priority mask for quality of service.

pub fn set_priority_mask(&mut self, new_val: <B3 as Specifier>::InOut)

Sets the value of priority_mask to the given value.

#Panics

If the given value is out of bounds for priority_mask. Priority mask for quality of service.

pub fn set_priority_mask_checked( &mut self, new_val: <B3 as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of priority_mask to the given value.

#Errors

If the given value is out of bounds for priority_mask. Priority mask for quality of service.

pub fn dfs_operation(&self) -> <bool as Specifier>::InOut

Returns the value of dfs_operation. Request is a DFS operation.

pub fn dfs_operation_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of dfs_operation.

#Errors

If the returned value contains an invalid bit pattern for dfs_operation. Request is a DFS operation.

pub fn with_dfs_operation(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of dfs_operation set to the given value.

#Panics

If the given value is out of bounds for dfs_operation. Request is a DFS operation.

pub fn with_dfs_operation_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of dfs_operation set to the given value.

#Errors

If the given value is out of bounds for dfs_operation. Request is a DFS operation.

pub fn set_dfs_operation(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of dfs_operation to the given value.

#Panics

If the given value is out of bounds for dfs_operation. Request is a DFS operation.

pub fn set_dfs_operation_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of dfs_operation to the given value.

#Errors

If the given value is out of bounds for dfs_operation. Request is a DFS operation.

pub fn replay_operation(&self) -> <bool as Specifier>::InOut

Returns the value of replay_operation. Request is a replay operation for resilient handles.

pub fn replay_operation_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of replay_operation.

#Errors

If the returned value contains an invalid bit pattern for replay_operation. Request is a replay operation for resilient handles.

pub fn with_replay_operation(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of replay_operation set to the given value.

#Panics

If the given value is out of bounds for replay_operation. Request is a replay operation for resilient handles.

pub fn with_replay_operation_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of replay_operation set to the given value.

#Errors

If the given value is out of bounds for replay_operation. Request is a replay operation for resilient handles.

pub fn set_replay_operation(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of replay_operation to the given value.

#Panics

If the given value is out of bounds for replay_operation. Request is a replay operation for resilient handles.

pub fn set_replay_operation_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of replay_operation to the given value.

#Errors

If the given value is out of bounds for replay_operation. Request is a replay operation for resilient handles.