pub struct AdditionalInfo { /* private fields */ }Implementations
Sourceimpl AdditionalInfo
impl AdditionalInfo
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl AdditionalInfo
impl AdditionalInfo
Sourcepub fn owner_security_information(&self) -> <bool as Specifier>::InOut
pub fn owner_security_information(&self) -> <bool as Specifier>::InOut
Returns the value of owner_security_information.
Sourcepub fn owner_security_information_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn owner_security_information_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of owner_security_information.
#Errors
If the returned value contains an invalid bit pattern for owner_security_information.
Sourcepub fn with_owner_security_information(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_owner_security_information( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of owner_security_information set to the given value.
#Panics
If the given value is out of bounds for owner_security_information.
Sourcepub fn with_owner_security_information_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_owner_security_information_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of owner_security_information set to the given value.
#Errors
If the given value is out of bounds for owner_security_information.
Sourcepub fn set_owner_security_information(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_owner_security_information( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of owner_security_information to the given value.
#Panics
If the given value is out of bounds for owner_security_information.
Sourcepub fn set_owner_security_information_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_owner_security_information_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of owner_security_information to the given value.
#Errors
If the given value is out of bounds for owner_security_information.
Sourcepub fn group_security_information(&self) -> <bool as Specifier>::InOut
pub fn group_security_information(&self) -> <bool as Specifier>::InOut
Returns the value of group_security_information.
Sourcepub fn group_security_information_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn group_security_information_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of group_security_information.
#Errors
If the returned value contains an invalid bit pattern for group_security_information.
Sourcepub fn with_group_security_information(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_group_security_information( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of group_security_information set to the given value.
#Panics
If the given value is out of bounds for group_security_information.
Sourcepub fn with_group_security_information_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_group_security_information_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of group_security_information set to the given value.
#Errors
If the given value is out of bounds for group_security_information.
Sourcepub fn set_group_security_information(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_group_security_information( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of group_security_information to the given value.
#Panics
If the given value is out of bounds for group_security_information.
Sourcepub fn set_group_security_information_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_group_security_information_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of group_security_information to the given value.
#Errors
If the given value is out of bounds for group_security_information.
Sourcepub fn dacl_security_information(&self) -> <bool as Specifier>::InOut
pub fn dacl_security_information(&self) -> <bool as Specifier>::InOut
Returns the value of dacl_security_information.
Sourcepub fn dacl_security_information_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn dacl_security_information_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of dacl_security_information.
#Errors
If the returned value contains an invalid bit pattern for dacl_security_information.
Sourcepub fn with_dacl_security_information(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_dacl_security_information( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of dacl_security_information set to the given value.
#Panics
If the given value is out of bounds for dacl_security_information.
Sourcepub fn with_dacl_security_information_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_dacl_security_information_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of dacl_security_information set to the given value.
#Errors
If the given value is out of bounds for dacl_security_information.
Sourcepub fn set_dacl_security_information(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_dacl_security_information( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of dacl_security_information to the given value.
#Panics
If the given value is out of bounds for dacl_security_information.
Sourcepub fn set_dacl_security_information_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_dacl_security_information_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of dacl_security_information to the given value.
#Errors
If the given value is out of bounds for dacl_security_information.
Sourcepub fn sacl_security_information(&self) -> <bool as Specifier>::InOut
pub fn sacl_security_information(&self) -> <bool as Specifier>::InOut
Returns the value of sacl_security_information.
Sourcepub fn sacl_security_information_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn sacl_security_information_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of sacl_security_information.
#Errors
If the returned value contains an invalid bit pattern for sacl_security_information.
Sourcepub fn with_sacl_security_information(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_sacl_security_information( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of sacl_security_information set to the given value.
#Panics
If the given value is out of bounds for sacl_security_information.
Sourcepub fn with_sacl_security_information_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_sacl_security_information_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of sacl_security_information set to the given value.
#Errors
If the given value is out of bounds for sacl_security_information.
Sourcepub fn set_sacl_security_information(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_sacl_security_information( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of sacl_security_information to the given value.
#Panics
If the given value is out of bounds for sacl_security_information.
Sourcepub fn set_sacl_security_information_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_sacl_security_information_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of sacl_security_information to the given value.
#Errors
If the given value is out of bounds for sacl_security_information.
Sourcepub fn label_security_information(&self) -> <bool as Specifier>::InOut
pub fn label_security_information(&self) -> <bool as Specifier>::InOut
Returns the value of label_security_information.
Sourcepub fn label_security_information_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn label_security_information_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of label_security_information.
#Errors
If the returned value contains an invalid bit pattern for label_security_information.
Sourcepub fn with_label_security_information(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_label_security_information( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of label_security_information set to the given value.
#Panics
If the given value is out of bounds for label_security_information.
Sourcepub fn with_label_security_information_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_label_security_information_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of label_security_information set to the given value.
#Errors
If the given value is out of bounds for label_security_information.
Sourcepub fn set_label_security_information(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_label_security_information( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of label_security_information to the given value.
#Panics
If the given value is out of bounds for label_security_information.
Sourcepub fn set_label_security_information_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_label_security_information_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of label_security_information to the given value.
#Errors
If the given value is out of bounds for label_security_information.
Sourcepub fn attribute_security_information(&self) -> <bool as Specifier>::InOut
pub fn attribute_security_information(&self) -> <bool as Specifier>::InOut
Returns the value of attribute_security_information.
Sourcepub fn attribute_security_information_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn attribute_security_information_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of attribute_security_information.
#Errors
If the returned value contains an invalid bit pattern for attribute_security_information.
Sourcepub fn with_attribute_security_information(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_attribute_security_information( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of attribute_security_information set to the given value.
#Panics
If the given value is out of bounds for attribute_security_information.
Sourcepub fn with_attribute_security_information_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_attribute_security_information_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of attribute_security_information set to the given value.
#Errors
If the given value is out of bounds for attribute_security_information.
Sourcepub fn set_attribute_security_information(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_attribute_security_information( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of attribute_security_information to the given value.
#Panics
If the given value is out of bounds for attribute_security_information.
Sourcepub fn set_attribute_security_information_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_attribute_security_information_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of attribute_security_information to the given value.
#Errors
If the given value is out of bounds for attribute_security_information.
Sourcepub fn scope_security_information(&self) -> <bool as Specifier>::InOut
pub fn scope_security_information(&self) -> <bool as Specifier>::InOut
Returns the value of scope_security_information.
Sourcepub fn scope_security_information_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn scope_security_information_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of scope_security_information.
#Errors
If the returned value contains an invalid bit pattern for scope_security_information.
Sourcepub fn with_scope_security_information(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_scope_security_information( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of scope_security_information set to the given value.
#Panics
If the given value is out of bounds for scope_security_information.
Sourcepub fn with_scope_security_information_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_scope_security_information_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of scope_security_information set to the given value.
#Errors
If the given value is out of bounds for scope_security_information.
Sourcepub fn set_scope_security_information(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_scope_security_information( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of scope_security_information to the given value.
#Panics
If the given value is out of bounds for scope_security_information.
Sourcepub fn set_scope_security_information_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_scope_security_information_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of scope_security_information to the given value.
#Errors
If the given value is out of bounds for scope_security_information.
Sourcepub fn backup_security_information(&self) -> <bool as Specifier>::InOut
pub fn backup_security_information(&self) -> <bool as Specifier>::InOut
Returns the value of backup_security_information.
Sourcepub fn backup_security_information_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn backup_security_information_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of backup_security_information.
#Errors
If the returned value contains an invalid bit pattern for backup_security_information.
Sourcepub fn with_backup_security_information(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_backup_security_information( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of backup_security_information set to the given value.
#Panics
If the given value is out of bounds for backup_security_information.
Sourcepub fn with_backup_security_information_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_backup_security_information_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of backup_security_information set to the given value.
#Errors
If the given value is out of bounds for backup_security_information.
Sourcepub fn set_backup_security_information(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_backup_security_information( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of backup_security_information to the given value.
#Panics
If the given value is out of bounds for backup_security_information.
Sourcepub fn set_backup_security_information_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_backup_security_information_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of backup_security_information to the given value.
#Errors
If the given value is out of bounds for backup_security_information.
Sourceimpl AdditionalInfo
impl AdditionalInfo
pub fn is_security(&self) -> bool