Module query

Module query 

Get/Set Info Request/Response

Structs

GetEaInfoList
NullByte
Single null (0) byte.
QueryInfoFlags
QueryInfoRequest
Request to query information on a file, named pipe, or underlying volume.
QueryInfoResponse
Response to a query information request, containing the requested data.
QueryInfoResponseData
A helper structure containing raw response data that can be parsed into specific information types.
QueryQuotaInfo
Specifies the quota information to query.
RawQueryInfoData

Enums

GetInfoRequestData
Input data for query information requests that require additional parameters.
QueryInfoClass
Helper enum to specify the information class for query info requests, when it is applicable.
QueryInfoData
Enum to hold the different info types for QueryInfoData, that are used within SMB requests for querying or setting information.