GetInfoRequestData

Enum GetInfoRequestData 

pub enum GetInfoRequestData {
    Quota(QueryQuotaInfo),
    EaInfo(GetEaInfoList),
    None(()),
}
Input data for query information requests that require additional parameters.

This payload is used for quota and extended attribute queries. Other information types have no input data.

MS-SMB2 2.2.37

Variants



Quota(QueryQuotaInfo)

The query quota to perform.



EaInfo(GetEaInfoList)

Extended attributes information to query.



None(())