pub struct QueryInfoResponse { /* private fields */ }Expand description
Response to a query information request, containing the requested data.
MS-SMB2 2.2.38
Implementations
Sourceimpl QueryInfoResponse
impl QueryInfoResponse
Sourcepub fn parse(&self, info_type: InfoType) -> Result<QueryInfoData, Error>
pub fn parse(&self, info_type: InfoType) -> Result<QueryInfoData, Error>
Call this method first when parsing an incoming query info response. It will parse the raw data into a QueryInfoResponseData struct, which has a variation for each information type: File, FileSystem, Security, Quota. This is done by calling the QueryInfoResponseData::parse method.