pub struct QueryInfoResponseData { /* private fields */ }Expand description
A helpers struct that contains the raw data of a query info response or a set info request,
and can be parsed using the QueryInfoResponseData::parse method, to a specific info type.
Implementations