Set Info Request/Response messages and related types.
Structs
- RawSet
Info Data - SetInfo
Request - SMB2 SET_INFO request packet for setting information on a file or object store.
- SetInfo
Response - SMB2 SET_INFO response packet indicating successful completion.
Enums
- SetInfo
Class - Information class specifying the type of information to set.
- SetInfo
Data - Enum to hold the different info types for SetInfoData, that are used within SMB requests for querying or setting information.