pub enum SetInfoData {
File(RawSetInfoData<SetFileInfo>),
FileSystem(RawSetInfoData<SetFileSystemInfo>),
Security(SecurityDescriptor),
Quota(ChainedItemList<FileQuotaInformation>),
}Expand description
Enum to hold the different info types for SetInfoData, that are used within SMB requests for querying or setting information.
Variants
File(RawSetInfoData<SetFileInfo>)
FileSystem(RawSetInfoData<SetFileSystemInfo>)
Security(SecurityDescriptor)
Quota(ChainedItemList<FileQuotaInformation>)
Implementations
Sourceimpl SetInfoData
impl SetInfoData
Sourcepub fn as_file(self) -> Result<RawSetInfoData<SetFileInfo>, SmbMsgError>
pub fn as_file(self) -> Result<RawSetInfoData<SetFileInfo>, SmbMsgError>
Get the inner content as RawSetInfoData<SetFileInfo>.
Sourcepub fn as_filesystem(
self,
) -> Result<RawSetInfoData<SetFileSystemInfo>, SmbMsgError>
pub fn as_filesystem( self, ) -> Result<RawSetInfoData<SetFileSystemInfo>, SmbMsgError>
Get the inner content as RawSetInfoData<SetFileSystemInfo>.
Sourcepub fn as_security(self) -> Result<SecurityDescriptor, SmbMsgError>
pub fn as_security(self) -> Result<SecurityDescriptor, SmbMsgError>
Get the inner content as SecurityDescriptor.
Sourcepub fn as_quota(
self,
) -> Result<ChainedItemList<FileQuotaInformation>, SmbMsgError>
pub fn as_quota( self, ) -> Result<ChainedItemList<FileQuotaInformation>, SmbMsgError>
Get the inner content as ChainedItemList<FileQuotaInformation>.
Sourceimpl SetInfoData
impl SetInfoData
Sourcepub fn to_req(
self,
info_class: SetInfoClass,
file_id: FileId,
additional_info: AdditionalInfo,
) -> SetInfoRequest
pub fn to_req( self, info_class: SetInfoClass, file_id: FileId, additional_info: AdditionalInfo, ) -> SetInfoRequest
Creates a SetInfoRequest from this data with the specified parameters.
Validates that the info class and data combination are compatible before creating the request structure.
Panics
Panics if the info class and data type combination is invalid (e.g., File class with FileSystem data).