IOCTL requessts and responses implementation, and FSCTLs.
Structs
- File
Level Trim Range - MSDN
- File
Level Trim Request - File
Level Trim Response - MS-FSCC 2.3.14
- Ioctl
Buffer - Utility structure to represent inner value of Ioctl requests that have no defined struct (i.e. they are treated as raw byte buffers).
- Ioctl
Request - SMB2 IOCTL request packet for issuing file system control or device control commands.
- Ioctl
Request Flags - Flags field indicating how to process the IOCTL operation.
- Ioctl
Response - SMB2 IOCTL response packet containing results of an IOCTL request.
- LmrRequest
Resiliency Response - Network
Interface Capability - Capability flags for network interfaces indicating supported features. Used in the NetworkInterfaceInfo structure to specify interface capabilities.
- Network
Interface Info - Network interface information structure returned by FSCTL_QUERY_NETWORK_INTERFACE_INFO. Contains details about a specific network interface on the server.
- Network
Resiliency Request - Request packet for requesting resiliency for a specified open file. Sent in an SMB2 IOCTL Request using FSCTL_LMR_REQUEST_RESILIENCY. This request is not valid for the SMB 2.0.2 dialect.
- Offload
Read Request - MS-FSCC 2.3.41
- Offload
Read Response - MS-FSCC 2.3.42
- Pipe
Peek Request - Pipe
Peek Response - MS-FSCC 2.3.46
- Pipe
Transceive Request - Pipe
Transceive Response - Pipe
Wait Request - The FSCTL_PIPE_WAIT Request requests that the server wait until either a time-out interval elapses, or an instance of the specified named pipe is available for connection.
- Pipe
Wait Response - Query
Alloc Ranges Item - Query
Alloc Ranges Result - Query
Network Interface Info Request - SetReparse
Point Request - Stores data for a reparse point.
- SetReparse
Point Response - Socket
Addr Storage V4 - Socket
Addr Storage V6 - SrvCopy
Chunk Copy Write - SrvCopychunk
Copy - Request packet for initiating a server-side copy of data. Sent in an SMB2 IOCTL Request using FSCTL_SRV_COPYCHUNK or FSCTL_SRV_COPYCHUNK_WRITE.
- SrvCopychunk
Item - Individual data range descriptor for server-side copy operations. Sent in the chunks array of a SRV_COPYCHUNK_COPY packet to describe an individual data range to copy.
- SrvCopychunk
Response - Response packet for server-side copy operations. Returned by the server in an SMB2 IOCTL Response for FSCTL_SRV_COPYCHUNK or FSCTL_SRV_COPYCHUNK_WRITE requests to provide the results of the copy operation.
- SrvEnumerate
Snapshots Request - SrvEnumerate
Snapshots Response - MS-SMB 2.2.7.2.2.1
- SrvHash
Retrieve File Based - File-based response format for SRV_READ_HASH when HashRetrievalType is SRV_HASH_RETRIEVE_FILE_BASED. Valid for servers implementing the SMB 3.x dialect family. Contains hash information for a specified range of file data.
- SrvHash
Retrieve Hash Based - Hash-based response format for SRV_READ_HASH when HashRetrievalType is SRV_HASH_RETRIEVE_HASH_BASED. Contains a portion of the Content Information File retrieved from a specified offset.
- SrvRead
Hash Req - Request packet for retrieving data from the Content Information File associated with a specified file. Sent in an SMB2 IOCTL Request using FSCTL_SRV_READ_HASH. The request is not valid for the SMB 2.0.2 dialect.
- SrvRead
Hash Res - Response packet for SRV_READ_HASH requests. Returned by the server in an SMB2 IOCTL Response for FSCTL_SRV_READ_HASH request. The response is not valid for the SMB 2.0.2 dialect.
- SrvRequest
Resume Key - Response packet containing a resume key for server-side copy operations. Returned by the server in an SMB2 IOCTL Response for FSCTL_SRV_REQUEST_RESUME_KEY request. The resume key can be used to uniquely identify the source file in subsequent copy operations.
- SrvRequest
Resume KeyRequest - SrvSnapshot
Array - Response packet containing snapshots associated with a share. Returned by the server in an SMB2 IOCTL Response for FSCTL_SRV_ENUMERATE_SNAPSHOTS request. Contains all revision timestamps associated with the Tree Connect share.
- Validate
Negotiate Info Request - Request packet for validating a previous SMB 2 NEGOTIATE. Used in FSCTL_VALIDATE_NEGOTIATE_INFO to ensure the negotiation was not tampered with. Valid for clients and servers implementing SMB 3.0 and SMB 3.0.2 dialects.
- Validate
Negotiate Info Response - Response for validating a previous SMB 2 NEGOTIATE. Returned in an SMB2 IOCTL response for FSCTL_VALIDATE_NEGOTIATE_INFO request. Valid for servers implementing the SMB 3.x dialect family, optional for others.
Enums
- Fsctl
Codes - Ioctl
ReqData - Socket
Addr Storage - SrvHash
Retrieval Type - Enum specifying the nature of the offset field in SRV_READ_HASH requests. Determines how the offset field should be interpreted for hash retrieval.
Traits
- Fsctl
Request - This is a helper trait that defines, for a certain FSCTL request type, the response type and their matching FSCTL code.
- Fsctl
Response Content - A trait that helps parsing FSCTL responses by matching the FSCTL code.
- Ioctl
Request Content - A trait that helps calculating the size of the buffer for IOCTL requests.