pub struct FileLevelTrimRange {
pub offset: u64,
pub length: u64,
}Expand description
Supports std::mem::size_of.
Fields
offset: u64Offset, in bytes, from the start of the file for the range to be trimmed.
length: u64Length, in bytes, for the range to be trimmed.