IoctlRequest

Struct IoctlRequest 

pub struct IoctlRequest {
    pub ctl_code: u32,
    pub file_id: FileId,
    pub max_input_response: u32,
    pub max_output_response: u32,
    pub flags: IoctlRequestFlags,
    pub buffer: IoctlReqData,
}
SMB2 IOCTL request packet for issuing file system control or device control commands.

Used to send implementation-specific FSCTL/IOCTL commands across the network. The structure size is fixed at 57 bytes regardless of the buffer size.

MS-SMB2 2.2.31

Fields

ctl_code: u32

Control code of the FSCTL/IOCTL method to execute

file_id: FileId

File identifier on which to perform the command

max_input_response: u32

Maximum bytes server can return for input data in response

max_output_response: u32

Maximum bytes server can return for output data in response

flags: IoctlRequestFlags

Indicates whether this is an IOCTL (0x00000000) or FSCTL (0x00000001) request

buffer: IoctlReqData

Variable-length buffer containing input data for the FSCTL/IOCTL command