pub struct IoctlRequestFlags { /* private fields */ }Implementations
Sourceimpl IoctlRequestFlags
impl IoctlRequestFlags
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl IoctlRequestFlags
impl IoctlRequestFlags
Sourcepub fn is_fsctl_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn is_fsctl_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of is_fsctl.
#Errors
If the returned value contains an invalid bit pattern for is_fsctl.
Sourcepub fn with_is_fsctl(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_is_fsctl(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of is_fsctl set to the given value.
#Panics
If the given value is out of bounds for is_fsctl.
Sourcepub fn with_is_fsctl_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_is_fsctl_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of is_fsctl set to the given value.
#Errors
If the given value is out of bounds for is_fsctl.
Sourcepub fn set_is_fsctl(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_is_fsctl(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of is_fsctl to the given value.
#Panics
If the given value is out of bounds for is_fsctl.
Sourcepub fn set_is_fsctl_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_is_fsctl_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of is_fsctl to the given value.
#Errors
If the given value is out of bounds for is_fsctl.