IoctlResponse

Struct IoctlResponse 

pub struct IoctlResponse {
    pub ctl_code: u32,
    pub file_id: FileId,
    pub in_buffer: Vec<u8>,
    pub out_buffer: Vec<u8>,
}
SMB2 IOCTL response packet containing results of an IOCTL request.

Sent by server to transmit the results of a client SMB2 IOCTL request. The structure size is fixed at 49 bytes regardless of the buffer size.

MS-SMB2 2.2.32

Fields

ctl_code: u32

Control code of the FSCTL/IOCTL method that was executed

file_id: FileId

File identifier on which the command was performed

in_buffer: Vec<u8>

Input data buffer (typically empty for responses except pass-through operations)

out_buffer: Vec<u8>

Output data buffer containing results of the FSCTL/IOCTL operation

Implementations

Source

impl IoctlResponse

pub fn parse_fsctl<T>(&self) -> Result<T, SmbMsgError>

Parses the FSCTL response output buffer into the specified response type.

Validates that the control code matches the expected FSCTL codes for the response type before attempting to parse the output buffer.

Errors

Returns MissingFsctlDefinition if the control code doesn’t match any of the expected FSCTL codes for the response type.