OffloadReadRequest

Struct OffloadReadRequest 

pub struct OffloadReadRequest {
    pub flags: u32,
    pub token_time_to_live: u32,
    pub file_offset: u64,
    pub copy_length: u64,
}
Fields

flags: u32

The flags to be set for this operation. Currently, no flags are defined.

token_time_to_live: u32

Time to Live (TTL) value in milliseconds for the generated Token. A value of 0 indicates a default TTL interval.

file_offset: u64

the file offset, in bytes, of the start of a range of bytes in a file from which to generate the Token. MUST be aligned to a logical sector boundary on the volume.

copy_length: u64

the requested range of the file from which to generate the Token. MUST be aligned to a logical sector boundary on the volume