OffloadReadResponse

Struct OffloadReadResponse 

pub struct OffloadReadResponse {
    pub all_zero_beyond_current_range: Boolean,
    pub transfer_length: u64,
    pub token: [u8; 512],
    /* private fields */
}
Fields

all_zero_beyond_current_range: Boolean

The data beyond the current range is logically equivalent to zero.

transfer_length: u64

contains the amount, in bytes, of data that the Token logically represents. This value indicates a contiguous region of the file from the beginning of the requested offset in the input. This value can be smaller than the CopyLength field specified in the request data element, which indicates that less data was logically represented (logically read) with the Token than was requested.

token: [u8; 512]

The generated Token to be used as a representation of the data contained within the portion of the file specified in the input request. The contents of this field MUST NOT be modified during subsequent operations.