pub struct PipePeekResponse {
pub named_pipe_state: NamedPipeState,
pub number_of_messages: u32,
pub message_length: u32,
pub data: Vec<u8>,
}Expand description
Fields
named_pipe_state: NamedPipeStateThe current state of the pipe
number_of_messages: u32Specifies the number of messages available in the pipe if the pipe has been created as a message-type pipe. Otherwise, this field is 0
message_length: u32Specifies the length of the first message available in the pipe if the pipe has been created as a message-type pipe. Otherwise, this field is 0.
data: Vec<u8>The data from the pipe.