PipeWaitRequest

Struct PipeWaitRequest 

pub struct PipeWaitRequest {
    pub timeout: u64,
    pub timeout_specified: Boolean,
    pub name: SizedWideString,
}
The FSCTL_PIPE_WAIT Request requests that the server wait until either a time-out interval elapses, or an instance of the specified named pipe is available for connection.

MS-FSCC 2.3.49

Fields

timeout: u64

specifies the maximum amount of time, in units of 100 milliseconds, that the function can wait for an instance of the named pipe to be available.

timeout_specified: Boolean

Whether the Timeout parameter will be ignored. FALSE Indicates that the server MUST wait forever. Any value in timeout must be ignored.

name: SizedWideString

A Unicode string that contains the name of the named pipe. Name MUST not include the “\pipe", so if the operation was on \server\pipe\pipename, the name would be “pipename”.