pub struct SrvCopychunkItem {
pub source_offset: u64,
pub target_offset: u64,
pub length: u32,
}Expand description
Individual data range descriptor for server-side copy operations. Sent in the chunks array of a SRV_COPYCHUNK_COPY packet to describe an individual data range to copy.
Reference: MS-SMB2 2.2.31.1.1
Fields
source_offset: u64The offset, in bytes, from the beginning of the source file to the location from which the data will be copied.
target_offset: u64The offset, in bytes, from the beginning of the destination file to where the data will be copied.
length: u32The number of bytes of data to copy.
Implementations