SrvCopychunkResponse

Struct SrvCopychunkResponse 

pub struct SrvCopychunkResponse {
    pub chunks_written: u32,
    pub chunk_bytes_written: u32,
    pub total_bytes_written: u32,
}
Response packet for server-side copy operations. Returned by the server in an SMB2 IOCTL Response for FSCTL_SRV_COPYCHUNK or FSCTL_SRV_COPYCHUNK_WRITE requests to provide the results of the copy operation.

Reference: MS-SMB2 2.2.32.1

Fields

chunks_written: u32

For successful operations: the number of chunks that were successfully written. For STATUS_INVALID_PARAMETER: the maximum number of chunks the server will accept.

chunk_bytes_written: u32

For successful operations: the number of bytes written in the last chunk that did not successfully process (if a partial write occurred). For STATUS_INVALID_PARAMETER: the maximum number of bytes the server will allow to be written in a single chunk.

total_bytes_written: u32

For successful operations: the total number of bytes written in the server-side copy operation. For STATUS_INVALID_PARAMETER: the maximum number of bytes the server will accept to copy in a single request.