pub struct SrvHashRetrieveFileBased {
pub file_data_offset: u64,
pub file_data_length: u64,
pub buffer: Vec<u8>,
}Expand description
File-based response format for SRV_READ_HASH when HashRetrievalType is SRV_HASH_RETRIEVE_FILE_BASED. Valid for servers implementing the SMB 3.x dialect family. Contains hash information for a specified range of file data.
Reference: MS-SMB2 2.2.32.4.3
Fields
file_data_offset: u64File data offset corresponding to the start of the hash data returned.
file_data_length: u64The length, in bytes, starting from the file_data_offset that is covered by the hash data returned.
buffer: Vec<u8>A variable-length buffer that contains the retrieved portion of the Content Information File. TODO: Parse as Content Information File as specified in MS-PCCRC section 2.4.