SrvHashRetrieveHashBased

Struct SrvHashRetrieveHashBased 

pub struct SrvHashRetrieveHashBased {
    pub offset: u64,
    /* private fields */
}
Hash-based response format for SRV_READ_HASH when HashRetrievalType is SRV_HASH_RETRIEVE_HASH_BASED. Contains a portion of the Content Information File retrieved from a specified offset.

Reference: MS-SMB2 2.2.32.4.2

Fields

offset: u64

The offset, in bytes, from the beginning of the Content Information File to the portion retrieved. This equals the offset field in the SRV_READ_HASH request.