SrvSnapshotArray

Struct SrvSnapshotArray 

pub struct SrvSnapshotArray {
    pub number_of_snap_shots: u32,
    pub number_of_snap_shots_returned: u32,
    pub snap_shots: Vec<NullWideString>,
}
Response packet containing snapshots associated with a share. Returned by the server in an SMB2 IOCTL Response for FSCTL_SRV_ENUMERATE_SNAPSHOTS request. Contains all revision timestamps associated with the Tree Connect share.

Reference: MS-SMB2 2.2.32.2

Fields

number_of_snap_shots: u32

The number of previous versions associated with the volume that backs this file.

number_of_snap_shots_returned: u32

The number of previous version timestamps returned in the snapshots array. If the output buffer could not accommodate the entire array, this will be zero.

snap_shots: Vec<NullWideString>

An array of timestamps in GMT format (@GMT token), separated by UNICODE null characters and terminated by two UNICODE null characters. Empty if the output buffer could not accommodate the entire array.