pub struct ValidateNegotiateInfoRequest {
pub capabilities: u32,
pub guid: Guid,
pub security_mode: NegotiateSecurityMode,
pub dialects: Vec<Dialect>,
}Expand description
Request packet for validating a previous SMB 2 NEGOTIATE. Used in FSCTL_VALIDATE_NEGOTIATE_INFO to ensure the negotiation was not tampered with. Valid for clients and servers implementing SMB 3.0 and SMB 3.0.2 dialects.
Reference: MS-SMB2 2.2.31.4
Fields
capabilities: u32The capabilities of the client.
guid: GuidThe ClientGuid of the client.
security_mode: NegotiateSecurityModeThe security mode of the client.
dialects: Vec<Dialect>The list of SMB2 dialects supported by the client. These entries should contain only the dialect values defined in the negotiate request.