pub trait FsctlRequest: for<'a> BinWrite<Args<'a> = ()> + Into<IoctlReqData> {
type Response: FsctlResponseContent;
const FSCTL_CODE: FsctlCodes;
}Expand description
This is a helper trait that defines, for a certain FSCTL request type, the response type and their matching FSCTL code.
Required Associated Constants
const FSCTL_CODE: FsctlCodes
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.