pub struct LockElement {
pub offset: u64,
pub length: u64,
pub flags: LockFlag,
}Expand description
SMB2_LOCK_ELEMENT structure used to indicate segments of files that are locked or unlocked in SMB2 LOCK requests.
Reference: MS-SMB2 2.2.26.1
Fields
offset: u64Starting offset in bytes from where the range being locked or unlocked starts.
length: u64Length in bytes of the range being locked or unlocked.
flags: LockFlagFlags describing how the range is being locked or unlocked and how to process the operation.