LockSequence

Struct LockSequence 

pub struct LockSequence { /* private fields */ }
Lock sequence information containing sequence number and index. In SMB 2.0.2 dialect, this field is unused and must be reserved. In all other dialects, contains sequence number and index fields.

Reference: MS-SMB2 2.2.26

Implementations

Source

impl LockSequence

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl LockSequence

pub const fn into_bytes(self) -> [u8; 4]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 4]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl LockSequence

pub fn number(&self) -> <B4 as Specifier>::InOut

Returns the value of number. 4-bit integer value containing the lock sequence number.

pub fn number_or_err( &self, ) -> Result<<B4 as Specifier>::InOut, InvalidBitPattern<<B4 as Specifier>::Bytes>>

Returns the value of number.

#Errors

If the returned value contains an invalid bit pattern for number. 4-bit integer value containing the lock sequence number.

pub fn with_number(self, new_val: <B4 as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of number set to the given value.

#Panics

If the given value is out of bounds for number. 4-bit integer value containing the lock sequence number.

pub fn with_number_checked( self, new_val: <B4 as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of number set to the given value.

#Errors

If the given value is out of bounds for number. 4-bit integer value containing the lock sequence number.

pub fn set_number(&mut self, new_val: <B4 as Specifier>::InOut)

Sets the value of number to the given value.

#Panics

If the given value is out of bounds for number. 4-bit integer value containing the lock sequence number.

pub fn set_number_checked( &mut self, new_val: <B4 as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of number to the given value.

#Errors

If the given value is out of bounds for number. 4-bit integer value containing the lock sequence number.

pub fn index(&self) -> <B28 as Specifier>::InOut

Returns the value of index. 28-bit integer value that must contain a value from 0 to 64, where 0 is reserved.

pub fn index_or_err( &self, ) -> Result<<B28 as Specifier>::InOut, InvalidBitPattern<<B28 as Specifier>::Bytes>>

Returns the value of index.

#Errors

If the returned value contains an invalid bit pattern for index. 28-bit integer value that must contain a value from 0 to 64, where 0 is reserved.

pub fn with_index(self, new_val: <B28 as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of index set to the given value.

#Panics

If the given value is out of bounds for index. 28-bit integer value that must contain a value from 0 to 64, where 0 is reserved.

pub fn with_index_checked( self, new_val: <B28 as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of index set to the given value.

#Errors

If the given value is out of bounds for index. 28-bit integer value that must contain a value from 0 to 64, where 0 is reserved.

pub fn set_index(&mut self, new_val: <B28 as Specifier>::InOut)

Sets the value of index to the given value.

#Panics

If the given value is out of bounds for index. 28-bit integer value that must contain a value from 0 to 64, where 0 is reserved.

pub fn set_index_checked( &mut self, new_val: <B28 as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of index to the given value.

#Errors

If the given value is out of bounds for index. 28-bit integer value that must contain a value from 0 to 64, where 0 is reserved.