pub enum NegotiateContextValue {
PreauthIntegrityCapabilities(PreauthIntegrityCapabilities),
EncryptionCapabilities(EncryptionCapabilities),
CompressionCapabilities(CompressionCapabilities),
NetnameNegotiateContextId(NetnameNegotiateContextId),
TransportCapabilities(TransportCapabilities),
RdmaTransformCapabilities(RdmaTransformCapabilities),
SigningCapabilities(SigningCapabilities),
}Expand description
Negotiate context values.
Each variant corresponds to a specific negotiate context type.
Variants
PreauthIntegrityCapabilities(PreauthIntegrityCapabilities)
EncryptionCapabilities(EncryptionCapabilities)
CompressionCapabilities(CompressionCapabilities)
NetnameNegotiateContextId(NetnameNegotiateContextId)
TransportCapabilities(TransportCapabilities)
RdmaTransformCapabilities(RdmaTransformCapabilities)
SigningCapabilities(SigningCapabilities)
Implementations
Sourceimpl NegotiateContextValue
impl NegotiateContextValue
Sourcepub fn get_matching_type(&self) -> NegotiateContextType
pub fn get_matching_type(&self) -> NegotiateContextType
Gets the matching negotiate context type for this value.