pub struct CompressionCapsFlags { /* private fields */ }Implementations
Sourceimpl CompressionCapsFlags
impl CompressionCapsFlags
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl CompressionCapsFlags
impl CompressionCapsFlags
Sourcepub fn chained_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn chained_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of chained.
#Errors
If the returned value contains an invalid bit pattern for chained.
Sourcepub fn with_chained(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_chained(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of chained set to the given value.
#Panics
If the given value is out of bounds for chained.
Sourcepub fn with_chained_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_chained_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of chained set to the given value.
#Errors
If the given value is out of bounds for chained.
Sourcepub fn set_chained(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_chained(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of chained to the given value.
#Panics
If the given value is out of bounds for chained.
Sourcepub fn set_chained_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_chained_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of chained to the given value.
#Errors
If the given value is out of bounds for chained.