GlobalCapabilities

Struct GlobalCapabilities 

pub struct GlobalCapabilities { /* private fields */ }
Global capabilities flags for SMB2/SMB3.

Indicates various protocol capabilities supported by the client or server.

Reference: MS-SMB2 2.2.3

Implementations

Source

impl GlobalCapabilities

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl GlobalCapabilities

pub const fn into_bytes(self) -> [u8; 4]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 4]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl GlobalCapabilities

pub fn dfs(&self) -> <bool as Specifier>::InOut

Returns the value of dfs. DFS support.

pub fn dfs_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of dfs.

#Errors

If the returned value contains an invalid bit pattern for dfs. DFS support.

pub fn with_dfs(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of dfs set to the given value.

#Panics

If the given value is out of bounds for dfs. DFS support.

pub fn with_dfs_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of dfs set to the given value.

#Errors

If the given value is out of bounds for dfs. DFS support.

pub fn set_dfs(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of dfs to the given value.

#Panics

If the given value is out of bounds for dfs. DFS support.

pub fn set_dfs_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of dfs to the given value.

#Errors

If the given value is out of bounds for dfs. DFS support.

pub fn leasing(&self) -> <bool as Specifier>::InOut

Returns the value of leasing. File leasing support.

pub fn leasing_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of leasing.

#Errors

If the returned value contains an invalid bit pattern for leasing. File leasing support.

pub fn with_leasing(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of leasing set to the given value.

#Panics

If the given value is out of bounds for leasing. File leasing support.

pub fn with_leasing_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of leasing set to the given value.

#Errors

If the given value is out of bounds for leasing. File leasing support.

pub fn set_leasing(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of leasing to the given value.

#Panics

If the given value is out of bounds for leasing. File leasing support.

pub fn set_leasing_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of leasing to the given value.

#Errors

If the given value is out of bounds for leasing. File leasing support.

pub fn large_mtu(&self) -> <bool as Specifier>::InOut

Returns the value of large_mtu. Large MTU support (multiple credit operations).

pub fn large_mtu_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of large_mtu.

#Errors

If the returned value contains an invalid bit pattern for large_mtu. Large MTU support (multiple credit operations).

pub fn with_large_mtu(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of large_mtu set to the given value.

#Panics

If the given value is out of bounds for large_mtu. Large MTU support (multiple credit operations).

pub fn with_large_mtu_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of large_mtu set to the given value.

#Errors

If the given value is out of bounds for large_mtu. Large MTU support (multiple credit operations).

pub fn set_large_mtu(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of large_mtu to the given value.

#Panics

If the given value is out of bounds for large_mtu. Large MTU support (multiple credit operations).

pub fn set_large_mtu_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of large_mtu to the given value.

#Errors

If the given value is out of bounds for large_mtu. Large MTU support (multiple credit operations).

pub fn multi_channel(&self) -> <bool as Specifier>::InOut

Returns the value of multi_channel. Multi-channel support.

pub fn multi_channel_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of multi_channel.

#Errors

If the returned value contains an invalid bit pattern for multi_channel. Multi-channel support.

pub fn with_multi_channel(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of multi_channel set to the given value.

#Panics

If the given value is out of bounds for multi_channel. Multi-channel support.

pub fn with_multi_channel_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of multi_channel set to the given value.

#Errors

If the given value is out of bounds for multi_channel. Multi-channel support.

pub fn set_multi_channel(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of multi_channel to the given value.

#Panics

If the given value is out of bounds for multi_channel. Multi-channel support.

pub fn set_multi_channel_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of multi_channel to the given value.

#Errors

If the given value is out of bounds for multi_channel. Multi-channel support.

pub fn persistent_handles(&self) -> <bool as Specifier>::InOut

Returns the value of persistent_handles. Persistent handles support.

pub fn persistent_handles_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of persistent_handles.

#Errors

If the returned value contains an invalid bit pattern for persistent_handles. Persistent handles support.

pub fn with_persistent_handles( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of persistent_handles set to the given value.

#Panics

If the given value is out of bounds for persistent_handles. Persistent handles support.

pub fn with_persistent_handles_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of persistent_handles set to the given value.

#Errors

If the given value is out of bounds for persistent_handles. Persistent handles support.

pub fn set_persistent_handles(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of persistent_handles to the given value.

#Panics

If the given value is out of bounds for persistent_handles. Persistent handles support.

pub fn set_persistent_handles_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of persistent_handles to the given value.

#Errors

If the given value is out of bounds for persistent_handles. Persistent handles support.

pub fn directory_leasing(&self) -> <bool as Specifier>::InOut

Returns the value of directory_leasing. Directory leasing support.

pub fn directory_leasing_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of directory_leasing.

#Errors

If the returned value contains an invalid bit pattern for directory_leasing. Directory leasing support.

pub fn with_directory_leasing(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of directory_leasing set to the given value.

#Panics

If the given value is out of bounds for directory_leasing. Directory leasing support.

pub fn with_directory_leasing_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of directory_leasing set to the given value.

#Errors

If the given value is out of bounds for directory_leasing. Directory leasing support.

pub fn set_directory_leasing(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of directory_leasing to the given value.

#Panics

If the given value is out of bounds for directory_leasing. Directory leasing support.

pub fn set_directory_leasing_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of directory_leasing to the given value.

#Errors

If the given value is out of bounds for directory_leasing. Directory leasing support.

pub fn encryption(&self) -> <bool as Specifier>::InOut

Returns the value of encryption. Encryption support.

pub fn encryption_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of encryption.

#Errors

If the returned value contains an invalid bit pattern for encryption. Encryption support.

pub fn with_encryption(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of encryption set to the given value.

#Panics

If the given value is out of bounds for encryption. Encryption support.

pub fn with_encryption_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of encryption set to the given value.

#Errors

If the given value is out of bounds for encryption. Encryption support.

pub fn set_encryption(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of encryption to the given value.

#Panics

If the given value is out of bounds for encryption. Encryption support.

pub fn set_encryption_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of encryption to the given value.

#Errors

If the given value is out of bounds for encryption. Encryption support.

pub fn notifications(&self) -> <bool as Specifier>::InOut

Returns the value of notifications. Change notifications support.

pub fn notifications_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of notifications.

#Errors

If the returned value contains an invalid bit pattern for notifications. Change notifications support.

pub fn with_notifications(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of notifications set to the given value.

#Panics

If the given value is out of bounds for notifications. Change notifications support.

pub fn with_notifications_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of notifications set to the given value.

#Errors

If the given value is out of bounds for notifications. Change notifications support.

pub fn set_notifications(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of notifications to the given value.

#Panics

If the given value is out of bounds for notifications. Change notifications support.

pub fn set_notifications_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of notifications to the given value.

#Errors

If the given value is out of bounds for notifications. Change notifications support.