pub struct TransportCapabilities { /* private fields */ }Expand description
(Context) Transport capabilities.
Specifies whether QUIC transport is supported.
Reference: MS-SMB2 2.2.3.1.5
Implementations
Sourceimpl TransportCapabilities
impl TransportCapabilities
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl TransportCapabilities
impl TransportCapabilities
Sourcepub fn accept_transport_layer_security(&self) -> <bool as Specifier>::InOut
pub fn accept_transport_layer_security(&self) -> <bool as Specifier>::InOut
Returns the value of accept_transport_layer_security. QUIC transport support.
Sourcepub fn accept_transport_layer_security_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn accept_transport_layer_security_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of accept_transport_layer_security.
#Errors
If the returned value contains an invalid bit pattern for accept_transport_layer_security. QUIC transport support.
Sourcepub fn with_accept_transport_layer_security(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_accept_transport_layer_security( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of accept_transport_layer_security set to the given value.
#Panics
If the given value is out of bounds for accept_transport_layer_security. QUIC transport support.
Sourcepub fn with_accept_transport_layer_security_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_accept_transport_layer_security_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of accept_transport_layer_security set to the given value.
#Errors
If the given value is out of bounds for accept_transport_layer_security. QUIC transport support.
Sourcepub fn set_accept_transport_layer_security(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_accept_transport_layer_security( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of accept_transport_layer_security to the given value.
#Panics
If the given value is out of bounds for accept_transport_layer_security. QUIC transport support.
Sourcepub fn set_accept_transport_layer_security_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_accept_transport_layer_security_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of accept_transport_layer_security to the given value.
#Errors
If the given value is out of bounds for accept_transport_layer_security. QUIC transport support.