SMB2 Change Notify Request and Response, and Server to Client Notification
Structs
- Change
Notify Request - Change
Notify Response - Notify
Filter - Notify
Flags - Notify
Session Closed - Server
ToClient Notification
SMB2 Change Notify Request and Response, and Server to Client Notification