ChangeNotifyRequest

Struct ChangeNotifyRequest 

pub struct ChangeNotifyRequest {
    pub flags: NotifyFlags,
    pub output_buffer_length: u32,
    pub file_id: FileId,
    pub completion_filter: NotifyFilter,
}
SMB2 CHANGE_NOTIFY Request packet sent by the client to request change notifications on a directory. The client can monitor changes on any file or directory contained beneath the specified directory.

Reference: MS-SMB2 2.2.35

Fields

flags: NotifyFlags

Flags indicating how the operation must be processed.

output_buffer_length: u32

Maximum number of bytes the server is allowed to return in the response.

file_id: FileId

File identifier of the directory to monitor for changes.

completion_filter: NotifyFilter

Specifies the types of changes to monitor. Multiple trigger conditions can be chosen.