NotifyFilter

Struct NotifyFilter 

pub struct NotifyFilter { /* private fields */ }

Implementations

Source

impl NotifyFilter

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl NotifyFilter

pub const fn into_bytes(self) -> [u8; 4]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 4]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl NotifyFilter

pub fn file_name(&self) -> <bool as Specifier>::InOut

Returns the value of file_name.

pub fn file_name_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of file_name.

#Errors

If the returned value contains an invalid bit pattern for file_name.

pub fn with_file_name(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of file_name set to the given value.

#Panics

If the given value is out of bounds for file_name.

pub fn with_file_name_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of file_name set to the given value.

#Errors

If the given value is out of bounds for file_name.

pub fn set_file_name(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of file_name to the given value.

#Panics

If the given value is out of bounds for file_name.

pub fn set_file_name_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of file_name to the given value.

#Errors

If the given value is out of bounds for file_name.

pub fn dir_name(&self) -> <bool as Specifier>::InOut

Returns the value of dir_name.

pub fn dir_name_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of dir_name.

#Errors

If the returned value contains an invalid bit pattern for dir_name.

pub fn with_dir_name(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of dir_name set to the given value.

#Panics

If the given value is out of bounds for dir_name.

pub fn with_dir_name_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of dir_name set to the given value.

#Errors

If the given value is out of bounds for dir_name.

pub fn set_dir_name(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of dir_name to the given value.

#Panics

If the given value is out of bounds for dir_name.

pub fn set_dir_name_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of dir_name to the given value.

#Errors

If the given value is out of bounds for dir_name.

pub fn attributes(&self) -> <bool as Specifier>::InOut

Returns the value of attributes.

pub fn attributes_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of attributes.

#Errors

If the returned value contains an invalid bit pattern for attributes.

pub fn with_attributes(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of attributes set to the given value.

#Panics

If the given value is out of bounds for attributes.

pub fn with_attributes_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of attributes set to the given value.

#Errors

If the given value is out of bounds for attributes.

pub fn set_attributes(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of attributes to the given value.

#Panics

If the given value is out of bounds for attributes.

pub fn set_attributes_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of attributes to the given value.

#Errors

If the given value is out of bounds for attributes.

pub fn size(&self) -> <bool as Specifier>::InOut

Returns the value of size.

pub fn size_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of size.

#Errors

If the returned value contains an invalid bit pattern for size.

pub fn with_size(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of size set to the given value.

#Panics

If the given value is out of bounds for size.

pub fn with_size_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of size set to the given value.

#Errors

If the given value is out of bounds for size.

pub fn set_size(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of size to the given value.

#Panics

If the given value is out of bounds for size.

pub fn set_size_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of size to the given value.

#Errors

If the given value is out of bounds for size.

pub fn last_write(&self) -> <bool as Specifier>::InOut

Returns the value of last_write.

pub fn last_write_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of last_write.

#Errors

If the returned value contains an invalid bit pattern for last_write.

pub fn with_last_write(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of last_write set to the given value.

#Panics

If the given value is out of bounds for last_write.

pub fn with_last_write_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of last_write set to the given value.

#Errors

If the given value is out of bounds for last_write.

pub fn set_last_write(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of last_write to the given value.

#Panics

If the given value is out of bounds for last_write.

pub fn set_last_write_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of last_write to the given value.

#Errors

If the given value is out of bounds for last_write.

pub fn last_access(&self) -> <bool as Specifier>::InOut

Returns the value of last_access.

pub fn last_access_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of last_access.

#Errors

If the returned value contains an invalid bit pattern for last_access.

pub fn with_last_access(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of last_access set to the given value.

#Panics

If the given value is out of bounds for last_access.

pub fn with_last_access_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of last_access set to the given value.

#Errors

If the given value is out of bounds for last_access.

pub fn set_last_access(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of last_access to the given value.

#Panics

If the given value is out of bounds for last_access.

pub fn set_last_access_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of last_access to the given value.

#Errors

If the given value is out of bounds for last_access.

pub fn creation(&self) -> <bool as Specifier>::InOut

Returns the value of creation.

pub fn creation_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of creation.

#Errors

If the returned value contains an invalid bit pattern for creation.

pub fn with_creation(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of creation set to the given value.

#Panics

If the given value is out of bounds for creation.

pub fn with_creation_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of creation set to the given value.

#Errors

If the given value is out of bounds for creation.

pub fn set_creation(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of creation to the given value.

#Panics

If the given value is out of bounds for creation.

pub fn set_creation_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of creation to the given value.

#Errors

If the given value is out of bounds for creation.

pub fn ea(&self) -> <bool as Specifier>::InOut

Returns the value of ea.

pub fn ea_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of ea.

#Errors

If the returned value contains an invalid bit pattern for ea.

pub fn with_ea(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of ea set to the given value.

#Panics

If the given value is out of bounds for ea.

pub fn with_ea_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of ea set to the given value.

#Errors

If the given value is out of bounds for ea.

pub fn set_ea(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of ea to the given value.

#Panics

If the given value is out of bounds for ea.

pub fn set_ea_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of ea to the given value.

#Errors

If the given value is out of bounds for ea.

pub fn security(&self) -> <bool as Specifier>::InOut

Returns the value of security.

pub fn security_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of security.

#Errors

If the returned value contains an invalid bit pattern for security.

pub fn with_security(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of security set to the given value.

#Panics

If the given value is out of bounds for security.

pub fn with_security_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of security set to the given value.

#Errors

If the given value is out of bounds for security.

pub fn set_security(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of security to the given value.

#Panics

If the given value is out of bounds for security.

pub fn set_security_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of security to the given value.

#Errors

If the given value is out of bounds for security.

pub fn stream_name(&self) -> <bool as Specifier>::InOut

Returns the value of stream_name.

pub fn stream_name_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of stream_name.

#Errors

If the returned value contains an invalid bit pattern for stream_name.

pub fn with_stream_name(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of stream_name set to the given value.

#Panics

If the given value is out of bounds for stream_name.

pub fn with_stream_name_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of stream_name set to the given value.

#Errors

If the given value is out of bounds for stream_name.

pub fn set_stream_name(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of stream_name to the given value.

#Panics

If the given value is out of bounds for stream_name.

pub fn set_stream_name_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of stream_name to the given value.

#Errors

If the given value is out of bounds for stream_name.

pub fn stream_size(&self) -> <bool as Specifier>::InOut

Returns the value of stream_size.

pub fn stream_size_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of stream_size.

#Errors

If the returned value contains an invalid bit pattern for stream_size.

pub fn with_stream_size(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of stream_size set to the given value.

#Panics

If the given value is out of bounds for stream_size.

pub fn with_stream_size_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of stream_size set to the given value.

#Errors

If the given value is out of bounds for stream_size.

pub fn set_stream_size(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of stream_size to the given value.

#Panics

If the given value is out of bounds for stream_size.

pub fn set_stream_size_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of stream_size to the given value.

#Errors

If the given value is out of bounds for stream_size.

pub fn stream_write(&self) -> <bool as Specifier>::InOut

Returns the value of stream_write.

pub fn stream_write_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of stream_write.

#Errors

If the returned value contains an invalid bit pattern for stream_write.

pub fn with_stream_write(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of stream_write set to the given value.

#Panics

If the given value is out of bounds for stream_write.

pub fn with_stream_write_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of stream_write set to the given value.

#Errors

If the given value is out of bounds for stream_write.

pub fn set_stream_write(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of stream_write to the given value.

#Panics

If the given value is out of bounds for stream_write.

pub fn set_stream_write_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of stream_write to the given value.

#Errors

If the given value is out of bounds for stream_write.