OpLock messages (requests, responses, notifications)
Structs
- Lease
Break AckResponse - Lease Break Acknowledgment/Response message.
- Lease
Break Notify - Lease Break Notification message.
- Lease
State - Lease state bitfield representing different types of caching permissions.
- Oplock
Break Msg - Oplock Break Notification/Acknowledgment/Response message.
Enums
- Oplock
Level - Oplock level values used in oplock break operations.
Type Aliases
- Lease
Break Ack - Lease Break Acknowledgment - sent by client in response to lease break notification.
- Lease
Break Response - Lease Break Response - sent by server in response to lease break acknowledgment.
- Oplock
Break Ack - Oplock Break Acknowledgment - sent by client in response to oplock break notification.
- Oplock
Break Notify - Oplock Break Notification - sent by server when an oplock is being broken.
- Oplock
Break Response - Oplock Break Response - sent by server in response to oplock break acknowledgment.