LeaseBreakNotify

Struct LeaseBreakNotify 

pub struct LeaseBreakNotify { /* private fields */ }
Lease Break Notification message.

Sent by the server when the underlying object store indicates that a lease is being broken, representing a change in the lease state. Not valid for SMB 2.0.2 dialect.

Reference: MS-SMB2 2.2.23.2