pub type LeaseBreakResponse = LeaseBreakAckResponse;Expand description
Lease Break Response - sent by server in response to lease break acknowledgment.
Aliased Type
pub struct LeaseBreakResponse { /* private fields */ }pub type LeaseBreakResponse = LeaseBreakAckResponse;Lease Break Response - sent by server in response to lease break acknowledgment.
pub struct LeaseBreakResponse { /* private fields */ }