pub type OplockBreakNotify = OplockBreakMsg;Expand description
Oplock Break Notification - sent by server when an oplock is being broken.
Aliased Type
pub struct OplockBreakNotify { /* private fields */ }pub type OplockBreakNotify = OplockBreakMsg;Oplock Break Notification - sent by server when an oplock is being broken.
pub struct OplockBreakNotify { /* private fields */ }