pub type OplockBreakResponse = OplockBreakMsg;Expand description
Oplock Break Response - sent by server in response to oplock break acknowledgment.
Aliased Type
pub struct OplockBreakResponse { /* private fields */ }pub type OplockBreakResponse = OplockBreakMsg;Oplock Break Response - sent by server in response to oplock break acknowledgment.
pub struct OplockBreakResponse { /* private fields */ }