pub enum ResponseContent {
Show 23 variants
Negotiate(NegotiateResponse),
SessionSetup(SessionSetupResponse),
Logoff(LogoffResponse),
TreeConnect(TreeConnectResponse),
TreeDisconnect(TreeDisconnectResponse),
Create(CreateResponse),
Close(CloseResponse),
Flush(FlushResponse),
Read(ReadResponse),
Write(WriteResponse),
Lock(LockResponse),
Ioctl(IoctlResponse),
Echo(EchoResponse),
QueryDirectory(QueryDirectoryResponse),
ChangeNotify(ChangeNotifyResponse),
QueryInfo(QueryInfoResponse),
SetInfo(SetInfoResponse),
OplockBreakNotify(OplockBreakNotify),
LeaseBreakNotify(LeaseBreakNotify),
OplockBreak(OplockBreakResponse),
LeaseBreak(LeaseBreakResponse),
ServerToClientNotification(ServerToClientNotification),
Error(ErrorResponse),
}Expand description
Contains all the variants for a plain SMB2 response message.
For example - read/write/create/close responses, etc.
Variants
Negotiate(NegotiateResponse)
SessionSetup(SessionSetupResponse)
Logoff(LogoffResponse)
TreeConnect(TreeConnectResponse)
TreeDisconnect(TreeDisconnectResponse)
Create(CreateResponse)
Close(CloseResponse)
Flush(FlushResponse)
Read(ReadResponse)
Write(WriteResponse)
Lock(LockResponse)
Ioctl(IoctlResponse)
Echo(EchoResponse)
QueryDirectory(QueryDirectoryResponse)
ChangeNotify(ChangeNotifyResponse)
QueryInfo(QueryInfoResponse)
SetInfo(SetInfoResponse)
OplockBreakNotify(OplockBreakNotify)
LeaseBreakNotify(LeaseBreakNotify)
OplockBreak(OplockBreakResponse)
LeaseBreak(LeaseBreakResponse)
ServerToClientNotification(ServerToClientNotification)
Error(ErrorResponse)
Implementations
Sourceimpl ResponseContent
impl ResponseContent
Sourcepub fn associated_cmd(&self) -> Command
pub fn associated_cmd(&self) -> Command
Get the command associated with this content.
Sourceimpl ResponseContent
impl ResponseContent
Sourcepub fn content_name(&self) -> &'static str
pub fn content_name(&self) -> &'static str
Returns the name of the content value.
Sourcepub fn to_negotiate(self) -> Result<NegotiateResponse, SmbMsgError>
pub fn to_negotiate(self) -> Result<NegotiateResponse, SmbMsgError>
Attempts to cast the current content type to [negotiate :: NegotiateResponse].
Sourcepub fn as_negotiate(&self) -> Result<&NegotiateResponse, SmbMsgError>
pub fn as_negotiate(&self) -> Result<&NegotiateResponse, SmbMsgError>
Attempts to cast the current content type to [negotiate :: NegotiateResponse].
Sourcepub fn as_mut_negotiate(
&mut self,
) -> Result<&mut NegotiateResponse, SmbMsgError>
pub fn as_mut_negotiate( &mut self, ) -> Result<&mut NegotiateResponse, SmbMsgError>
Attempts to cast the current content type to [negotiate :: NegotiateResponse].
Sourcepub fn to_sessionsetup(self) -> Result<SessionSetupResponse, SmbMsgError>
pub fn to_sessionsetup(self) -> Result<SessionSetupResponse, SmbMsgError>
Attempts to cast the current content type to [session_setup :: SessionSetupResponse].
Sourcepub fn as_sessionsetup(&self) -> Result<&SessionSetupResponse, SmbMsgError>
pub fn as_sessionsetup(&self) -> Result<&SessionSetupResponse, SmbMsgError>
Attempts to cast the current content type to [session_setup :: SessionSetupResponse].
Sourcepub fn as_mut_sessionsetup(
&mut self,
) -> Result<&mut SessionSetupResponse, SmbMsgError>
pub fn as_mut_sessionsetup( &mut self, ) -> Result<&mut SessionSetupResponse, SmbMsgError>
Attempts to cast the current content type to [session_setup :: SessionSetupResponse].
Sourcepub fn to_logoff(self) -> Result<LogoffResponse, SmbMsgError>
pub fn to_logoff(self) -> Result<LogoffResponse, SmbMsgError>
Attempts to cast the current content type to [session_setup :: LogoffResponse].
Sourcepub fn as_logoff(&self) -> Result<&LogoffResponse, SmbMsgError>
pub fn as_logoff(&self) -> Result<&LogoffResponse, SmbMsgError>
Attempts to cast the current content type to [session_setup :: LogoffResponse].
Sourcepub fn as_mut_logoff(&mut self) -> Result<&mut LogoffResponse, SmbMsgError>
pub fn as_mut_logoff(&mut self) -> Result<&mut LogoffResponse, SmbMsgError>
Attempts to cast the current content type to [session_setup :: LogoffResponse].
Sourcepub fn to_treeconnect(self) -> Result<TreeConnectResponse, SmbMsgError>
pub fn to_treeconnect(self) -> Result<TreeConnectResponse, SmbMsgError>
Attempts to cast the current content type to [tree_connect :: TreeConnectResponse].
Sourcepub fn as_treeconnect(&self) -> Result<&TreeConnectResponse, SmbMsgError>
pub fn as_treeconnect(&self) -> Result<&TreeConnectResponse, SmbMsgError>
Attempts to cast the current content type to [tree_connect :: TreeConnectResponse].
Sourcepub fn as_mut_treeconnect(
&mut self,
) -> Result<&mut TreeConnectResponse, SmbMsgError>
pub fn as_mut_treeconnect( &mut self, ) -> Result<&mut TreeConnectResponse, SmbMsgError>
Attempts to cast the current content type to [tree_connect :: TreeConnectResponse].
Sourcepub fn to_treedisconnect(self) -> Result<TreeDisconnectResponse, SmbMsgError>
pub fn to_treedisconnect(self) -> Result<TreeDisconnectResponse, SmbMsgError>
Attempts to cast the current content type to [tree_connect :: TreeDisconnectResponse].
Sourcepub fn as_treedisconnect(&self) -> Result<&TreeDisconnectResponse, SmbMsgError>
pub fn as_treedisconnect(&self) -> Result<&TreeDisconnectResponse, SmbMsgError>
Attempts to cast the current content type to [tree_connect :: TreeDisconnectResponse].
Sourcepub fn as_mut_treedisconnect(
&mut self,
) -> Result<&mut TreeDisconnectResponse, SmbMsgError>
pub fn as_mut_treedisconnect( &mut self, ) -> Result<&mut TreeDisconnectResponse, SmbMsgError>
Attempts to cast the current content type to [tree_connect :: TreeDisconnectResponse].
Sourcepub fn to_create(self) -> Result<CreateResponse, SmbMsgError>
pub fn to_create(self) -> Result<CreateResponse, SmbMsgError>
Attempts to cast the current content type to [create :: CreateResponse].
Sourcepub fn as_create(&self) -> Result<&CreateResponse, SmbMsgError>
pub fn as_create(&self) -> Result<&CreateResponse, SmbMsgError>
Attempts to cast the current content type to [create :: CreateResponse].
Sourcepub fn as_mut_create(&mut self) -> Result<&mut CreateResponse, SmbMsgError>
pub fn as_mut_create(&mut self) -> Result<&mut CreateResponse, SmbMsgError>
Attempts to cast the current content type to [create :: CreateResponse].
Sourcepub fn to_close(self) -> Result<CloseResponse, SmbMsgError>
pub fn to_close(self) -> Result<CloseResponse, SmbMsgError>
Attempts to cast the current content type to [create :: CloseResponse].
Sourcepub fn as_close(&self) -> Result<&CloseResponse, SmbMsgError>
pub fn as_close(&self) -> Result<&CloseResponse, SmbMsgError>
Attempts to cast the current content type to [create :: CloseResponse].
Sourcepub fn as_mut_close(&mut self) -> Result<&mut CloseResponse, SmbMsgError>
pub fn as_mut_close(&mut self) -> Result<&mut CloseResponse, SmbMsgError>
Attempts to cast the current content type to [create :: CloseResponse].
Sourcepub fn to_flush(self) -> Result<FlushResponse, SmbMsgError>
pub fn to_flush(self) -> Result<FlushResponse, SmbMsgError>
Attempts to cast the current content type to [file :: FlushResponse].
Sourcepub fn as_flush(&self) -> Result<&FlushResponse, SmbMsgError>
pub fn as_flush(&self) -> Result<&FlushResponse, SmbMsgError>
Attempts to cast the current content type to [file :: FlushResponse].
Sourcepub fn as_mut_flush(&mut self) -> Result<&mut FlushResponse, SmbMsgError>
pub fn as_mut_flush(&mut self) -> Result<&mut FlushResponse, SmbMsgError>
Attempts to cast the current content type to [file :: FlushResponse].
Sourcepub fn to_read(self) -> Result<ReadResponse, SmbMsgError>
pub fn to_read(self) -> Result<ReadResponse, SmbMsgError>
Attempts to cast the current content type to [file :: ReadResponse].
Sourcepub fn as_read(&self) -> Result<&ReadResponse, SmbMsgError>
pub fn as_read(&self) -> Result<&ReadResponse, SmbMsgError>
Attempts to cast the current content type to [file :: ReadResponse].
Sourcepub fn as_mut_read(&mut self) -> Result<&mut ReadResponse, SmbMsgError>
pub fn as_mut_read(&mut self) -> Result<&mut ReadResponse, SmbMsgError>
Attempts to cast the current content type to [file :: ReadResponse].
Sourcepub fn to_write(self) -> Result<WriteResponse, SmbMsgError>
pub fn to_write(self) -> Result<WriteResponse, SmbMsgError>
Attempts to cast the current content type to [file :: WriteResponse].
Sourcepub fn as_write(&self) -> Result<&WriteResponse, SmbMsgError>
pub fn as_write(&self) -> Result<&WriteResponse, SmbMsgError>
Attempts to cast the current content type to [file :: WriteResponse].
Sourcepub fn as_mut_write(&mut self) -> Result<&mut WriteResponse, SmbMsgError>
pub fn as_mut_write(&mut self) -> Result<&mut WriteResponse, SmbMsgError>
Attempts to cast the current content type to [file :: WriteResponse].
Sourcepub fn to_lock(self) -> Result<LockResponse, SmbMsgError>
pub fn to_lock(self) -> Result<LockResponse, SmbMsgError>
Attempts to cast the current content type to [lock :: LockResponse].
Sourcepub fn as_lock(&self) -> Result<&LockResponse, SmbMsgError>
pub fn as_lock(&self) -> Result<&LockResponse, SmbMsgError>
Attempts to cast the current content type to [lock :: LockResponse].
Sourcepub fn as_mut_lock(&mut self) -> Result<&mut LockResponse, SmbMsgError>
pub fn as_mut_lock(&mut self) -> Result<&mut LockResponse, SmbMsgError>
Attempts to cast the current content type to [lock :: LockResponse].
Sourcepub fn to_ioctl(self) -> Result<IoctlResponse, SmbMsgError>
pub fn to_ioctl(self) -> Result<IoctlResponse, SmbMsgError>
Attempts to cast the current content type to [ioctl :: IoctlResponse].
Sourcepub fn as_ioctl(&self) -> Result<&IoctlResponse, SmbMsgError>
pub fn as_ioctl(&self) -> Result<&IoctlResponse, SmbMsgError>
Attempts to cast the current content type to [ioctl :: IoctlResponse].
Sourcepub fn as_mut_ioctl(&mut self) -> Result<&mut IoctlResponse, SmbMsgError>
pub fn as_mut_ioctl(&mut self) -> Result<&mut IoctlResponse, SmbMsgError>
Attempts to cast the current content type to [ioctl :: IoctlResponse].
Sourcepub fn to_echo(self) -> Result<EchoResponse, SmbMsgError>
pub fn to_echo(self) -> Result<EchoResponse, SmbMsgError>
Attempts to cast the current content type to [echo :: EchoResponse].
Sourcepub fn as_echo(&self) -> Result<&EchoResponse, SmbMsgError>
pub fn as_echo(&self) -> Result<&EchoResponse, SmbMsgError>
Attempts to cast the current content type to [echo :: EchoResponse].
Sourcepub fn as_mut_echo(&mut self) -> Result<&mut EchoResponse, SmbMsgError>
pub fn as_mut_echo(&mut self) -> Result<&mut EchoResponse, SmbMsgError>
Attempts to cast the current content type to [echo :: EchoResponse].
Sourcepub fn to_querydirectory(self) -> Result<QueryDirectoryResponse, SmbMsgError>
pub fn to_querydirectory(self) -> Result<QueryDirectoryResponse, SmbMsgError>
Attempts to cast the current content type to [query_dir :: QueryDirectoryResponse].
Sourcepub fn as_querydirectory(&self) -> Result<&QueryDirectoryResponse, SmbMsgError>
pub fn as_querydirectory(&self) -> Result<&QueryDirectoryResponse, SmbMsgError>
Attempts to cast the current content type to [query_dir :: QueryDirectoryResponse].
Sourcepub fn as_mut_querydirectory(
&mut self,
) -> Result<&mut QueryDirectoryResponse, SmbMsgError>
pub fn as_mut_querydirectory( &mut self, ) -> Result<&mut QueryDirectoryResponse, SmbMsgError>
Attempts to cast the current content type to [query_dir :: QueryDirectoryResponse].
Sourcepub fn to_changenotify(self) -> Result<ChangeNotifyResponse, SmbMsgError>
pub fn to_changenotify(self) -> Result<ChangeNotifyResponse, SmbMsgError>
Attempts to cast the current content type to [notify :: ChangeNotifyResponse].
Sourcepub fn as_changenotify(&self) -> Result<&ChangeNotifyResponse, SmbMsgError>
pub fn as_changenotify(&self) -> Result<&ChangeNotifyResponse, SmbMsgError>
Attempts to cast the current content type to [notify :: ChangeNotifyResponse].
Sourcepub fn as_mut_changenotify(
&mut self,
) -> Result<&mut ChangeNotifyResponse, SmbMsgError>
pub fn as_mut_changenotify( &mut self, ) -> Result<&mut ChangeNotifyResponse, SmbMsgError>
Attempts to cast the current content type to [notify :: ChangeNotifyResponse].
Sourcepub fn to_queryinfo(self) -> Result<QueryInfoResponse, SmbMsgError>
pub fn to_queryinfo(self) -> Result<QueryInfoResponse, SmbMsgError>
Attempts to cast the current content type to [info :: QueryInfoResponse].
Sourcepub fn as_queryinfo(&self) -> Result<&QueryInfoResponse, SmbMsgError>
pub fn as_queryinfo(&self) -> Result<&QueryInfoResponse, SmbMsgError>
Attempts to cast the current content type to [info :: QueryInfoResponse].
Sourcepub fn as_mut_queryinfo(
&mut self,
) -> Result<&mut QueryInfoResponse, SmbMsgError>
pub fn as_mut_queryinfo( &mut self, ) -> Result<&mut QueryInfoResponse, SmbMsgError>
Attempts to cast the current content type to [info :: QueryInfoResponse].
Sourcepub fn to_setinfo(self) -> Result<SetInfoResponse, SmbMsgError>
pub fn to_setinfo(self) -> Result<SetInfoResponse, SmbMsgError>
Attempts to cast the current content type to [info :: SetInfoResponse].
Sourcepub fn as_setinfo(&self) -> Result<&SetInfoResponse, SmbMsgError>
pub fn as_setinfo(&self) -> Result<&SetInfoResponse, SmbMsgError>
Attempts to cast the current content type to [info :: SetInfoResponse].
Sourcepub fn as_mut_setinfo(&mut self) -> Result<&mut SetInfoResponse, SmbMsgError>
pub fn as_mut_setinfo(&mut self) -> Result<&mut SetInfoResponse, SmbMsgError>
Attempts to cast the current content type to [info :: SetInfoResponse].
Sourcepub fn to_oplockbreaknotify(self) -> Result<OplockBreakNotify, SmbMsgError>
pub fn to_oplockbreaknotify(self) -> Result<OplockBreakNotify, SmbMsgError>
Attempts to cast the current content type to [oplock :: OplockBreakNotify].
Sourcepub fn as_oplockbreaknotify(&self) -> Result<&OplockBreakNotify, SmbMsgError>
pub fn as_oplockbreaknotify(&self) -> Result<&OplockBreakNotify, SmbMsgError>
Attempts to cast the current content type to [oplock :: OplockBreakNotify].
Sourcepub fn as_mut_oplockbreaknotify(
&mut self,
) -> Result<&mut OplockBreakNotify, SmbMsgError>
pub fn as_mut_oplockbreaknotify( &mut self, ) -> Result<&mut OplockBreakNotify, SmbMsgError>
Attempts to cast the current content type to [oplock :: OplockBreakNotify].
Sourcepub fn to_leasebreaknotify(self) -> Result<LeaseBreakNotify, SmbMsgError>
pub fn to_leasebreaknotify(self) -> Result<LeaseBreakNotify, SmbMsgError>
Attempts to cast the current content type to [oplock :: LeaseBreakNotify].
Sourcepub fn as_leasebreaknotify(&self) -> Result<&LeaseBreakNotify, SmbMsgError>
pub fn as_leasebreaknotify(&self) -> Result<&LeaseBreakNotify, SmbMsgError>
Attempts to cast the current content type to [oplock :: LeaseBreakNotify].
Sourcepub fn as_mut_leasebreaknotify(
&mut self,
) -> Result<&mut LeaseBreakNotify, SmbMsgError>
pub fn as_mut_leasebreaknotify( &mut self, ) -> Result<&mut LeaseBreakNotify, SmbMsgError>
Attempts to cast the current content type to [oplock :: LeaseBreakNotify].
Sourcepub fn to_oplockbreak(self) -> Result<OplockBreakResponse, SmbMsgError>
pub fn to_oplockbreak(self) -> Result<OplockBreakResponse, SmbMsgError>
Attempts to cast the current content type to [oplock :: OplockBreakResponse].
Sourcepub fn as_oplockbreak(&self) -> Result<&OplockBreakResponse, SmbMsgError>
pub fn as_oplockbreak(&self) -> Result<&OplockBreakResponse, SmbMsgError>
Attempts to cast the current content type to [oplock :: OplockBreakResponse].
Sourcepub fn as_mut_oplockbreak(
&mut self,
) -> Result<&mut OplockBreakResponse, SmbMsgError>
pub fn as_mut_oplockbreak( &mut self, ) -> Result<&mut OplockBreakResponse, SmbMsgError>
Attempts to cast the current content type to [oplock :: OplockBreakResponse].
Sourcepub fn to_leasebreak(self) -> Result<LeaseBreakResponse, SmbMsgError>
pub fn to_leasebreak(self) -> Result<LeaseBreakResponse, SmbMsgError>
Attempts to cast the current content type to [oplock :: LeaseBreakResponse].
Sourcepub fn as_leasebreak(&self) -> Result<&LeaseBreakResponse, SmbMsgError>
pub fn as_leasebreak(&self) -> Result<&LeaseBreakResponse, SmbMsgError>
Attempts to cast the current content type to [oplock :: LeaseBreakResponse].
Sourcepub fn as_mut_leasebreak(
&mut self,
) -> Result<&mut LeaseBreakResponse, SmbMsgError>
pub fn as_mut_leasebreak( &mut self, ) -> Result<&mut LeaseBreakResponse, SmbMsgError>
Attempts to cast the current content type to [oplock :: LeaseBreakResponse].
Sourcepub fn to_servertoclientnotification(
self,
) -> Result<ServerToClientNotification, SmbMsgError>
pub fn to_servertoclientnotification( self, ) -> Result<ServerToClientNotification, SmbMsgError>
Attempts to cast the current content type to [notify :: ServerToClientNotification].
Sourcepub fn as_servertoclientnotification(
&self,
) -> Result<&ServerToClientNotification, SmbMsgError>
pub fn as_servertoclientnotification( &self, ) -> Result<&ServerToClientNotification, SmbMsgError>
Attempts to cast the current content type to [notify :: ServerToClientNotification].
Sourcepub fn as_mut_servertoclientnotification(
&mut self,
) -> Result<&mut ServerToClientNotification, SmbMsgError>
pub fn as_mut_servertoclientnotification( &mut self, ) -> Result<&mut ServerToClientNotification, SmbMsgError>
Attempts to cast the current content type to [notify :: ServerToClientNotification].
Sourcepub fn to_error(self) -> Result<ErrorResponse, SmbMsgError>
pub fn to_error(self) -> Result<ErrorResponse, SmbMsgError>
Attempts to cast the current content type to [error :: ErrorResponse].
Sourcepub fn as_error(&self) -> Result<&ErrorResponse, SmbMsgError>
pub fn as_error(&self) -> Result<&ErrorResponse, SmbMsgError>
Attempts to cast the current content type to [error :: ErrorResponse].
Sourcepub fn as_mut_error(&mut self) -> Result<&mut ErrorResponse, SmbMsgError>
pub fn as_mut_error(&mut self) -> Result<&mut ErrorResponse, SmbMsgError>
Attempts to cast the current content type to [error :: ErrorResponse].