QueryDirectoryFlags

Struct QueryDirectoryFlags 

pub struct QueryDirectoryFlags { /* private fields */ }
Flags indicating how the query directory operation must be processed.

These flags control the behavior of directory enumeration, such as whether to restart the scan from the beginning or return only a single entry.

Reference: MS-SMB2 section 2.2.33

Implementations

Source

impl QueryDirectoryFlags

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl QueryDirectoryFlags

pub const fn into_bytes(self) -> [u8; 1]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 1]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl QueryDirectoryFlags

pub fn restart_scans(&self) -> <bool as Specifier>::InOut

Returns the value of restart_scans. The server is requested to restart the enumeration from the beginning.

pub fn restart_scans_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of restart_scans.

#Errors

If the returned value contains an invalid bit pattern for restart_scans. The server is requested to restart the enumeration from the beginning.

pub fn with_restart_scans(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of restart_scans set to the given value.

#Panics

If the given value is out of bounds for restart_scans. The server is requested to restart the enumeration from the beginning.

pub fn with_restart_scans_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of restart_scans set to the given value.

#Errors

If the given value is out of bounds for restart_scans. The server is requested to restart the enumeration from the beginning.

pub fn set_restart_scans(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of restart_scans to the given value.

#Panics

If the given value is out of bounds for restart_scans. The server is requested to restart the enumeration from the beginning.

pub fn set_restart_scans_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of restart_scans to the given value.

#Errors

If the given value is out of bounds for restart_scans. The server is requested to restart the enumeration from the beginning.

pub fn return_single_entry(&self) -> <bool as Specifier>::InOut

Returns the value of return_single_entry. The server is requested to only return the first entry of the search results.

pub fn return_single_entry_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of return_single_entry.

#Errors

If the returned value contains an invalid bit pattern for return_single_entry. The server is requested to only return the first entry of the search results.

pub fn with_return_single_entry( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of return_single_entry set to the given value.

#Panics

If the given value is out of bounds for return_single_entry. The server is requested to only return the first entry of the search results.

pub fn with_return_single_entry_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of return_single_entry set to the given value.

#Errors

If the given value is out of bounds for return_single_entry. The server is requested to only return the first entry of the search results.

pub fn set_return_single_entry(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of return_single_entry to the given value.

#Panics

If the given value is out of bounds for return_single_entry. The server is requested to only return the first entry of the search results.

pub fn set_return_single_entry_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of return_single_entry to the given value.

#Errors

If the given value is out of bounds for return_single_entry. The server is requested to only return the first entry of the search results.

pub fn index_specified(&self) -> <bool as Specifier>::InOut

Returns the value of index_specified. The server is requested to return entries beginning at the byte number specified by FileIndex.

pub fn index_specified_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of index_specified.

#Errors

If the returned value contains an invalid bit pattern for index_specified. The server is requested to return entries beginning at the byte number specified by FileIndex.

pub fn with_index_specified(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of index_specified set to the given value.

#Panics

If the given value is out of bounds for index_specified. The server is requested to return entries beginning at the byte number specified by FileIndex.

pub fn with_index_specified_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of index_specified set to the given value.

#Errors

If the given value is out of bounds for index_specified. The server is requested to return entries beginning at the byte number specified by FileIndex.

pub fn set_index_specified(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of index_specified to the given value.

#Panics

If the given value is out of bounds for index_specified. The server is requested to return entries beginning at the byte number specified by FileIndex.

pub fn set_index_specified_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of index_specified to the given value.

#Errors

If the given value is out of bounds for index_specified. The server is requested to return entries beginning at the byte number specified by FileIndex.

pub fn reopen(&self) -> <bool as Specifier>::InOut

Returns the value of reopen. The server is requested to restart the enumeration from the beginning, and the search pattern is to be changed.

pub fn reopen_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of reopen.

#Errors

If the returned value contains an invalid bit pattern for reopen. The server is requested to restart the enumeration from the beginning, and the search pattern is to be changed.

pub fn with_reopen(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of reopen set to the given value.

#Panics

If the given value is out of bounds for reopen. The server is requested to restart the enumeration from the beginning, and the search pattern is to be changed.

pub fn with_reopen_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of reopen set to the given value.

#Errors

If the given value is out of bounds for reopen. The server is requested to restart the enumeration from the beginning, and the search pattern is to be changed.

pub fn set_reopen(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of reopen to the given value.

#Panics

If the given value is out of bounds for reopen. The server is requested to restart the enumeration from the beginning, and the search pattern is to be changed.

pub fn set_reopen_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of reopen to the given value.

#Errors

If the given value is out of bounds for reopen. The server is requested to restart the enumeration from the beginning, and the search pattern is to be changed.