Module session_setup

Module session_setup 

Session setup messages

Structs

LogoffRequest
SMB2 LOGOFF Request packet sent by the client to request termination of a particular session.
LogoffResponse
SMB2 LOGOFF Response packet sent by the server in response to a LOGOFF Request.
NegotiateCapabilities
Protocol capabilities for the client.
SessionFlags
Flags indicating additional information about the session.
SessionSecurityMode
Security mode field specifying whether SMB signing is enabled or required at the client.
SessionSetupRequest
SMB2 SESSION_SETUP Request packet sent by the client to request a new authenticated session within a new or existing SMB 2 Protocol transport connection.
SessionSetupResponse
SMB2 SESSION_SETUP Response packet sent by the server in response to a SESSION_SETUP Request.
SetupRequestFlags
Flags field for SESSION_SETUP request (SMB 3.x dialect family only).