pub struct NegotiateCapabilities { /* private fields */ }Implementations
Sourceimpl NegotiateCapabilities
impl NegotiateCapabilities
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl NegotiateCapabilities
impl NegotiateCapabilities
Sourcepub fn dfs_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn dfs_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of dfs.
#Errors
If the returned value contains an invalid bit pattern for dfs.
Sourcepub fn with_dfs(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_dfs(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of dfs set to the given value.
#Panics
If the given value is out of bounds for dfs.
Sourcepub fn with_dfs_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_dfs_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of dfs set to the given value.
#Errors
If the given value is out of bounds for dfs.
Sourcepub fn set_dfs(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_dfs(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of dfs to the given value.
#Panics
If the given value is out of bounds for dfs.
Sourcepub fn set_dfs_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_dfs_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of dfs to the given value.
#Errors
If the given value is out of bounds for dfs.