SessionFlags

Struct SessionFlags 

pub struct SessionFlags { /* private fields */ }
Flags indicating additional information about the session.

MS-SMB2 2.2.6

Implementations

Source

impl SessionFlags

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl SessionFlags

pub const fn into_bytes(self) -> [u8; 2]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 2]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl SessionFlags

pub fn is_guest(&self) -> <bool as Specifier>::InOut

Returns the value of is_guest. Client has been authenticated as a guest user

pub fn is_guest_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of is_guest.

#Errors

If the returned value contains an invalid bit pattern for is_guest. Client has been authenticated as a guest user

pub fn with_is_guest(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of is_guest set to the given value.

#Panics

If the given value is out of bounds for is_guest. Client has been authenticated as a guest user

pub fn with_is_guest_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of is_guest set to the given value.

#Errors

If the given value is out of bounds for is_guest. Client has been authenticated as a guest user

pub fn set_is_guest(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of is_guest to the given value.

#Panics

If the given value is out of bounds for is_guest. Client has been authenticated as a guest user

pub fn set_is_guest_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of is_guest to the given value.

#Errors

If the given value is out of bounds for is_guest. Client has been authenticated as a guest user

pub fn is_null_session(&self) -> <bool as Specifier>::InOut

Returns the value of is_null_session. Client has been authenticated as an anonymous user

pub fn is_null_session_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of is_null_session.

#Errors

If the returned value contains an invalid bit pattern for is_null_session. Client has been authenticated as an anonymous user

pub fn with_is_null_session(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of is_null_session set to the given value.

#Panics

If the given value is out of bounds for is_null_session. Client has been authenticated as an anonymous user

pub fn with_is_null_session_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of is_null_session set to the given value.

#Errors

If the given value is out of bounds for is_null_session. Client has been authenticated as an anonymous user

pub fn set_is_null_session(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of is_null_session to the given value.

#Panics

If the given value is out of bounds for is_null_session. Client has been authenticated as an anonymous user

pub fn set_is_null_session_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of is_null_session to the given value.

#Errors

If the given value is out of bounds for is_null_session. Client has been authenticated as an anonymous user

pub fn encrypt_data(&self) -> <bool as Specifier>::InOut

Returns the value of encrypt_data. Server requires encryption of messages on this session (SMB 3.x only)

pub fn encrypt_data_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of encrypt_data.

#Errors

If the returned value contains an invalid bit pattern for encrypt_data. Server requires encryption of messages on this session (SMB 3.x only)

pub fn with_encrypt_data(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of encrypt_data set to the given value.

#Panics

If the given value is out of bounds for encrypt_data. Server requires encryption of messages on this session (SMB 3.x only)

pub fn with_encrypt_data_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of encrypt_data set to the given value.

#Errors

If the given value is out of bounds for encrypt_data. Server requires encryption of messages on this session (SMB 3.x only)

pub fn set_encrypt_data(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of encrypt_data to the given value.

#Panics

If the given value is out of bounds for encrypt_data. Server requires encryption of messages on this session (SMB 3.x only)

pub fn set_encrypt_data_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of encrypt_data to the given value.

#Errors

If the given value is out of bounds for encrypt_data. Server requires encryption of messages on this session (SMB 3.x only)

Source

impl SessionFlags