pub struct ShareFlags { /* private fields */ }Expand description
Share flags indicating various share properties
Reference: MS-SMB2 2.2.10
Implementations
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourcepub fn dfs(&self) -> <bool as Specifier>::InOut
pub fn dfs(&self) -> <bool as Specifier>::InOut
Returns the value of dfs. Share is present in a Distributed File System tree structure
Sourcepub fn dfs_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn dfs_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of dfs.
#Errors
If the returned value contains an invalid bit pattern for dfs. Share is present in a Distributed File System tree structure
Sourcepub fn with_dfs(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_dfs(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of dfs set to the given value.
#Panics
If the given value is out of bounds for dfs. Share is present in a Distributed File System tree structure
Sourcepub fn with_dfs_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_dfs_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of dfs set to the given value.
#Errors
If the given value is out of bounds for dfs. Share is present in a Distributed File System tree structure
Sourcepub fn set_dfs(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_dfs(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of dfs to the given value.
#Panics
If the given value is out of bounds for dfs. Share is present in a Distributed File System tree structure
Sourcepub fn set_dfs_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_dfs_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of dfs to the given value.
#Errors
If the given value is out of bounds for dfs. Share is present in a Distributed File System tree structure
Sourcepub fn dfs_root(&self) -> <bool as Specifier>::InOut
pub fn dfs_root(&self) -> <bool as Specifier>::InOut
Returns the value of dfs_root. Share is present in a DFS Root tree structure
Sourcepub fn dfs_root_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn dfs_root_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of dfs_root.
#Errors
If the returned value contains an invalid bit pattern for dfs_root. Share is present in a DFS Root tree structure
Sourcepub fn with_dfs_root(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_dfs_root(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of dfs_root set to the given value.
#Panics
If the given value is out of bounds for dfs_root. Share is present in a DFS Root tree structure
Sourcepub fn with_dfs_root_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_dfs_root_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of dfs_root set to the given value.
#Errors
If the given value is out of bounds for dfs_root. Share is present in a DFS Root tree structure
Sourcepub fn set_dfs_root(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_dfs_root(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of dfs_root to the given value.
#Panics
If the given value is out of bounds for dfs_root. Share is present in a DFS Root tree structure
Sourcepub fn set_dfs_root_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_dfs_root_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of dfs_root to the given value.
#Errors
If the given value is out of bounds for dfs_root. Share is present in a DFS Root tree structure
Sourcepub fn caching_mode(&self) -> <ShareCacheMode as Specifier>::InOut
pub fn caching_mode(&self) -> <ShareCacheMode as Specifier>::InOut
Returns the value of caching_mode. Offline caching behavior for this share
Sourcepub fn caching_mode_or_err(
&self,
) -> Result<<ShareCacheMode as Specifier>::InOut, InvalidBitPattern<<ShareCacheMode as Specifier>::Bytes>>
pub fn caching_mode_or_err( &self, ) -> Result<<ShareCacheMode as Specifier>::InOut, InvalidBitPattern<<ShareCacheMode as Specifier>::Bytes>>
Returns the value of caching_mode.
#Errors
If the returned value contains an invalid bit pattern for caching_mode. Offline caching behavior for this share
Sourcepub fn with_caching_mode(
self,
new_val: <ShareCacheMode as Specifier>::InOut,
) -> Self
pub fn with_caching_mode( self, new_val: <ShareCacheMode as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of caching_mode set to the given value.
#Panics
If the given value is out of bounds for caching_mode. Offline caching behavior for this share
Sourcepub fn with_caching_mode_checked(
self,
new_val: <ShareCacheMode as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_caching_mode_checked( self, new_val: <ShareCacheMode as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of caching_mode set to the given value.
#Errors
If the given value is out of bounds for caching_mode. Offline caching behavior for this share
Sourcepub fn set_caching_mode(
&mut self,
new_val: <ShareCacheMode as Specifier>::InOut,
)
pub fn set_caching_mode( &mut self, new_val: <ShareCacheMode as Specifier>::InOut, )
Sets the value of caching_mode to the given value.
#Panics
If the given value is out of bounds for caching_mode. Offline caching behavior for this share
Sourcepub fn set_caching_mode_checked(
&mut self,
new_val: <ShareCacheMode as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_caching_mode_checked( &mut self, new_val: <ShareCacheMode as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of caching_mode to the given value.
#Errors
If the given value is out of bounds for caching_mode. Offline caching behavior for this share
Sourcepub fn restrict_exclusive_opens(&self) -> <bool as Specifier>::InOut
pub fn restrict_exclusive_opens(&self) -> <bool as Specifier>::InOut
Returns the value of restrict_exclusive_opens. Share disallows exclusive file opens that deny reads to an open file
Sourcepub fn restrict_exclusive_opens_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn restrict_exclusive_opens_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of restrict_exclusive_opens.
#Errors
If the returned value contains an invalid bit pattern for restrict_exclusive_opens. Share disallows exclusive file opens that deny reads to an open file
Sourcepub fn with_restrict_exclusive_opens(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_restrict_exclusive_opens( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of restrict_exclusive_opens set to the given value.
#Panics
If the given value is out of bounds for restrict_exclusive_opens. Share disallows exclusive file opens that deny reads to an open file
Sourcepub fn with_restrict_exclusive_opens_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_restrict_exclusive_opens_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of restrict_exclusive_opens set to the given value.
#Errors
If the given value is out of bounds for restrict_exclusive_opens. Share disallows exclusive file opens that deny reads to an open file
Sourcepub fn set_restrict_exclusive_opens(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_restrict_exclusive_opens( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of restrict_exclusive_opens to the given value.
#Panics
If the given value is out of bounds for restrict_exclusive_opens. Share disallows exclusive file opens that deny reads to an open file
Sourcepub fn set_restrict_exclusive_opens_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_restrict_exclusive_opens_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of restrict_exclusive_opens to the given value.
#Errors
If the given value is out of bounds for restrict_exclusive_opens. Share disallows exclusive file opens that deny reads to an open file
Returns the value of force_shared_delete. Share disallows clients from opening files in exclusive mode that prevents deletion
Returns the value of force_shared_delete.
#Errors
If the returned value contains an invalid bit pattern for force_shared_delete. Share disallows clients from opening files in exclusive mode that prevents deletion
Returns a copy of the bitfield with the value of force_shared_delete set to the given value.
#Panics
If the given value is out of bounds for force_shared_delete. Share disallows clients from opening files in exclusive mode that prevents deletion
Returns a copy of the bitfield with the value of force_shared_delete set to the given value.
#Errors
If the given value is out of bounds for force_shared_delete. Share disallows clients from opening files in exclusive mode that prevents deletion
Sets the value of force_shared_delete to the given value.
#Panics
If the given value is out of bounds for force_shared_delete. Share disallows clients from opening files in exclusive mode that prevents deletion
Sets the value of force_shared_delete to the given value.
#Errors
If the given value is out of bounds for force_shared_delete. Share disallows clients from opening files in exclusive mode that prevents deletion
Sourcepub fn allow_namespace_caching(&self) -> <bool as Specifier>::InOut
pub fn allow_namespace_caching(&self) -> <bool as Specifier>::InOut
Returns the value of allow_namespace_caching. Namespace caching is allowed (client must ignore this flag)
Sourcepub fn allow_namespace_caching_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn allow_namespace_caching_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of allow_namespace_caching.
#Errors
If the returned value contains an invalid bit pattern for allow_namespace_caching. Namespace caching is allowed (client must ignore this flag)
Sourcepub fn with_allow_namespace_caching(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_allow_namespace_caching( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of allow_namespace_caching set to the given value.
#Panics
If the given value is out of bounds for allow_namespace_caching. Namespace caching is allowed (client must ignore this flag)
Sourcepub fn with_allow_namespace_caching_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_allow_namespace_caching_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of allow_namespace_caching set to the given value.
#Errors
If the given value is out of bounds for allow_namespace_caching. Namespace caching is allowed (client must ignore this flag)
Sourcepub fn set_allow_namespace_caching(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_allow_namespace_caching( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of allow_namespace_caching to the given value.
#Panics
If the given value is out of bounds for allow_namespace_caching. Namespace caching is allowed (client must ignore this flag)
Sourcepub fn set_allow_namespace_caching_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_allow_namespace_caching_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of allow_namespace_caching to the given value.
#Errors
If the given value is out of bounds for allow_namespace_caching. Namespace caching is allowed (client must ignore this flag)
Sourcepub fn access_based_directory_enum(&self) -> <bool as Specifier>::InOut
pub fn access_based_directory_enum(&self) -> <bool as Specifier>::InOut
Returns the value of access_based_directory_enum. Server will filter directory entries based on client access permissions
Sourcepub fn access_based_directory_enum_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn access_based_directory_enum_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of access_based_directory_enum.
#Errors
If the returned value contains an invalid bit pattern for access_based_directory_enum. Server will filter directory entries based on client access permissions
Sourcepub fn with_access_based_directory_enum(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_access_based_directory_enum( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of access_based_directory_enum set to the given value.
#Panics
If the given value is out of bounds for access_based_directory_enum. Server will filter directory entries based on client access permissions
Sourcepub fn with_access_based_directory_enum_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_access_based_directory_enum_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of access_based_directory_enum set to the given value.
#Errors
If the given value is out of bounds for access_based_directory_enum. Server will filter directory entries based on client access permissions
Sourcepub fn set_access_based_directory_enum(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_access_based_directory_enum( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of access_based_directory_enum to the given value.
#Panics
If the given value is out of bounds for access_based_directory_enum. Server will filter directory entries based on client access permissions
Sourcepub fn set_access_based_directory_enum_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_access_based_directory_enum_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of access_based_directory_enum to the given value.
#Errors
If the given value is out of bounds for access_based_directory_enum. Server will filter directory entries based on client access permissions
Sourcepub fn force_levelii_oplock(&self) -> <bool as Specifier>::InOut
pub fn force_levelii_oplock(&self) -> <bool as Specifier>::InOut
Returns the value of force_levelii_oplock. Server will not issue exclusive caching rights on this share
Sourcepub fn force_levelii_oplock_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn force_levelii_oplock_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of force_levelii_oplock.
#Errors
If the returned value contains an invalid bit pattern for force_levelii_oplock. Server will not issue exclusive caching rights on this share
Sourcepub fn with_force_levelii_oplock(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_force_levelii_oplock( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of force_levelii_oplock set to the given value.
#Panics
If the given value is out of bounds for force_levelii_oplock. Server will not issue exclusive caching rights on this share
Sourcepub fn with_force_levelii_oplock_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_force_levelii_oplock_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of force_levelii_oplock set to the given value.
#Errors
If the given value is out of bounds for force_levelii_oplock. Server will not issue exclusive caching rights on this share
Sourcepub fn set_force_levelii_oplock(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_force_levelii_oplock(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of force_levelii_oplock to the given value.
#Panics
If the given value is out of bounds for force_levelii_oplock. Server will not issue exclusive caching rights on this share
Sourcepub fn set_force_levelii_oplock_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_force_levelii_oplock_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of force_levelii_oplock to the given value.
#Errors
If the given value is out of bounds for force_levelii_oplock. Server will not issue exclusive caching rights on this share
Sourcepub fn enable_hash_v1(&self) -> <bool as Specifier>::InOut
pub fn enable_hash_v1(&self) -> <bool as Specifier>::InOut
Returns the value of enable_hash_v1. Share supports hash generation for branch cache retrieval of data
Sourcepub fn enable_hash_v1_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn enable_hash_v1_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of enable_hash_v1.
#Errors
If the returned value contains an invalid bit pattern for enable_hash_v1. Share supports hash generation for branch cache retrieval of data
Sourcepub fn with_enable_hash_v1(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_enable_hash_v1(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of enable_hash_v1 set to the given value.
#Panics
If the given value is out of bounds for enable_hash_v1. Share supports hash generation for branch cache retrieval of data
Sourcepub fn with_enable_hash_v1_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_enable_hash_v1_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of enable_hash_v1 set to the given value.
#Errors
If the given value is out of bounds for enable_hash_v1. Share supports hash generation for branch cache retrieval of data
Sourcepub fn set_enable_hash_v1(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_enable_hash_v1(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of enable_hash_v1 to the given value.
#Panics
If the given value is out of bounds for enable_hash_v1. Share supports hash generation for branch cache retrieval of data
Sourcepub fn set_enable_hash_v1_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_enable_hash_v1_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of enable_hash_v1 to the given value.
#Errors
If the given value is out of bounds for enable_hash_v1. Share supports hash generation for branch cache retrieval of data
Sourcepub fn enable_hash_v2(&self) -> <bool as Specifier>::InOut
pub fn enable_hash_v2(&self) -> <bool as Specifier>::InOut
Returns the value of enable_hash_v2. Share supports v2 hash generation for branch cache retrieval of data
Sourcepub fn enable_hash_v2_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn enable_hash_v2_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of enable_hash_v2.
#Errors
If the returned value contains an invalid bit pattern for enable_hash_v2. Share supports v2 hash generation for branch cache retrieval of data
Sourcepub fn with_enable_hash_v2(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_enable_hash_v2(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of enable_hash_v2 set to the given value.
#Panics
If the given value is out of bounds for enable_hash_v2. Share supports v2 hash generation for branch cache retrieval of data
Sourcepub fn with_enable_hash_v2_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_enable_hash_v2_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of enable_hash_v2 set to the given value.
#Errors
If the given value is out of bounds for enable_hash_v2. Share supports v2 hash generation for branch cache retrieval of data
Sourcepub fn set_enable_hash_v2(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_enable_hash_v2(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of enable_hash_v2 to the given value.
#Panics
If the given value is out of bounds for enable_hash_v2. Share supports v2 hash generation for branch cache retrieval of data
Sourcepub fn set_enable_hash_v2_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_enable_hash_v2_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of enable_hash_v2 to the given value.
#Errors
If the given value is out of bounds for enable_hash_v2. Share supports v2 hash generation for branch cache retrieval of data
Sourcepub fn encrypt_data(&self) -> <bool as Specifier>::InOut
pub fn encrypt_data(&self) -> <bool as Specifier>::InOut
Returns the value of encrypt_data. Server requires encryption of remote file access messages on this share
Sourcepub fn encrypt_data_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn encrypt_data_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of encrypt_data.
#Errors
If the returned value contains an invalid bit pattern for encrypt_data. Server requires encryption of remote file access messages on this share
Sourcepub fn with_encrypt_data(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_encrypt_data(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of encrypt_data set to the given value.
#Panics
If the given value is out of bounds for encrypt_data. Server requires encryption of remote file access messages on this share
Sourcepub fn with_encrypt_data_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_encrypt_data_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of encrypt_data set to the given value.
#Errors
If the given value is out of bounds for encrypt_data. Server requires encryption of remote file access messages on this share
Sourcepub fn set_encrypt_data(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_encrypt_data(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of encrypt_data to the given value.
#Panics
If the given value is out of bounds for encrypt_data. Server requires encryption of remote file access messages on this share
Sourcepub fn set_encrypt_data_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_encrypt_data_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of encrypt_data to the given value.
#Errors
If the given value is out of bounds for encrypt_data. Server requires encryption of remote file access messages on this share
Sourcepub fn identity_remoting(&self) -> <bool as Specifier>::InOut
pub fn identity_remoting(&self) -> <bool as Specifier>::InOut
Returns the value of identity_remoting. Share supports identity remoting via SMB2_REMOTED_IDENTITY_TREE_CONNECT context
Sourcepub fn identity_remoting_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn identity_remoting_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of identity_remoting.
#Errors
If the returned value contains an invalid bit pattern for identity_remoting. Share supports identity remoting via SMB2_REMOTED_IDENTITY_TREE_CONNECT context
Sourcepub fn with_identity_remoting(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_identity_remoting(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of identity_remoting set to the given value.
#Panics
If the given value is out of bounds for identity_remoting. Share supports identity remoting via SMB2_REMOTED_IDENTITY_TREE_CONNECT context
Sourcepub fn with_identity_remoting_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_identity_remoting_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of identity_remoting set to the given value.
#Errors
If the given value is out of bounds for identity_remoting. Share supports identity remoting via SMB2_REMOTED_IDENTITY_TREE_CONNECT context
Sourcepub fn set_identity_remoting(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_identity_remoting(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of identity_remoting to the given value.
#Panics
If the given value is out of bounds for identity_remoting. Share supports identity remoting via SMB2_REMOTED_IDENTITY_TREE_CONNECT context
Sourcepub fn set_identity_remoting_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_identity_remoting_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of identity_remoting to the given value.
#Errors
If the given value is out of bounds for identity_remoting. Share supports identity remoting via SMB2_REMOTED_IDENTITY_TREE_CONNECT context
Sourcepub fn compress_data(&self) -> <bool as Specifier>::InOut
pub fn compress_data(&self) -> <bool as Specifier>::InOut
Returns the value of compress_data. Server supports compression of read/write messages on this share
Sourcepub fn compress_data_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn compress_data_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of compress_data.
#Errors
If the returned value contains an invalid bit pattern for compress_data. Server supports compression of read/write messages on this share
Sourcepub fn with_compress_data(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_compress_data(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of compress_data set to the given value.
#Panics
If the given value is out of bounds for compress_data. Server supports compression of read/write messages on this share
Sourcepub fn with_compress_data_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_compress_data_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of compress_data set to the given value.
#Errors
If the given value is out of bounds for compress_data. Server supports compression of read/write messages on this share
Sourcepub fn set_compress_data(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_compress_data(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of compress_data to the given value.
#Panics
If the given value is out of bounds for compress_data. Server supports compression of read/write messages on this share
Sourcepub fn set_compress_data_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_compress_data_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of compress_data to the given value.
#Errors
If the given value is out of bounds for compress_data. Server supports compression of read/write messages on this share
Sourcepub fn isolated_transport(&self) -> <bool as Specifier>::InOut
pub fn isolated_transport(&self) -> <bool as Specifier>::InOut
Returns the value of isolated_transport. Server indicates preference to isolate communication on separate connections
Sourcepub fn isolated_transport_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn isolated_transport_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of isolated_transport.
#Errors
If the returned value contains an invalid bit pattern for isolated_transport. Server indicates preference to isolate communication on separate connections
Sourcepub fn with_isolated_transport(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_isolated_transport( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of isolated_transport set to the given value.
#Panics
If the given value is out of bounds for isolated_transport. Server indicates preference to isolate communication on separate connections
Sourcepub fn with_isolated_transport_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_isolated_transport_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of isolated_transport set to the given value.
#Errors
If the given value is out of bounds for isolated_transport. Server indicates preference to isolate communication on separate connections
Sourcepub fn set_isolated_transport(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_isolated_transport(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of isolated_transport to the given value.
#Panics
If the given value is out of bounds for isolated_transport. Server indicates preference to isolate communication on separate connections
Sourcepub fn set_isolated_transport_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_isolated_transport_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of isolated_transport to the given value.
#Errors
If the given value is out of bounds for isolated_transport. Server indicates preference to isolate communication on separate connections