pub struct TreeCapabilities { /* private fields */ }Expand description
Tree capabilities indicating various share capabilities
Reference: MS-SMB2 2.2.10
Implementations
Sourceimpl TreeCapabilities
impl TreeCapabilities
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl TreeCapabilities
impl TreeCapabilities
Sourcepub fn dfs(&self) -> <bool as Specifier>::InOut
pub fn dfs(&self) -> <bool as Specifier>::InOut
Returns the value of dfs. Share is present in a DFS tree structure
Sourcepub fn dfs_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn dfs_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of dfs.
#Errors
If the returned value contains an invalid bit pattern for dfs. Share is present in a DFS tree structure
Sourcepub fn with_dfs(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_dfs(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of dfs set to the given value.
#Panics
If the given value is out of bounds for dfs. Share is present in a DFS tree structure
Sourcepub fn with_dfs_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_dfs_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of dfs set to the given value.
#Errors
If the given value is out of bounds for dfs. Share is present in a DFS tree structure
Sourcepub fn set_dfs(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_dfs(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of dfs to the given value.
#Panics
If the given value is out of bounds for dfs. Share is present in a DFS tree structure
Sourcepub fn set_dfs_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_dfs_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of dfs to the given value.
#Errors
If the given value is out of bounds for dfs. Share is present in a DFS tree structure
Sourcepub fn continuous_availability(&self) -> <bool as Specifier>::InOut
pub fn continuous_availability(&self) -> <bool as Specifier>::InOut
Returns the value of continuous_availability. Share is continuously available
Sourcepub fn continuous_availability_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn continuous_availability_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of continuous_availability.
#Errors
If the returned value contains an invalid bit pattern for continuous_availability. Share is continuously available
Sourcepub fn with_continuous_availability(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_continuous_availability( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of continuous_availability set to the given value.
#Panics
If the given value is out of bounds for continuous_availability. Share is continuously available
Sourcepub fn with_continuous_availability_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_continuous_availability_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of continuous_availability set to the given value.
#Errors
If the given value is out of bounds for continuous_availability. Share is continuously available
Sourcepub fn set_continuous_availability(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_continuous_availability( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of continuous_availability to the given value.
#Panics
If the given value is out of bounds for continuous_availability. Share is continuously available
Sourcepub fn set_continuous_availability_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_continuous_availability_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of continuous_availability to the given value.
#Errors
If the given value is out of bounds for continuous_availability. Share is continuously available
Sourcepub fn scaleout(&self) -> <bool as Specifier>::InOut
pub fn scaleout(&self) -> <bool as Specifier>::InOut
Returns the value of scaleout. Share facilitates faster recovery of durable handles
Sourcepub fn scaleout_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn scaleout_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of scaleout.
#Errors
If the returned value contains an invalid bit pattern for scaleout. Share facilitates faster recovery of durable handles
Sourcepub fn with_scaleout(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_scaleout(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of scaleout set to the given value.
#Panics
If the given value is out of bounds for scaleout. Share facilitates faster recovery of durable handles
Sourcepub fn with_scaleout_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_scaleout_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of scaleout set to the given value.
#Errors
If the given value is out of bounds for scaleout. Share facilitates faster recovery of durable handles
Sourcepub fn set_scaleout(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_scaleout(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of scaleout to the given value.
#Panics
If the given value is out of bounds for scaleout. Share facilitates faster recovery of durable handles
Sourcepub fn set_scaleout_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_scaleout_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of scaleout to the given value.
#Errors
If the given value is out of bounds for scaleout. Share facilitates faster recovery of durable handles
Sourcepub fn cluster(&self) -> <bool as Specifier>::InOut
pub fn cluster(&self) -> <bool as Specifier>::InOut
Returns the value of cluster. Share provides monitoring through the Witness service
Sourcepub fn cluster_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn cluster_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of cluster.
#Errors
If the returned value contains an invalid bit pattern for cluster. Share provides monitoring through the Witness service
Sourcepub fn with_cluster(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_cluster(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of cluster set to the given value.
#Panics
If the given value is out of bounds for cluster. Share provides monitoring through the Witness service
Sourcepub fn with_cluster_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_cluster_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of cluster set to the given value.
#Errors
If the given value is out of bounds for cluster. Share provides monitoring through the Witness service
Sourcepub fn set_cluster(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_cluster(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of cluster to the given value.
#Panics
If the given value is out of bounds for cluster. Share provides monitoring through the Witness service
Sourcepub fn set_cluster_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_cluster_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of cluster to the given value.
#Errors
If the given value is out of bounds for cluster. Share provides monitoring through the Witness service
Sourcepub fn asymmetric(&self) -> <bool as Specifier>::InOut
pub fn asymmetric(&self) -> <bool as Specifier>::InOut
Returns the value of asymmetric. Share allows dynamic changes in ownership
Sourcepub fn asymmetric_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn asymmetric_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of asymmetric.
#Errors
If the returned value contains an invalid bit pattern for asymmetric. Share allows dynamic changes in ownership
Sourcepub fn with_asymmetric(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_asymmetric(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of asymmetric set to the given value.
#Panics
If the given value is out of bounds for asymmetric. Share allows dynamic changes in ownership
Sourcepub fn with_asymmetric_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_asymmetric_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of asymmetric set to the given value.
#Errors
If the given value is out of bounds for asymmetric. Share allows dynamic changes in ownership
Sourcepub fn set_asymmetric(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_asymmetric(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of asymmetric to the given value.
#Panics
If the given value is out of bounds for asymmetric. Share allows dynamic changes in ownership
Sourcepub fn set_asymmetric_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_asymmetric_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of asymmetric to the given value.
#Errors
If the given value is out of bounds for asymmetric. Share allows dynamic changes in ownership
Sourcepub fn redirect_to_owner(&self) -> <bool as Specifier>::InOut
pub fn redirect_to_owner(&self) -> <bool as Specifier>::InOut
Returns the value of redirect_to_owner. Share supports synchronous share level redirection
Sourcepub fn redirect_to_owner_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn redirect_to_owner_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of redirect_to_owner.
#Errors
If the returned value contains an invalid bit pattern for redirect_to_owner. Share supports synchronous share level redirection
Sourcepub fn with_redirect_to_owner(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_redirect_to_owner(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of redirect_to_owner set to the given value.
#Panics
If the given value is out of bounds for redirect_to_owner. Share supports synchronous share level redirection
Sourcepub fn with_redirect_to_owner_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_redirect_to_owner_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of redirect_to_owner set to the given value.
#Errors
If the given value is out of bounds for redirect_to_owner. Share supports synchronous share level redirection
Sourcepub fn set_redirect_to_owner(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_redirect_to_owner(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of redirect_to_owner to the given value.
#Panics
If the given value is out of bounds for redirect_to_owner. Share supports synchronous share level redirection
Sourcepub fn set_redirect_to_owner_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_redirect_to_owner_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of redirect_to_owner to the given value.
#Errors
If the given value is out of bounds for redirect_to_owner. Share supports synchronous share level redirection