CompressedMessage

Enum CompressedMessage 

pub enum CompressedMessage {
    Unchained(CompressedUnchainedMessage),
    Chained(CompressedChainedMessage),
}
SMB2 compression transform header variants for compressed messages.

Used by client or server when sending compressed messages in SMB 3.1.1 dialect. The variant is determined by the compression flags.

MS-SMB2 2.2.42

Variants

Implementations

Source

impl CompressedMessage

pub fn total_size(&self) -> usize

Calculates the total size of the compressed message including headers and data.