Create & Close (files) requests and responses.
Structs
- Allocation
Size - Specifies the allocation size for a newly created or overwritten file.
- AppInstance
Id - Application instance identifier (SMB 3.x dialect family only).
- AppInstance
Version - Application instance version (SMB 3.1.1 dialect only).
- Close
Flags - Flags indicating how to process the CLOSE operation.
- Close
Request - The SMB2 CLOSE Request packet is used by the client to close an instance of a file that was opened previously with a successful SMB2 CREATE Request.
- Close
Response - The SMB2 CLOSE Response packet is sent by the server to indicate that an SMB2 CLOSE Request was processed successfully.
- Create
Context Request - The common definition that wrap around all create contexts, for both request and response. Create contexts are used to pass additional information to the server or receive additional information from the server in the CREATE request and response.
- Create
Context Response - The common definition that wrap around all create contexts, for both request and response. Create contexts are used to pass additional information to the server or receive additional information from the server in the CREATE request and response.
- Create
Options - Options to be applied when creating or opening the file.
- Create
Request - The SMB2 CREATE Request packet is sent by a client to request either creation of or access to a file. In case of a named pipe or printer, the server creates a new file.
- Create
Response - The SMB2 CREATE Response packet is sent by the server to notify the client of the status of its SMB2 CREATE Request.
- Create
Response Flags - Response flags indicating properties of the opened file. Only valid for SMB 3.x dialect family.
- DH2Q
Resp - Response for SMB 3.x durable or persistent handle request. Indicates successful creation of a durable/persistent handle.
- Durable
Handle Reconnect - Request to reestablish a durable open after being disconnected.
- Durable
Handle Reconnect V2 - Request to reestablish a durable open (SMB 3.x dialect family only).
- Durable
Handle Request - Request for a durable handle that can survive brief network disconnections.
- Durable
Handle Request V2 - Request for a durable or persistent handle (SMB 3.x dialect family only).
- Durable
Handle Response - Response indicating the server has marked the open as durable.
- Durable
Handle V2Flags - Flags for durable handle v2 requests.
- FileId
- 2.2.14.1: SMB2_FILEID
- Lease
Flags - Flags for lease requests and responses.
- Query
Maximal Access Request - Request for the server to retrieve maximal access information.
- Query
Maximal Access Response - Query
OnDisk IdReq - Request for the server to return an identifier for the open file.
- Query
OnDisk IdResp - Response containing disk file and volume identifiers for the opened file.
- Request
Lease V1 - Version 1 lease request and response (SMB 2.1 and 3.x dialect family). Contains the lease key, state, flags, and duration.
- Request
Lease V2 - Version 2 lease request and response (SMB 3.x dialect family only). Includes parent lease key and epoch tracking for lease state changes.
- Share
Access Flags - Specifies the sharing mode for the open.
- Svhdx
Open Device Context V1 - Version 1 context for opening a shared virtual disk file.
- Svhdx
Open Device Context V2 - Version 2 context for opening a shared virtual disk file.
- Timewarp
Token - Request to open a version of the file at a previous point in time.
Enums
- Create
Action - The action taken in establishing the open.
- Create
Context Request Data - The
CreateRequestContext data enum. - Create
Context Response Data - The
CreateResponseContext data enum. - Create
Context Type - This enum contains all the types of create contexts.
- Create
Disposition - Defines the action the server must take if the file already exists. For opening named pipes, this field can be set to any value and is ignored by the server.
- Impersonation
Level - The impersonation level requested by the application issuing the create request.
- Request
Lease - Request for the server to return a lease on a file or directory. Also used by the server to respond with a granted lease.
- Svhdx
Open Device Context - Context for opening a shared virtual disk file.
Traits
- Create
Context Data Request Value - This trait is automatically implemented for all
CreateRequestcreate context values. - Create
Context Data Response Value - This trait is automatically implemented for all
CreateResponsecreate context values.