CreateContextRequestData

Enum CreateContextRequestData 

pub enum CreateContextRequestData {
Show 14 variants ExtaRequest(ChainedItemList<FileFullEaInformation>), SecdRequest(SecurityDescriptor), DhnqRequest(DurableHandleRequest), DhncRequest(DurableHandleReconnect), AlsiRequest(AllocationSize), MxacRequest(QueryMaximalAccessRequest), TwrpRequest(TimewarpToken), QfidRequest(QueryOnDiskIdReq), RqlsRequest(RequestLease), Dh2qRequest(DurableHandleRequestV2), Dh2cRequest(DurableHandleReconnectV2), AppinstidRequest(AppInstanceId), AppinstverRequest(AppInstanceVersion), SvhdxopendevRequest(SvhdxOpenDeviceContext),
}
The CreateRequest Context data enum.

Variants



ExtaRequest(ChainedItemList<FileFullEaInformation>)



SecdRequest(SecurityDescriptor)



DhnqRequest(DurableHandleRequest)



DhncRequest(DurableHandleReconnect)



AlsiRequest(AllocationSize)



MxacRequest(QueryMaximalAccessRequest)



TwrpRequest(TimewarpToken)



QfidRequest(QueryOnDiskIdReq)



RqlsRequest(RequestLease)



Dh2qRequest(DurableHandleRequestV2)



Dh2cRequest(DurableHandleReconnectV2)



AppinstidRequest(AppInstanceId)



AppinstverRequest(AppInstanceVersion)



SvhdxopendevRequest(SvhdxOpenDeviceContext)

Implementations

Source

impl CreateContextRequestData

pub fn name(&self) -> &'static [u8]

pub fn as_exta(&self) -> Option<&ChainedItemList<FileFullEaInformation>>

pub fn first_exta( val: &[CreateContextRequest], ) -> Option<&ChainedItemList<FileFullEaInformation>>

Get the first exta create context from the list, if any.

Note: this function is auto-generated by the make_create_context! macro.

pub fn as_secd(&self) -> Option<&SecurityDescriptor>

pub fn first_secd(val: &[CreateContextRequest]) -> Option<&SecurityDescriptor>

Get the first secd create context from the list, if any.

Note: this function is auto-generated by the make_create_context! macro.

pub fn as_dhnq(&self) -> Option<&DurableHandleRequest>

pub fn first_dhnq(val: &[CreateContextRequest]) -> Option<&DurableHandleRequest>

Get the first dhnq create context from the list, if any.

Note: this function is auto-generated by the make_create_context! macro.

pub fn as_dhnc(&self) -> Option<&DurableHandleReconnect>

pub fn first_dhnc( val: &[CreateContextRequest], ) -> Option<&DurableHandleReconnect>

Get the first dhnc create context from the list, if any.

Note: this function is auto-generated by the make_create_context! macro.

pub fn as_alsi(&self) -> Option<&AllocationSize>

pub fn first_alsi(val: &[CreateContextRequest]) -> Option<&AllocationSize>

Get the first alsi create context from the list, if any.

Note: this function is auto-generated by the make_create_context! macro.

pub fn as_mxac(&self) -> Option<&QueryMaximalAccessRequest>

pub fn first_mxac( val: &[CreateContextRequest], ) -> Option<&QueryMaximalAccessRequest>

Get the first mxac create context from the list, if any.

Note: this function is auto-generated by the make_create_context! macro.

pub fn as_twrp(&self) -> Option<&TimewarpToken>

pub fn first_twrp(val: &[CreateContextRequest]) -> Option<&TimewarpToken>

Get the first twrp create context from the list, if any.

Note: this function is auto-generated by the make_create_context! macro.

pub fn as_qfid(&self) -> Option<&QueryOnDiskIdReq>

pub fn first_qfid(val: &[CreateContextRequest]) -> Option<&QueryOnDiskIdReq>

Get the first qfid create context from the list, if any.

Note: this function is auto-generated by the make_create_context! macro.

pub fn as_rqls(&self) -> Option<&RequestLease>

pub fn first_rqls(val: &[CreateContextRequest]) -> Option<&RequestLease>

Get the first rqls create context from the list, if any.

Note: this function is auto-generated by the make_create_context! macro.

pub fn as_dh2q(&self) -> Option<&DurableHandleRequestV2>

pub fn first_dh2q( val: &[CreateContextRequest], ) -> Option<&DurableHandleRequestV2>

Get the first dh2q create context from the list, if any.

Note: this function is auto-generated by the make_create_context! macro.

pub fn as_dh2c(&self) -> Option<&DurableHandleReconnectV2>

pub fn first_dh2c( val: &[CreateContextRequest], ) -> Option<&DurableHandleReconnectV2>

Get the first dh2c create context from the list, if any.

Note: this function is auto-generated by the make_create_context! macro.

pub fn as_appinstid(&self) -> Option<&AppInstanceId>

pub fn first_appinstid(val: &[CreateContextRequest]) -> Option<&AppInstanceId>

Get the first appinstid create context from the list, if any.

Note: this function is auto-generated by the make_create_context! macro.

pub fn as_appinstver(&self) -> Option<&AppInstanceVersion>

pub fn first_appinstver( val: &[CreateContextRequest], ) -> Option<&AppInstanceVersion>

Get the first appinstver create context from the list, if any.

Note: this function is auto-generated by the make_create_context! macro.

pub fn as_svhdxopendev(&self) -> Option<&SvhdxOpenDeviceContext>

pub fn first_svhdxopendev( val: &[CreateContextRequest], ) -> Option<&SvhdxOpenDeviceContext>

Get the first svhdxopendev create context from the list, if any.

Note: this function is auto-generated by the make_create_context! macro.