pub enum CreateContextResponseData {
DhnqResponse(DurableHandleResponse),
MxacResponse(QueryMaximalAccessResponse),
QfidResponse(QueryOnDiskIdResp),
RqlsResponse(RequestLease),
Dh2qResponse(DH2QResp),
AppinstidResponse(AppInstanceId),
AppinstverResponse(AppInstanceVersion),
SvhdxopendevResponse(SvhdxOpenDeviceContext),
}Expand description
The CreateResponse Context data enum.
Variants
DhnqResponse(DurableHandleResponse)
MxacResponse(QueryMaximalAccessResponse)
QfidResponse(QueryOnDiskIdResp)
RqlsResponse(RequestLease)
Dh2qResponse(DH2QResp)
AppinstidResponse(AppInstanceId)
AppinstverResponse(AppInstanceVersion)
SvhdxopendevResponse(SvhdxOpenDeviceContext)
Implementations
Sourceimpl CreateContextResponseData
impl CreateContextResponseData
pub fn name(&self) -> &'static [u8] ⓘ
pub fn as_dhnq(&self) -> Option<&DurableHandleResponse>
Sourcepub fn first_dhnq(
val: &[CreateContextResponse],
) -> Option<&DurableHandleResponse>
pub fn first_dhnq( val: &[CreateContextResponse], ) -> Option<&DurableHandleResponse>
Get the first dhnq create context from the list, if any.
Note: this function is auto-generated by the make_create_context! macro.
pub fn as_mxac(&self) -> Option<&QueryMaximalAccessResponse>
Sourcepub fn first_mxac(
val: &[CreateContextResponse],
) -> Option<&QueryMaximalAccessResponse>
pub fn first_mxac( val: &[CreateContextResponse], ) -> Option<&QueryMaximalAccessResponse>
Get the first mxac create context from the list, if any.
Note: this function is auto-generated by the make_create_context! macro.
pub fn as_qfid(&self) -> Option<&QueryOnDiskIdResp>
Sourcepub fn first_qfid(val: &[CreateContextResponse]) -> Option<&QueryOnDiskIdResp>
pub fn first_qfid(val: &[CreateContextResponse]) -> Option<&QueryOnDiskIdResp>
Get the first qfid create context from the list, if any.
Note: this function is auto-generated by the make_create_context! macro.
pub fn as_rqls(&self) -> Option<&RequestLease>
Sourcepub fn first_rqls(val: &[CreateContextResponse]) -> Option<&RequestLease>
pub fn first_rqls(val: &[CreateContextResponse]) -> Option<&RequestLease>
Get the first rqls create context from the list, if any.
Note: this function is auto-generated by the make_create_context! macro.
pub fn as_dh2q(&self) -> Option<&DH2QResp>
Sourcepub fn first_dh2q(val: &[CreateContextResponse]) -> Option<&DH2QResp>
pub fn first_dh2q(val: &[CreateContextResponse]) -> Option<&DH2QResp>
Get the first dh2q create context from the list, if any.
Note: this function is auto-generated by the make_create_context! macro.
pub fn as_appinstid(&self) -> Option<&AppInstanceId>
Sourcepub fn first_appinstid(val: &[CreateContextResponse]) -> Option<&AppInstanceId>
pub fn first_appinstid(val: &[CreateContextResponse]) -> Option<&AppInstanceId>
Get the first appinstid create context from the list, if any.
Note: this function is auto-generated by the make_create_context! macro.
pub fn as_appinstver(&self) -> Option<&AppInstanceVersion>
Sourcepub fn first_appinstver(
val: &[CreateContextResponse],
) -> Option<&AppInstanceVersion>
pub fn first_appinstver( val: &[CreateContextResponse], ) -> Option<&AppInstanceVersion>
Get the first appinstver create context from the list, if any.
Note: this function is auto-generated by the make_create_context! macro.
pub fn as_svhdxopendev(&self) -> Option<&SvhdxOpenDeviceContext>
Sourcepub fn first_svhdxopendev(
val: &[CreateContextResponse],
) -> Option<&SvhdxOpenDeviceContext>
pub fn first_svhdxopendev( val: &[CreateContextResponse], ) -> Option<&SvhdxOpenDeviceContext>
Get the first svhdxopendev create context from the list, if any.
Note: this function is auto-generated by the make_create_context! macro.