pub enum CreateContextType {
Show 14 variants
EXTA,
SECD,
DHNQ,
DHNC,
ALSI,
MXAC,
TWRP,
QFID,
RQLS,
DH2Q,
DH2C,
APPINSTID,
APPINSTVER,
SVHDXOPENDEV,
}Expand description
This enum contains all the types of create contexts.
Variants
EXTA
The data contains the extended attributes that MUST be stored on the created file.
SECD
The data contains a security descriptor that MUST be stored on the created file.
DHNQ
The client is requesting the open to be durable
DHNC
The client is requesting to reconnect to a durable open after being disconnected
ALSI
The data contains the required allocation size of the newly created file.
MXAC
The client is requesting that the server return maximal access information.
TWRP
The client is requesting that the server open an earlier version of the file identified by the provided time stamp.
QFID
The client is requesting that the server return a 32-byte opaque BLOB that uniquely identifies the file being opened on disk.
RQLS
The client is requesting that the server return a lease. This value is only supported for the SMB 2.1 and 3.x dialect family.
DH2Q
The client is requesting the open to be durable. This value is only supported for the SMB 3.x dialect family.
DH2C
The client is requesting to reconnect to a durable open after being disconnected. This value is only supported for the SMB 3.x dialect family.
APPINSTID
The client is supplying an identifier provided by an application instance while opening a file. This value is only supported for the SMB 3.x dialect family.
APPINSTVER
The client is supplying a version to correspond to the application instance identifier. This value is only supported for SMB 3.1.1 dialect.
SVHDXOPENDEV
Provided by an application while opening a shared virtual disk file. This Create Context value is not valid for the SMB 2.002, SMB 2.1, and SMB 3.0 dialects
Implementations
Sourceimpl CreateContextType
impl CreateContextType
Sourcepub const APPINSTID_NAME: &[u8] = b"\x45\xBC\xA6\x6A\xEF\xA7\xF7\x4A\x90\x08\xFA\x46\x2E\x14\x4D\x74"
pub const APPINSTID_NAME: &[u8] = b"\x45\xBC\xA6\x6A\xEF\xA7\xF7\x4A\x90\x08\xFA\x46\x2E\x14\x4D\x74"
The name for the appinstid create context.
Sourcepub const APPINSTVER_NAME: &[u8] = b"\xB9\x82\xD0\xB7\x3B\x56\x07\x4F\xA0\x7B\x52\x4A\x81\x16\xA0\x10"
pub const APPINSTVER_NAME: &[u8] = b"\xB9\x82\xD0\xB7\x3B\x56\x07\x4F\xA0\x7B\x52\x4A\x81\x16\xA0\x10"
The name for the appinstver create context.
Sourcepub const SVHDXOPENDEV_NAME: &[u8] = b"\x9C\xCB\xCF\x9E\x04\xC1\xE6\x43\x98\x0E\x15\x8D\xA1\xF6\xEC\x83"
pub const SVHDXOPENDEV_NAME: &[u8] = b"\x9C\xCB\xCF\x9E\x04\xC1\xE6\x43\x98\x0E\x15\x8D\xA1\xF6\xEC\x83"
The name for the svhdxopendev create context.