pub struct CloseFlags { /* private fields */ }Expand description
Flags indicating how to process the CLOSE operation.
Reference: MS-SMB2 2.2.15, 2.2.16
Implementations
Sourceimpl CloseFlags
impl CloseFlags
Sourceimpl CloseFlags
impl CloseFlags
Sourcepub const fn into_bytes(self) -> [u8; 2]
pub const fn into_bytes(self) -> [u8; 2]
Sourcepub const fn from_bytes(bytes: [u8; 2]) -> Self
pub const fn from_bytes(bytes: [u8; 2]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl CloseFlags
impl CloseFlags
Sourcepub fn postquery_attrib(&self) -> <bool as Specifier>::InOut
pub fn postquery_attrib(&self) -> <bool as Specifier>::InOut
Returns the value of postquery_attrib. If set in request, the server MUST set the attribute fields in the response to valid values. If set in response, the client MUST use the attribute fields that are returned.
Sourcepub fn postquery_attrib_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn postquery_attrib_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of postquery_attrib.
#Errors
If the returned value contains an invalid bit pattern for postquery_attrib. If set in request, the server MUST set the attribute fields in the response to valid values. If set in response, the client MUST use the attribute fields that are returned.
Sourcepub fn with_postquery_attrib(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_postquery_attrib(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of postquery_attrib set to the given value.
#Panics
If the given value is out of bounds for postquery_attrib. If set in request, the server MUST set the attribute fields in the response to valid values. If set in response, the client MUST use the attribute fields that are returned.
Sourcepub fn with_postquery_attrib_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_postquery_attrib_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of postquery_attrib set to the given value.
#Errors
If the given value is out of bounds for postquery_attrib. If set in request, the server MUST set the attribute fields in the response to valid values. If set in response, the client MUST use the attribute fields that are returned.
Sourcepub fn set_postquery_attrib(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_postquery_attrib(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of postquery_attrib to the given value.
#Panics
If the given value is out of bounds for postquery_attrib. If set in request, the server MUST set the attribute fields in the response to valid values. If set in response, the client MUST use the attribute fields that are returned.
Sourcepub fn set_postquery_attrib_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_postquery_attrib_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of postquery_attrib to the given value.
#Errors
If the given value is out of bounds for postquery_attrib. If set in request, the server MUST set the attribute fields in the response to valid values. If set in response, the client MUST use the attribute fields that are returned.