CloseRequest

Struct CloseRequest 

pub struct CloseRequest {
    pub file_id: FileId,
}
The SMB2 CLOSE Request packet is used by the client to close an instance of a file that was opened previously with a successful SMB2 CREATE Request.

Reference: MS-SMB2 2.2.15

Fields

file_id: FileId

The identifier of the open to a file or named pipe that is being closed