CreateOptions

Struct CreateOptions 

pub struct CreateOptions { /* private fields */ }
Options to be applied when creating or opening the file.

Reference: MS-SMB2 2.2.13

Implementations

Source

impl CreateOptions

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl CreateOptions

pub const fn into_bytes(self) -> [u8; 4]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 4]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl CreateOptions

pub fn directory_file(&self) -> <bool as Specifier>::InOut

Returns the value of directory_file. The file being created or opened is a directory file

pub fn directory_file_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of directory_file.

#Errors

If the returned value contains an invalid bit pattern for directory_file. The file being created or opened is a directory file

pub fn with_directory_file(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of directory_file set to the given value.

#Panics

If the given value is out of bounds for directory_file. The file being created or opened is a directory file

pub fn with_directory_file_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of directory_file set to the given value.

#Errors

If the given value is out of bounds for directory_file. The file being created or opened is a directory file

pub fn set_directory_file(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of directory_file to the given value.

#Panics

If the given value is out of bounds for directory_file. The file being created or opened is a directory file

pub fn set_directory_file_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of directory_file to the given value.

#Errors

If the given value is out of bounds for directory_file. The file being created or opened is a directory file

pub fn write_through(&self) -> <bool as Specifier>::InOut

Returns the value of write_through. The server performs file write-through

pub fn write_through_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of write_through.

#Errors

If the returned value contains an invalid bit pattern for write_through. The server performs file write-through

pub fn with_write_through(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of write_through set to the given value.

#Panics

If the given value is out of bounds for write_through. The server performs file write-through

pub fn with_write_through_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of write_through set to the given value.

#Errors

If the given value is out of bounds for write_through. The server performs file write-through

pub fn set_write_through(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of write_through to the given value.

#Panics

If the given value is out of bounds for write_through. The server performs file write-through

pub fn set_write_through_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of write_through to the given value.

#Errors

If the given value is out of bounds for write_through. The server performs file write-through

pub fn sequential_only(&self) -> <bool as Specifier>::InOut

Returns the value of sequential_only. Application intends to read or write at sequential offsets

pub fn sequential_only_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of sequential_only.

#Errors

If the returned value contains an invalid bit pattern for sequential_only. Application intends to read or write at sequential offsets

pub fn with_sequential_only(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of sequential_only set to the given value.

#Panics

If the given value is out of bounds for sequential_only. Application intends to read or write at sequential offsets

pub fn with_sequential_only_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of sequential_only set to the given value.

#Errors

If the given value is out of bounds for sequential_only. Application intends to read or write at sequential offsets

pub fn set_sequential_only(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of sequential_only to the given value.

#Panics

If the given value is out of bounds for sequential_only. Application intends to read or write at sequential offsets

pub fn set_sequential_only_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of sequential_only to the given value.

#Errors

If the given value is out of bounds for sequential_only. Application intends to read or write at sequential offsets

pub fn no_intermediate_buffering(&self) -> <bool as Specifier>::InOut

Returns the value of no_intermediate_buffering. File buffering is not performed on this open

pub fn no_intermediate_buffering_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of no_intermediate_buffering.

#Errors

If the returned value contains an invalid bit pattern for no_intermediate_buffering. File buffering is not performed on this open

pub fn with_no_intermediate_buffering( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of no_intermediate_buffering set to the given value.

#Panics

If the given value is out of bounds for no_intermediate_buffering. File buffering is not performed on this open

pub fn with_no_intermediate_buffering_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of no_intermediate_buffering set to the given value.

#Errors

If the given value is out of bounds for no_intermediate_buffering. File buffering is not performed on this open

pub fn set_no_intermediate_buffering( &mut self, new_val: <bool as Specifier>::InOut, )

Sets the value of no_intermediate_buffering to the given value.

#Panics

If the given value is out of bounds for no_intermediate_buffering. File buffering is not performed on this open

pub fn set_no_intermediate_buffering_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of no_intermediate_buffering to the given value.

#Errors

If the given value is out of bounds for no_intermediate_buffering. File buffering is not performed on this open

pub fn synchronous_io_alert(&self) -> <bool as Specifier>::InOut

Returns the value of synchronous_io_alert. Should be set to 0 and is ignored by the server

pub fn synchronous_io_alert_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of synchronous_io_alert.

#Errors

If the returned value contains an invalid bit pattern for synchronous_io_alert. Should be set to 0 and is ignored by the server

pub fn with_synchronous_io_alert( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of synchronous_io_alert set to the given value.

#Panics

If the given value is out of bounds for synchronous_io_alert. Should be set to 0 and is ignored by the server

pub fn with_synchronous_io_alert_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of synchronous_io_alert set to the given value.

#Errors

If the given value is out of bounds for synchronous_io_alert. Should be set to 0 and is ignored by the server

pub fn set_synchronous_io_alert(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of synchronous_io_alert to the given value.

#Panics

If the given value is out of bounds for synchronous_io_alert. Should be set to 0 and is ignored by the server

pub fn set_synchronous_io_alert_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of synchronous_io_alert to the given value.

#Errors

If the given value is out of bounds for synchronous_io_alert. Should be set to 0 and is ignored by the server

pub fn synchronous_io_nonalert(&self) -> <bool as Specifier>::InOut

Returns the value of synchronous_io_nonalert. Should be set to 0 and is ignored by the server

pub fn synchronous_io_nonalert_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of synchronous_io_nonalert.

#Errors

If the returned value contains an invalid bit pattern for synchronous_io_nonalert. Should be set to 0 and is ignored by the server

pub fn with_synchronous_io_nonalert( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of synchronous_io_nonalert set to the given value.

#Panics

If the given value is out of bounds for synchronous_io_nonalert. Should be set to 0 and is ignored by the server

pub fn with_synchronous_io_nonalert_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of synchronous_io_nonalert set to the given value.

#Errors

If the given value is out of bounds for synchronous_io_nonalert. Should be set to 0 and is ignored by the server

pub fn set_synchronous_io_nonalert( &mut self, new_val: <bool as Specifier>::InOut, )

Sets the value of synchronous_io_nonalert to the given value.

#Panics

If the given value is out of bounds for synchronous_io_nonalert. Should be set to 0 and is ignored by the server

pub fn set_synchronous_io_nonalert_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of synchronous_io_nonalert to the given value.

#Errors

If the given value is out of bounds for synchronous_io_nonalert. Should be set to 0 and is ignored by the server

pub fn non_directory_file(&self) -> <bool as Specifier>::InOut

Returns the value of non_directory_file. If the name matches an existing directory file, the server must fail the request

pub fn non_directory_file_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of non_directory_file.

#Errors

If the returned value contains an invalid bit pattern for non_directory_file. If the name matches an existing directory file, the server must fail the request

pub fn with_non_directory_file( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of non_directory_file set to the given value.

#Panics

If the given value is out of bounds for non_directory_file. If the name matches an existing directory file, the server must fail the request

pub fn with_non_directory_file_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of non_directory_file set to the given value.

#Errors

If the given value is out of bounds for non_directory_file. If the name matches an existing directory file, the server must fail the request

pub fn set_non_directory_file(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of non_directory_file to the given value.

#Panics

If the given value is out of bounds for non_directory_file. If the name matches an existing directory file, the server must fail the request

pub fn set_non_directory_file_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of non_directory_file to the given value.

#Errors

If the given value is out of bounds for non_directory_file. If the name matches an existing directory file, the server must fail the request

pub fn complete_if_oplocked(&self) -> <bool as Specifier>::InOut

Returns the value of complete_if_oplocked. Should be set to 0 and is ignored by the server

pub fn complete_if_oplocked_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of complete_if_oplocked.

#Errors

If the returned value contains an invalid bit pattern for complete_if_oplocked. Should be set to 0 and is ignored by the server

pub fn with_complete_if_oplocked( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of complete_if_oplocked set to the given value.

#Panics

If the given value is out of bounds for complete_if_oplocked. Should be set to 0 and is ignored by the server

pub fn with_complete_if_oplocked_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of complete_if_oplocked set to the given value.

#Errors

If the given value is out of bounds for complete_if_oplocked. Should be set to 0 and is ignored by the server

pub fn set_complete_if_oplocked(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of complete_if_oplocked to the given value.

#Panics

If the given value is out of bounds for complete_if_oplocked. Should be set to 0 and is ignored by the server

pub fn set_complete_if_oplocked_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of complete_if_oplocked to the given value.

#Errors

If the given value is out of bounds for complete_if_oplocked. Should be set to 0 and is ignored by the server

pub fn no_ea_knowledge(&self) -> <bool as Specifier>::InOut

Returns the value of no_ea_knowledge. The caller does not understand how to handle extended attributes

pub fn no_ea_knowledge_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of no_ea_knowledge.

#Errors

If the returned value contains an invalid bit pattern for no_ea_knowledge. The caller does not understand how to handle extended attributes

pub fn with_no_ea_knowledge(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of no_ea_knowledge set to the given value.

#Panics

If the given value is out of bounds for no_ea_knowledge. The caller does not understand how to handle extended attributes

pub fn with_no_ea_knowledge_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of no_ea_knowledge set to the given value.

#Errors

If the given value is out of bounds for no_ea_knowledge. The caller does not understand how to handle extended attributes

pub fn set_no_ea_knowledge(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of no_ea_knowledge to the given value.

#Panics

If the given value is out of bounds for no_ea_knowledge. The caller does not understand how to handle extended attributes

pub fn set_no_ea_knowledge_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of no_ea_knowledge to the given value.

#Errors

If the given value is out of bounds for no_ea_knowledge. The caller does not understand how to handle extended attributes

pub fn open_remote_instance(&self) -> <bool as Specifier>::InOut

Returns the value of open_remote_instance. Should be set to 0 and is ignored by the server

pub fn open_remote_instance_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of open_remote_instance.

#Errors

If the returned value contains an invalid bit pattern for open_remote_instance. Should be set to 0 and is ignored by the server

pub fn with_open_remote_instance( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of open_remote_instance set to the given value.

#Panics

If the given value is out of bounds for open_remote_instance. Should be set to 0 and is ignored by the server

pub fn with_open_remote_instance_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of open_remote_instance set to the given value.

#Errors

If the given value is out of bounds for open_remote_instance. Should be set to 0 and is ignored by the server

pub fn set_open_remote_instance(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of open_remote_instance to the given value.

#Panics

If the given value is out of bounds for open_remote_instance. Should be set to 0 and is ignored by the server

pub fn set_open_remote_instance_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of open_remote_instance to the given value.

#Errors

If the given value is out of bounds for open_remote_instance. Should be set to 0 and is ignored by the server

pub fn random_access(&self) -> <bool as Specifier>::InOut

Returns the value of random_access. Application intends to read or write at random offsets

pub fn random_access_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of random_access.

#Errors

If the returned value contains an invalid bit pattern for random_access. Application intends to read or write at random offsets

pub fn with_random_access(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of random_access set to the given value.

#Panics

If the given value is out of bounds for random_access. Application intends to read or write at random offsets

pub fn with_random_access_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of random_access set to the given value.

#Errors

If the given value is out of bounds for random_access. Application intends to read or write at random offsets

pub fn set_random_access(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of random_access to the given value.

#Panics

If the given value is out of bounds for random_access. Application intends to read or write at random offsets

pub fn set_random_access_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of random_access to the given value.

#Errors

If the given value is out of bounds for random_access. Application intends to read or write at random offsets

pub fn delete_on_close(&self) -> <bool as Specifier>::InOut

Returns the value of delete_on_close. The file must be automatically deleted when the last open request is closed

pub fn delete_on_close_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of delete_on_close.

#Errors

If the returned value contains an invalid bit pattern for delete_on_close. The file must be automatically deleted when the last open request is closed

pub fn with_delete_on_close(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of delete_on_close set to the given value.

#Panics

If the given value is out of bounds for delete_on_close. The file must be automatically deleted when the last open request is closed

pub fn with_delete_on_close_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of delete_on_close set to the given value.

#Errors

If the given value is out of bounds for delete_on_close. The file must be automatically deleted when the last open request is closed

pub fn set_delete_on_close(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of delete_on_close to the given value.

#Panics

If the given value is out of bounds for delete_on_close. The file must be automatically deleted when the last open request is closed

pub fn set_delete_on_close_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of delete_on_close to the given value.

#Errors

If the given value is out of bounds for delete_on_close. The file must be automatically deleted when the last open request is closed

pub fn open_by_file_id(&self) -> <bool as Specifier>::InOut

Returns the value of open_by_file_id. Should be set to 0 and the server must fail the request if set

pub fn open_by_file_id_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of open_by_file_id.

#Errors

If the returned value contains an invalid bit pattern for open_by_file_id. Should be set to 0 and the server must fail the request if set

pub fn with_open_by_file_id(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of open_by_file_id set to the given value.

#Panics

If the given value is out of bounds for open_by_file_id. Should be set to 0 and the server must fail the request if set

pub fn with_open_by_file_id_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of open_by_file_id set to the given value.

#Errors

If the given value is out of bounds for open_by_file_id. Should be set to 0 and the server must fail the request if set

pub fn set_open_by_file_id(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of open_by_file_id to the given value.

#Panics

If the given value is out of bounds for open_by_file_id. Should be set to 0 and the server must fail the request if set

pub fn set_open_by_file_id_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of open_by_file_id to the given value.

#Errors

If the given value is out of bounds for open_by_file_id. Should be set to 0 and the server must fail the request if set

pub fn open_for_backup_intent(&self) -> <bool as Specifier>::InOut

Returns the value of open_for_backup_intent. The file is being opened for backup intent

pub fn open_for_backup_intent_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of open_for_backup_intent.

#Errors

If the returned value contains an invalid bit pattern for open_for_backup_intent. The file is being opened for backup intent

pub fn with_open_for_backup_intent( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of open_for_backup_intent set to the given value.

#Panics

If the given value is out of bounds for open_for_backup_intent. The file is being opened for backup intent

pub fn with_open_for_backup_intent_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of open_for_backup_intent set to the given value.

#Errors

If the given value is out of bounds for open_for_backup_intent. The file is being opened for backup intent

pub fn set_open_for_backup_intent( &mut self, new_val: <bool as Specifier>::InOut, )

Sets the value of open_for_backup_intent to the given value.

#Panics

If the given value is out of bounds for open_for_backup_intent. The file is being opened for backup intent

pub fn set_open_for_backup_intent_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of open_for_backup_intent to the given value.

#Errors

If the given value is out of bounds for open_for_backup_intent. The file is being opened for backup intent

pub fn no_compression(&self) -> <bool as Specifier>::InOut

Returns the value of no_compression. The file cannot be compressed

pub fn no_compression_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of no_compression.

#Errors

If the returned value contains an invalid bit pattern for no_compression. The file cannot be compressed

pub fn with_no_compression(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of no_compression set to the given value.

#Panics

If the given value is out of bounds for no_compression. The file cannot be compressed

pub fn with_no_compression_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of no_compression set to the given value.

#Errors

If the given value is out of bounds for no_compression. The file cannot be compressed

pub fn set_no_compression(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of no_compression to the given value.

#Panics

If the given value is out of bounds for no_compression. The file cannot be compressed

pub fn set_no_compression_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of no_compression to the given value.

#Errors

If the given value is out of bounds for no_compression. The file cannot be compressed

pub fn open_requiring_oplock(&self) -> <bool as Specifier>::InOut

Returns the value of open_requiring_oplock. Should be set to 0 and is ignored by the server

pub fn open_requiring_oplock_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of open_requiring_oplock.

#Errors

If the returned value contains an invalid bit pattern for open_requiring_oplock. Should be set to 0 and is ignored by the server

pub fn with_open_requiring_oplock( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of open_requiring_oplock set to the given value.

#Panics

If the given value is out of bounds for open_requiring_oplock. Should be set to 0 and is ignored by the server

pub fn with_open_requiring_oplock_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of open_requiring_oplock set to the given value.

#Errors

If the given value is out of bounds for open_requiring_oplock. Should be set to 0 and is ignored by the server

pub fn set_open_requiring_oplock(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of open_requiring_oplock to the given value.

#Panics

If the given value is out of bounds for open_requiring_oplock. Should be set to 0 and is ignored by the server

pub fn set_open_requiring_oplock_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of open_requiring_oplock to the given value.

#Errors

If the given value is out of bounds for open_requiring_oplock. Should be set to 0 and is ignored by the server

pub fn disallow_exclusive(&self) -> <bool as Specifier>::InOut

Returns the value of disallow_exclusive. Should be set to 0 and is ignored by the server

pub fn disallow_exclusive_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of disallow_exclusive.

#Errors

If the returned value contains an invalid bit pattern for disallow_exclusive. Should be set to 0 and is ignored by the server

pub fn with_disallow_exclusive( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of disallow_exclusive set to the given value.

#Panics

If the given value is out of bounds for disallow_exclusive. Should be set to 0 and is ignored by the server

pub fn with_disallow_exclusive_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of disallow_exclusive set to the given value.

#Errors

If the given value is out of bounds for disallow_exclusive. Should be set to 0 and is ignored by the server

pub fn set_disallow_exclusive(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of disallow_exclusive to the given value.

#Panics

If the given value is out of bounds for disallow_exclusive. Should be set to 0 and is ignored by the server

pub fn set_disallow_exclusive_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of disallow_exclusive to the given value.

#Errors

If the given value is out of bounds for disallow_exclusive. Should be set to 0 and is ignored by the server

pub fn reserve_opfilter(&self) -> <bool as Specifier>::InOut

Returns the value of reserve_opfilter. Should be set to 0 and the server must fail the request if set

pub fn reserve_opfilter_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of reserve_opfilter.

#Errors

If the returned value contains an invalid bit pattern for reserve_opfilter. Should be set to 0 and the server must fail the request if set

pub fn with_reserve_opfilter(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of reserve_opfilter set to the given value.

#Panics

If the given value is out of bounds for reserve_opfilter. Should be set to 0 and the server must fail the request if set

pub fn with_reserve_opfilter_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of reserve_opfilter set to the given value.

#Errors

If the given value is out of bounds for reserve_opfilter. Should be set to 0 and the server must fail the request if set

pub fn set_reserve_opfilter(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of reserve_opfilter to the given value.

#Panics

If the given value is out of bounds for reserve_opfilter. Should be set to 0 and the server must fail the request if set

pub fn set_reserve_opfilter_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of reserve_opfilter to the given value.

#Errors

If the given value is out of bounds for reserve_opfilter. Should be set to 0 and the server must fail the request if set

pub fn open_reparse_point(&self) -> <bool as Specifier>::InOut

Returns the value of open_reparse_point. If the file is a reparse point, open the reparse point itself

pub fn open_reparse_point_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of open_reparse_point.

#Errors

If the returned value contains an invalid bit pattern for open_reparse_point. If the file is a reparse point, open the reparse point itself

pub fn with_open_reparse_point( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of open_reparse_point set to the given value.

#Panics

If the given value is out of bounds for open_reparse_point. If the file is a reparse point, open the reparse point itself

pub fn with_open_reparse_point_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of open_reparse_point set to the given value.

#Errors

If the given value is out of bounds for open_reparse_point. If the file is a reparse point, open the reparse point itself

pub fn set_open_reparse_point(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of open_reparse_point to the given value.

#Panics

If the given value is out of bounds for open_reparse_point. If the file is a reparse point, open the reparse point itself

pub fn set_open_reparse_point_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of open_reparse_point to the given value.

#Errors

If the given value is out of bounds for open_reparse_point. If the file is a reparse point, open the reparse point itself

pub fn open_no_recall(&self) -> <bool as Specifier>::InOut

Returns the value of open_no_recall. In HSM environment, the file should not be recalled from tertiary storage

pub fn open_no_recall_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of open_no_recall.

#Errors

If the returned value contains an invalid bit pattern for open_no_recall. In HSM environment, the file should not be recalled from tertiary storage

pub fn with_open_no_recall(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of open_no_recall set to the given value.

#Panics

If the given value is out of bounds for open_no_recall. In HSM environment, the file should not be recalled from tertiary storage

pub fn with_open_no_recall_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of open_no_recall set to the given value.

#Errors

If the given value is out of bounds for open_no_recall. In HSM environment, the file should not be recalled from tertiary storage

pub fn set_open_no_recall(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of open_no_recall to the given value.

#Panics

If the given value is out of bounds for open_no_recall. In HSM environment, the file should not be recalled from tertiary storage

pub fn set_open_no_recall_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of open_no_recall to the given value.

#Errors

If the given value is out of bounds for open_no_recall. In HSM environment, the file should not be recalled from tertiary storage

pub fn open_for_free_space_query(&self) -> <bool as Specifier>::InOut

Returns the value of open_for_free_space_query. Open file to query for free space

pub fn open_for_free_space_query_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of open_for_free_space_query.

#Errors

If the returned value contains an invalid bit pattern for open_for_free_space_query. Open file to query for free space

pub fn with_open_for_free_space_query( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of open_for_free_space_query set to the given value.

#Panics

If the given value is out of bounds for open_for_free_space_query. Open file to query for free space

pub fn with_open_for_free_space_query_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of open_for_free_space_query set to the given value.

#Errors

If the given value is out of bounds for open_for_free_space_query. Open file to query for free space

pub fn set_open_for_free_space_query( &mut self, new_val: <bool as Specifier>::InOut, )

Sets the value of open_for_free_space_query to the given value.

#Panics

If the given value is out of bounds for open_for_free_space_query. Open file to query for free space

pub fn set_open_for_free_space_query_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of open_for_free_space_query to the given value.

#Errors

If the given value is out of bounds for open_for_free_space_query. Open file to query for free space