pub struct CreateResponseFlags { /* private fields */ }Implementations
Sourceimpl CreateResponseFlags
impl CreateResponseFlags
Sourcepub const fn into_bytes(self) -> [u8; 1]
pub const fn into_bytes(self) -> [u8; 1]
Sourcepub const fn from_bytes(bytes: [u8; 1]) -> Self
pub const fn from_bytes(bytes: [u8; 1]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl CreateResponseFlags
impl CreateResponseFlags
Sourcepub fn reparsepoint(&self) -> <bool as Specifier>::InOut
pub fn reparsepoint(&self) -> <bool as Specifier>::InOut
Returns the value of reparsepoint.
Sourcepub fn reparsepoint_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn reparsepoint_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of reparsepoint.
#Errors
If the returned value contains an invalid bit pattern for reparsepoint.
Sourcepub fn with_reparsepoint(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_reparsepoint(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of reparsepoint set to the given value.
#Panics
If the given value is out of bounds for reparsepoint.
Sourcepub fn with_reparsepoint_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_reparsepoint_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of reparsepoint set to the given value.
#Errors
If the given value is out of bounds for reparsepoint.
Sourcepub fn set_reparsepoint(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_reparsepoint(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of reparsepoint to the given value.
#Panics
If the given value is out of bounds for reparsepoint.
Sourcepub fn set_reparsepoint_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_reparsepoint_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of reparsepoint to the given value.
#Errors
If the given value is out of bounds for reparsepoint.