pub struct ShareAccessFlags { /* private fields */ }Expand description
Specifies the sharing mode for the open.
Reference: MS-SMB2 2.2.13
Implementations
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourcepub fn read(&self) -> <bool as Specifier>::InOut
pub fn read(&self) -> <bool as Specifier>::InOut
Returns the value of read. Other opens are allowed to read this file while this open is present
Sourcepub fn read_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn read_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of read.
#Errors
If the returned value contains an invalid bit pattern for read. Other opens are allowed to read this file while this open is present
Sourcepub fn with_read(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_read(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of read set to the given value.
#Panics
If the given value is out of bounds for read. Other opens are allowed to read this file while this open is present
Sourcepub fn with_read_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_read_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of read set to the given value.
#Errors
If the given value is out of bounds for read. Other opens are allowed to read this file while this open is present
Sourcepub fn set_read(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_read(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of read to the given value.
#Panics
If the given value is out of bounds for read. Other opens are allowed to read this file while this open is present
Sourcepub fn set_read_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_read_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of read to the given value.
#Errors
If the given value is out of bounds for read. Other opens are allowed to read this file while this open is present
Sourcepub fn write(&self) -> <bool as Specifier>::InOut
pub fn write(&self) -> <bool as Specifier>::InOut
Returns the value of write. Other opens are allowed to write this file while this open is present
Sourcepub fn write_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn write_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of write.
#Errors
If the returned value contains an invalid bit pattern for write. Other opens are allowed to write this file while this open is present
Sourcepub fn with_write(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_write(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of write set to the given value.
#Panics
If the given value is out of bounds for write. Other opens are allowed to write this file while this open is present
Sourcepub fn with_write_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_write_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of write set to the given value.
#Errors
If the given value is out of bounds for write. Other opens are allowed to write this file while this open is present
Sourcepub fn set_write(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_write(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of write to the given value.
#Panics
If the given value is out of bounds for write. Other opens are allowed to write this file while this open is present
Sourcepub fn set_write_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_write_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of write to the given value.
#Errors
If the given value is out of bounds for write. Other opens are allowed to write this file while this open is present
Sourcepub fn delete(&self) -> <bool as Specifier>::InOut
pub fn delete(&self) -> <bool as Specifier>::InOut
Returns the value of delete. Other opens are allowed to delete or rename this file while this open is present
Sourcepub fn delete_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn delete_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of delete.
#Errors
If the returned value contains an invalid bit pattern for delete. Other opens are allowed to delete or rename this file while this open is present
Sourcepub fn with_delete(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_delete(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of delete set to the given value.
#Panics
If the given value is out of bounds for delete. Other opens are allowed to delete or rename this file while this open is present
Sourcepub fn with_delete_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_delete_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of delete set to the given value.
#Errors
If the given value is out of bounds for delete. Other opens are allowed to delete or rename this file while this open is present
Sourcepub fn set_delete(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_delete(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of delete to the given value.
#Panics
If the given value is out of bounds for delete. Other opens are allowed to delete or rename this file while this open is present
Sourcepub fn set_delete_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_delete_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of delete to the given value.
#Errors
If the given value is out of bounds for delete. Other opens are allowed to delete or rename this file while this open is present