ReferralHeaderFlags

Struct ReferralHeaderFlags 

pub struct ReferralHeaderFlags { /* private fields */ }

Implementations

Source

impl ReferralHeaderFlags

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl ReferralHeaderFlags

pub const fn into_bytes(self) -> [u8; 4]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 4]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl ReferralHeaderFlags

pub fn referral_servers(&self) -> <bool as Specifier>::InOut

Returns the value of referral_servers. Whether all of the targets in the referral entries returned are DFS root targets capable of handling DFS referral requests.

pub fn referral_servers_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of referral_servers.

#Errors

If the returned value contains an invalid bit pattern for referral_servers. Whether all of the targets in the referral entries returned are DFS root targets capable of handling DFS referral requests.

pub fn with_referral_servers(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of referral_servers set to the given value.

#Panics

If the given value is out of bounds for referral_servers. Whether all of the targets in the referral entries returned are DFS root targets capable of handling DFS referral requests.

pub fn with_referral_servers_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of referral_servers set to the given value.

#Errors

If the given value is out of bounds for referral_servers. Whether all of the targets in the referral entries returned are DFS root targets capable of handling DFS referral requests.

pub fn set_referral_servers(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of referral_servers to the given value.

#Panics

If the given value is out of bounds for referral_servers. Whether all of the targets in the referral entries returned are DFS root targets capable of handling DFS referral requests.

pub fn set_referral_servers_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of referral_servers to the given value.

#Errors

If the given value is out of bounds for referral_servers. Whether all of the targets in the referral entries returned are DFS root targets capable of handling DFS referral requests.

pub fn storage_servers(&self) -> <bool as Specifier>::InOut

Returns the value of storage_servers. Whether all of the targets in the referral response can be accessed without requiring further referral requests.

pub fn storage_servers_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of storage_servers.

#Errors

If the returned value contains an invalid bit pattern for storage_servers. Whether all of the targets in the referral response can be accessed without requiring further referral requests.

pub fn with_storage_servers(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of storage_servers set to the given value.

#Panics

If the given value is out of bounds for storage_servers. Whether all of the targets in the referral response can be accessed without requiring further referral requests.

pub fn with_storage_servers_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of storage_servers set to the given value.

#Errors

If the given value is out of bounds for storage_servers. Whether all of the targets in the referral response can be accessed without requiring further referral requests.

pub fn set_storage_servers(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of storage_servers to the given value.

#Panics

If the given value is out of bounds for storage_servers. Whether all of the targets in the referral response can be accessed without requiring further referral requests.

pub fn set_storage_servers_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of storage_servers to the given value.

#Errors

If the given value is out of bounds for storage_servers. Whether all of the targets in the referral response can be accessed without requiring further referral requests.

pub fn target_failbacl(&self) -> <bool as Specifier>::InOut

Returns the value of target_failbacl. Whether DFS client target failback is enabled for all targets in this referral response. This value used only in version 4.

pub fn target_failbacl_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of target_failbacl.

#Errors

If the returned value contains an invalid bit pattern for target_failbacl. Whether DFS client target failback is enabled for all targets in this referral response. This value used only in version 4.

pub fn with_target_failbacl(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of target_failbacl set to the given value.

#Panics

If the given value is out of bounds for target_failbacl. Whether DFS client target failback is enabled for all targets in this referral response. This value used only in version 4.

pub fn with_target_failbacl_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of target_failbacl set to the given value.

#Errors

If the given value is out of bounds for target_failbacl. Whether DFS client target failback is enabled for all targets in this referral response. This value used only in version 4.

pub fn set_target_failbacl(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of target_failbacl to the given value.

#Panics

If the given value is out of bounds for target_failbacl. Whether DFS client target failback is enabled for all targets in this referral response. This value used only in version 4.

pub fn set_target_failbacl_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of target_failbacl to the given value.

#Errors

If the given value is out of bounds for target_failbacl. Whether DFS client target failback is enabled for all targets in this referral response. This value used only in version 4.