pub struct ReqGetDfsReferralEx {
pub max_referral_level: u16,
pub request_flags: DfsRequestFlags,
pub request_data: DfsRequestData,
/* private fields */
}Fields
max_referral_level: u16An integer that indicates the highest DFS referral version understood by the client. The DFS referral versions specified by this document are 1 through 4 inclusive. A DFS client MUST support DFS referral version 1 through the version number set in this field. The referral response messages are referral version dependent and are specified in sections 2.2.5.1 through 2.2.5.4.
request_flags: DfsRequestFlagsrequest_data: DfsRequestDataTrait Implementations
Sourceimpl BinRead for ReqGetDfsReferralEx
impl BinRead for ReqGetDfsReferralEx
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl BinWrite for ReqGetDfsReferralEx
impl BinWrite for ReqGetDfsReferralEx
Sourcefn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<()>
fn write_options<W: Write + Seek>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<()>
Sourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming big-endian byte order. Read moreSourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming little-endian byte order. Read moreSourcefn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming native-endian byte order. Read moreSourcefn write_be_args<W>(
&self,
writer: &mut W,
args: Self::Args<'_>,
) -> Result<(), Error>
fn write_be_args<W>( &self, writer: &mut W, args: Self::Args<'_>, ) -> Result<(), Error>
Write
Self to the writer, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl Debug for ReqGetDfsReferralEx
impl Debug for ReqGetDfsReferralEx
Sourceimpl From<ReqGetDfsReferralEx> for IoctlReqData
impl From<ReqGetDfsReferralEx> for IoctlReqData
Sourcefn from(model: ReqGetDfsReferralEx) -> IoctlReqData
fn from(model: ReqGetDfsReferralEx) -> IoctlReqData
Converts to this type from the input type.
Sourceimpl FsctlRequest for ReqGetDfsReferralEx
impl FsctlRequest for ReqGetDfsReferralEx
const FSCTL_CODE: FsctlCodes = FsctlCodes::DfsGetReferralsEx
type Response = RespGetDfsReferral
Sourceimpl IoctlRequestContent for ReqGetDfsReferralEx
impl IoctlRequestContent for ReqGetDfsReferralEx
Sourcefn get_bin_size(&self) -> u32
fn get_bin_size(&self) -> u32
Returns the size of the buffer for IOCTL requests – the size of the ENCODED data, in bytes.
Sourceimpl PartialEq for ReqGetDfsReferralEx
impl PartialEq for ReqGetDfsReferralEx
impl Eq for ReqGetDfsReferralEx
impl StructuralPartialEq for ReqGetDfsReferralEx