Encrypted message and header implementation.
Structs
- Encrypted
Header - This header is used by the client or server when sending encrypted messages
- Encrypted
Message - An entirely encrypted SMB2 message, that includes both the encrypted header and the encrypted message.
Type Aliases
- Encryption
Nonce - The nonce used for encryption. Depending on the encryption algorithm, the nonce may be trimmed to a smaller size when used, or padded with zeroes to match the required size. When transmitted, the full 16 bytes are used.