Module encrypted

Module encrypted 

Encrypted messages

Structs

EncryptedHeader
EncryptedMessage

Type Aliases

EncryptionNonce
The nonce used for encryption. Depending on the encryption algorithm, the nonce may be trimmed to a smaller size when used, or padded with zeroes to match the required size. When transmitted, the full 16 bytes are used.