EncryptedHeader

Struct EncryptedHeader 

pub struct EncryptedHeader {
    pub signature: u128,
    pub nonce: EncryptionNonce,
    pub original_message_size: u32,
    pub session_id: u64,
}

Fields

signature: u128nonce: EncryptionNonceoriginal_message_size: u32session_id: u64

Implementations

Source

impl EncryptedHeader

pub const STRUCTURE_SIZE: usize = 52usize

pub fn aead_bytes(&self) -> [u8; 32]

The bytes to use as the additional data for the AEAD out of this header. Make sure to call it after all fields (except signature) are finalized.

Returns (according to MS-SMB2) the bytes of the header, excluding the magic and the signature.