Status

Enum Status 

#[repr(u32)]
pub enum Status {
Show 45 variants Success = 0, Pending = 259, NotifyCleanup = 267, NotifyEnumDir = 268, InvalidSmb = 65_538, SmbBadTid = 327_682, SmbBadCommand = 1_441_794, SmbBadUid = 5_963_778, SmbUseStandard = 16_449_538, BufferOverflow = 2_147_483_653, NoMoreFiles = 2_147_483_654, StoppedOnSymlink = 2_147_483_693, NotImplemented = 3_221_225_474, InvalidInfoClass = 3_221_225_475, InfoLengthMismatch = 3_221_225_476, InvalidParameter = 3_221_225_485, NoSuchDevice = 3_221_225_486, InvalidDeviceRequest0 = 3_221_225_488, EndOfFile = 3_221_225_489, MoreProcessingRequired = 3_221_225_494, AccessDenied = 3_221_225_506, BufferTooSmall = 3_221_225_507, ObjectNameInvalid = 3_221_225_523, ObjectNameNotFound = 3_221_225_524, ObjectNameCollision = 3_221_225_525, SharingViolation = 3_221_225_539, ObjectPathNotFound = 3_221_225_530, NoEasOnFile = 3_221_225_540, LogonFailure = 3_221_225_581, NotMapped = 3_221_225_587, BadImpersonationLevel = 3_221_225_637, IoTimeout = 3_221_225_653, FileIsADirectory = 3_221_225_658, NotSupported = 3_221_225_659, NetworkNameDeleted = 3_221_225_673, BadNetworkName = 3_221_225_676, RequestNotAccepted = 3_221_225_680, DirectoryNotEmpty = 3_221_225_729, Cancelled = 3_221_225_760, UserSessionDeleted = 3_221_225_987, UserAccountLockedOut = 3_221_226_036, PathNotCovered = 3_221_226_071, NetworkSessionExpired = 3_221_226_332, SmbTooManyUids = 3_221_233_754, DeviceFeatureNotSupported = 3_221_226_595,
}
NT Status codes for SMB.

For each status code, a U32 constant is also provided for easier access. for example, Status::U32_END_OF_FILE is 0xC0000011, matching Status::EndOfFile.

Variants



Success = 0

Success (0x00000000)



Pending = 259

Pending (0x00000103)



NotifyCleanup = 267

Notify Cleanup (0x0000010B)



NotifyEnumDir = 268

Notify Enum Dir (0x0000010C)



InvalidSmb = 65_538

Invalid SMB (0x00010002)



SmbBadTid = 327_682

SMB Bad TID (0x00050002)



SmbBadCommand = 1_441_794

SMB Bad Command (0x00160002)



SmbBadUid = 5_963_778

SMB Bad UID (0x005B0002)



SmbUseStandard = 16_449_538

SMB Use Standard (0x00FB0002)



BufferOverflow = 2_147_483_653

Buffer Overflow (0x80000005)



NoMoreFiles = 2_147_483_654

No More Files (0x80000006)

Stopped on Symlink (0x8000002D)



NotImplemented = 3_221_225_474

Not Implemented (0xC0000002)



InvalidInfoClass = 3_221_225_475

Invalid Info Class (0xC0000003)



InfoLengthMismatch = 3_221_225_476

Info Length Mismatch (0xC0000004)



InvalidParameter = 3_221_225_485

Invalid Parameter (0xC000000D)



NoSuchDevice = 3_221_225_486

No Such Device (0xC000000E)



InvalidDeviceRequest0 = 3_221_225_488

Invalid Device Request (0xC0000010)



EndOfFile = 3_221_225_489

End of File (0xC0000011)



MoreProcessingRequired = 3_221_225_494

More Processing Required (0xC0000016)



AccessDenied = 3_221_225_506

Access Denied (0xC0000022)



BufferTooSmall = 3_221_225_507

Buffer Too Small (0xC0000023)



ObjectNameInvalid = 3_221_225_523

Object Name Invalid (0xC0000033)



ObjectNameNotFound = 3_221_225_524

Object Name Not Found (0xC0000034)



ObjectNameCollision = 3_221_225_525

Object Name Collision (0xC0000035)



SharingViolation = 3_221_225_539

Sharing Violation (0xC0000043)



ObjectPathNotFound = 3_221_225_530

Object Path Not Found (0xC000003A)



NoEasOnFile = 3_221_225_540

No EAs on File (0xC0000044)



LogonFailure = 3_221_225_581

Logon Failure (0xC000006D)



NotMapped = 3_221_225_587

Not Mapped (0xC0000073)



BadImpersonationLevel = 3_221_225_637

Bad Impersonation Level (0xC00000A5)



IoTimeout = 3_221_225_653

I/O Timeout (0xC00000B5)



FileIsADirectory = 3_221_225_658

File is a Directory (0xC00000BA)



NotSupported = 3_221_225_659

Not Supported (0xC00000BB)



NetworkNameDeleted = 3_221_225_673

Network Name Deleted (0xC00000C9)



BadNetworkName = 3_221_225_676

Bad Network Name (0xC00000CC)



RequestNotAccepted = 3_221_225_680

Request Not Accepted (0xC00000D0)



DirectoryNotEmpty = 3_221_225_729

Directory Not Empty (0xC0000101)



Cancelled = 3_221_225_760

Cancelled (0xC0000120)



UserSessionDeleted = 3_221_225_987

User Session Deleted (0xC0000203)



UserAccountLockedOut = 3_221_226_036

User Account Locked Out (0xC0000234)



PathNotCovered = 3_221_226_071

Path Not Covered (0xC0000257)



NetworkSessionExpired = 3_221_226_332

Network Session Expired (0xC000035C)



SmbTooManyUids = 3_221_233_754

SMB Too Many UIDs (0xC000205A)



DeviceFeatureNotSupported = 3_221_226_595

Device Feature Not Supported (0xC0000463)

Implementations

Source

impl Status

pub const U32_SUCCESS: u32 = 0u32

Success as u32

pub const U32_PENDING: u32 = 259u32

Pending as u32

pub const U32_NOTIFY_CLEANUP: u32 = 267u32

pub const U32_NOTIFY_ENUM_DIR: u32 = 268u32

pub const U32_INVALID_SMB: u32 = 65_538u32

InvalidSmb as u32

pub const U32_SMB_BAD_TID: u32 = 327_682u32

SmbBadTid as u32

pub const U32_SMB_BAD_COMMAND: u32 = 1_441_794u32

pub const U32_SMB_BAD_UID: u32 = 5_963_778u32

SmbBadUid as u32

pub const U32_SMB_USE_STANDARD: u32 = 16_449_538u32

pub const U32_BUFFER_OVERFLOW: u32 = 2_147_483_653u32

pub const U32_NO_MORE_FILES: u32 = 2_147_483_654u32

NoMoreFiles as u32

pub const U32_NOT_IMPLEMENTED: u32 = 3_221_225_474u32

pub const U32_INVALID_INFO_CLASS: u32 = 3_221_225_475u32

pub const U32_INFO_LENGTH_MISMATCH: u32 = 3_221_225_476u32

pub const U32_INVALID_PARAMETER: u32 = 3_221_225_485u32

pub const U32_NO_SUCH_DEVICE: u32 = 3_221_225_486u32

NoSuchDevice as u32

pub const U32_INVALID_DEVICE_REQUEST0: u32 = 3_221_225_488u32

pub const U32_END_OF_FILE: u32 = 3_221_225_489u32

EndOfFile as u32

pub const U32_MORE_PROCESSING_REQUIRED: u32 = 3_221_225_494u32

pub const U32_ACCESS_DENIED: u32 = 3_221_225_506u32

AccessDenied as u32

pub const U32_BUFFER_TOO_SMALL: u32 = 3_221_225_507u32

pub const U32_OBJECT_NAME_INVALID: u32 = 3_221_225_523u32

pub const U32_OBJECT_NAME_NOT_FOUND: u32 = 3_221_225_524u32

pub const U32_OBJECT_NAME_COLLISION: u32 = 3_221_225_525u32

pub const U32_SHARING_VIOLATION: u32 = 3_221_225_539u32

pub const U32_OBJECT_PATH_NOT_FOUND: u32 = 3_221_225_530u32

pub const U32_NO_EAS_ON_FILE: u32 = 3_221_225_540u32

NoEasOnFile as u32

pub const U32_LOGON_FAILURE: u32 = 3_221_225_581u32

LogonFailure as u32

pub const U32_NOT_MAPPED: u32 = 3_221_225_587u32

NotMapped as u32

pub const U32_BAD_IMPERSONATION_LEVEL: u32 = 3_221_225_637u32

pub const U32_IO_TIMEOUT: u32 = 3_221_225_653u32

IoTimeout as u32

pub const U32_FILE_IS_A_DIRECTORY: u32 = 3_221_225_658u32

pub const U32_NOT_SUPPORTED: u32 = 3_221_225_659u32

NotSupported as u32

pub const U32_NETWORK_NAME_DELETED: u32 = 3_221_225_673u32

pub const U32_BAD_NETWORK_NAME: u32 = 3_221_225_676u32

pub const U32_REQUEST_NOT_ACCEPTED: u32 = 3_221_225_680u32

pub const U32_DIRECTORY_NOT_EMPTY: u32 = 3_221_225_729u32

pub const U32_CANCELLED: u32 = 3_221_225_760u32

Cancelled as u32

pub const U32_USER_SESSION_DELETED: u32 = 3_221_225_987u32

pub const U32_USER_ACCOUNT_LOCKED_OUT: u32 = 3_221_226_036u32

pub const U32_PATH_NOT_COVERED: u32 = 3_221_226_071u32

pub const U32_NETWORK_SESSION_EXPIRED: u32 = 3_221_226_332u32

pub const U32_SMB_TOO_MANY_UIDS: u32 = 3_221_233_754u32

pub const U32_DEVICE_FEATURE_NOT_SUPPORTED: u32 = 3_221_226_595u32

pub fn try_display_as_status(value: u32) -> String

A helper function that tries converting u32 to a Status, and returns a string representation of the status. Otherwise, it returns the hex representation of the u32 value. This is useful for displaying NT status codes that are not necessarily defined in the Status enum.