Module query

Module query 

Get/Set Info Request/Response

Structs

GetEaInfoList
NullByte
QueryInfoFlags
QueryInfoRequest
QueryInfoResponse
QueryInfoResponseData
A helpers struct that contains the raw data of a query info response or a set info request, and can be parsed using the QueryInfoResponseData::parse method, to a specific info type.
QueryQuotaInfo
RawQueryInfoData

Enums

GetInfoRequestData
This struct describes the payload to be added in the QueryInfoRequest when asking for information about Quota or Extended Attributes. In other cases, it is empty.
QueryInfoClass
QueryInfoData
Enum to hold the different info types for QueryInfoData, that are used within SMB requests for querying or setting information.