Get/Set Info Request/Response
Structs
- GetEa
Info List - Null
Byte - Query
Info Flags - Query
Info Request - Query
Info Response - Query
Info Response Data - A helpers struct that contains the raw data of a query info response or a set info request,
and can be parsed using the
QueryInfoResponseData::parsemethod, to a specific info type. - Query
Quota Info - RawQuery
Info Data
Enums
- GetInfo
Request Data - This struct describes the payload to be added in the QueryInfoRequest when asking for information about Quota or Extended Attributes. In other cases, it is empty.
- Query
Info Class - Query
Info Data - Represents information passed in get/set info requests. This is the information matching InfoType, and should be used in the get info response and in the set info request.