pub enum GetInfoRequestData {
Quota(QueryQuotaInfo),
EaInfo(GetEaInfoList),
None(()),
}Expand description
This struct describes the payload to be added in the QueryInfoRequest when asking for information about Quota or Extended Attributes. In other cases, it is empty.
Variants
Quota(QueryQuotaInfo)
The query quota to perform.
EaInfo(GetEaInfoList)
Extended attributes information to query.
None(())