Module set

Module set 

Set Info Request/Response messages and related types.

Structs

RawSetInfoData
SetInfoRequest
SMB2 SET_INFO request packet for setting information on a file or object store.
SetInfoResponse
SMB2 SET_INFO response packet indicating successful completion.

Enums

SetInfoClass
Information class specifying the type of information to set.
SetInfoData
Enum to hold the different info types for SetInfoData, that are used within SMB requests for querying or setting information.