Module set

Module set 

SMB2 Set Info Request/Response messages.

Structs

RawSetInfoData
SetInfoRequest
SetInfoResponse

Enums

SetInfoClass
A helper class for SetInfoRequest to contain the information class to set. In cases of no class, it will be set to a null byte (0u8).
SetInfoData
Enum to hold the different info types for SetInfoData, that are used within SMB requests for querying or setting information.