SMB2 Set Info Request/Response messages.
Structs
Enums
- SetInfo
Class - A helper class for SetInfoRequest to contain the information class to set. In cases of no class, it will be set to a null byte (0u8).
- SetInfo
Data - Enum to hold the different info types for SetInfoData, that are used within SMB requests for querying or setting information.