SMB2 Set Info Request/Response messages.
Structs
Enums
- SetInfo
Class - A helper class for SetInfoRequest to contain the information class to set. In cases of no class, it will be set to a null byte (0u8).
- SetInfo
Data - Represents information passed in get/set info requests. This is the information matching InfoType, and should be used in the get info response and in the set info request.