pub enum SetInfoClass {
File(SetFileInfoClass),
FileSystem(SetFileSystemInfoClass),
Security(NullByte),
Quota(NullByte),
}Expand description
Information class specifying the type of information to set.
Defines the specific information class for each info type category. For Security and Quota operations, the class is set to null byte (0).
MS-SMB2 2.2.39
Variants
File(SetFileInfoClass)
File information class (e.g., FileBasicInformation, FileRenameInformation)
FileSystem(SetFileSystemInfoClass)
Filesystem information class (e.g., FileFsControlInformation)
Security(NullByte)
Security information class (always 0)
Quota(NullByte)
Quota information class (always 0)