SetInfoData

Enum SetInfoData 

pub enum SetInfoData {
    File(RawSetInfoData<SetFileInfo>),
    FileSystem(RawSetInfoData<SetFileSystemInfo>),
    Security(SecurityDescriptor),
    Quota(ChainedItemList<FileQuotaInformation>),
}
Enum to hold the different info types for SetInfoData, that are used within SMB requests for querying or setting information.

Variants

Implementations

Source

impl SetInfoData

pub fn as_file(self) -> Result<RawSetInfoData<SetFileInfo>, SmbMsgError>

Get the inner content as RawSetInfoData<SetFileInfo>.

pub fn as_filesystem( self, ) -> Result<RawSetInfoData<SetFileSystemInfo>, SmbMsgError>

Get the inner content as RawSetInfoData<SetFileSystemInfo>.

pub fn as_security(self) -> Result<SecurityDescriptor, SmbMsgError>

Get the inner content as SecurityDescriptor.

pub fn as_quota( self, ) -> Result<ChainedItemList<FileQuotaInformation>, SmbMsgError>

Get the inner content as ChainedItemList<FileQuotaInformation>.

pub fn info_type(&self) -> InfoType

Get the InfoType of this data.

pub fn name(&self) -> &'static str

Get the name of this data.

Source

impl SetInfoData

pub fn to_req( self, info_class: SetInfoClass, file_id: FileId, additional_info: AdditionalInfo, ) -> SetInfoRequest

This is a helper function to convert the SetInfoData to a SetInfoRequest.