pub enum SetInfoData {
File(RawSetInfoData<SetFileInfo>),
FileSystem(RawSetInfoData<SetFileSystemInfo>),
Security(SecurityDescriptor),
Quota(QueryQuotaInfo),
}Expand description
Represents information passed in get/set info requests. This is the information matching InfoType, and should be used in the get info response and in the set info request.
Variants
File(RawSetInfoData<SetFileInfo>)
FileSystem(RawSetInfoData<SetFileSystemInfo>)
Security(SecurityDescriptor)
Quota(QueryQuotaInfo)
Implementations
Sourceimpl SetInfoData
impl SetInfoData
pub fn unwrap_file(self) -> RawSetInfoData<SetFileInfo>
pub fn as_file(self) -> Result<RawSetInfoData<SetFileInfo>, SmbMsgError>
pub fn unwrap_filesystem(self) -> RawSetInfoData<SetFileSystemInfo>
pub fn as_filesystem( self, ) -> Result<RawSetInfoData<SetFileSystemInfo>, SmbMsgError>
pub fn unwrap_security(self) -> SecurityDescriptor
pub fn as_security(self) -> Result<SecurityDescriptor, SmbMsgError>
pub fn unwrap_quota(self) -> QueryQuotaInfo
pub fn as_quota(self) -> Result<QueryQuotaInfo, SmbMsgError>
Sourceimpl SetInfoData
impl SetInfoData
Sourcepub fn to_req(
self,
info_class: SetInfoClass,
file_id: FileId,
additional_info: AdditionalInfo,
) -> SetInfoRequest
pub fn to_req( self, info_class: SetInfoClass, file_id: FileId, additional_info: AdditionalInfo, ) -> SetInfoRequest
This is a helper function to convert the SetInfoData to a SetInfoRequest.