Module ioctl

Module ioctl 

IOCTL requessts and responses implementation, and FSCTLs.

Structs

FileLevelTrimRange
MSDN
FileLevelTrimRequest
FileLevelTrimResponse
MS-FSCC 2.3.14
IoctlBuffer
Utility structure to represent inner value of Ioctl requests that have no defined struct (i.e. they are treated as raw byte buffers).
IoctlRequest
SMB2 IOCTL request packet for issuing file system control or device control commands.
IoctlRequestFlags
Flags field indicating how to process the IOCTL operation.
IoctlResponse
SMB2 IOCTL response packet containing results of an IOCTL request.
LmrRequestResiliencyResponse
NetworkInterfaceCapability
Capability flags for network interfaces indicating supported features. Used in the NetworkInterfaceInfo structure to specify interface capabilities.
NetworkInterfaceInfo
Network interface information structure returned by FSCTL_QUERY_NETWORK_INTERFACE_INFO. Contains details about a specific network interface on the server.
NetworkResiliencyRequest
Request packet for requesting resiliency for a specified open file. Sent in an SMB2 IOCTL Request using FSCTL_LMR_REQUEST_RESILIENCY. This request is not valid for the SMB 2.0.2 dialect.
OffloadReadRequest
MS-FSCC 2.3.41
OffloadReadResponse
MS-FSCC 2.3.42
PipePeekRequest
PipePeekResponse
MS-FSCC 2.3.46
PipeTransceiveRequest
PipeTransceiveResponse
PipeWaitRequest
The FSCTL_PIPE_WAIT Request requests that the server wait until either a time-out interval elapses, or an instance of the specified named pipe is available for connection.
PipeWaitResponse
QueryAllocRangesItem
QueryAllocRangesResult
QueryNetworkInterfaceInfoRequest
SetReparsePointRequest
Stores data for a reparse point.
SetReparsePointResponse
SocketAddrStorageV4
SocketAddrStorageV6
SrvCopyChunkCopyWrite
SrvCopychunkCopy
Request packet for initiating a server-side copy of data. Sent in an SMB2 IOCTL Request using FSCTL_SRV_COPYCHUNK or FSCTL_SRV_COPYCHUNK_WRITE.
SrvCopychunkItem
Individual data range descriptor for server-side copy operations. Sent in the chunks array of a SRV_COPYCHUNK_COPY packet to describe an individual data range to copy.
SrvCopychunkResponse
Response packet for server-side copy operations. Returned by the server in an SMB2 IOCTL Response for FSCTL_SRV_COPYCHUNK or FSCTL_SRV_COPYCHUNK_WRITE requests to provide the results of the copy operation.
SrvEnumerateSnapshotsRequest
SrvEnumerateSnapshotsResponse
MS-SMB 2.2.7.2.2.1
SrvHashRetrieveFileBased
File-based response format for SRV_READ_HASH when HashRetrievalType is SRV_HASH_RETRIEVE_FILE_BASED. Valid for servers implementing the SMB 3.x dialect family. Contains hash information for a specified range of file data.
SrvHashRetrieveHashBased
Hash-based response format for SRV_READ_HASH when HashRetrievalType is SRV_HASH_RETRIEVE_HASH_BASED. Contains a portion of the Content Information File retrieved from a specified offset.
SrvReadHashReq
Request packet for retrieving data from the Content Information File associated with a specified file. Sent in an SMB2 IOCTL Request using FSCTL_SRV_READ_HASH. The request is not valid for the SMB 2.0.2 dialect.
SrvReadHashRes
Response packet for SRV_READ_HASH requests. Returned by the server in an SMB2 IOCTL Response for FSCTL_SRV_READ_HASH request. The response is not valid for the SMB 2.0.2 dialect.
SrvRequestResumeKey
Response packet containing a resume key for server-side copy operations. Returned by the server in an SMB2 IOCTL Response for FSCTL_SRV_REQUEST_RESUME_KEY request. The resume key can be used to uniquely identify the source file in subsequent copy operations.
SrvRequestResumeKeyRequest
SrvSnapshotArray
Response packet containing snapshots associated with a share. Returned by the server in an SMB2 IOCTL Response for FSCTL_SRV_ENUMERATE_SNAPSHOTS request. Contains all revision timestamps associated with the Tree Connect share.
ValidateNegotiateInfoRequest
Request packet for validating a previous SMB 2 NEGOTIATE. Used in FSCTL_VALIDATE_NEGOTIATE_INFO to ensure the negotiation was not tampered with. Valid for clients and servers implementing SMB 3.0 and SMB 3.0.2 dialects.
ValidateNegotiateInfoResponse
Response for validating a previous SMB 2 NEGOTIATE. Returned in an SMB2 IOCTL response for FSCTL_VALIDATE_NEGOTIATE_INFO request. Valid for servers implementing the SMB 3.x dialect family, optional for others.

Enums

FsctlCodes
IoctlReqData
SocketAddrStorage
SrvHashRetrievalType
Enum specifying the nature of the offset field in SRV_READ_HASH requests. Determines how the offset field should be interpreted for hash retrieval.

Traits

FsctlRequest
This is a helper trait that defines, for a certain FSCTL request type, the response type and their matching FSCTL code.
FsctlResponseContent
A trait that helps parsing FSCTL responses by matching the FSCTL code.
IoctlRequestContent
A trait that helps calculating the size of the buffer for IOCTL requests.

Type Aliases

NetworkInterfacesInfo