Module ioctl

Module ioctl 

SMB2 IOCTL packet implementation

Structs

FileLevelTrimRange
MSDN
FileLevelTrimRequest
FileLevelTrimResponse
MS-FSCC 2.3.14
IoctlBuffer
IoctlRequest
IoctlRequestFlags
IoctlResponse
LmrRequestResiliencyResponse
NetworkInterfaceCapability
NetworkInterfaceInfo
NetworkResiliencyRequest
Sent to request resiliency for a specified open file. This request is not valid for the SMB 2.0.2 dialect.
OffloadReadRequest
MS-FSCC 2.3.41
OffloadReadResponse
MS-FSCC 2.3.42
PipePeekRequest
PipePeekResponse
MS-FSCC 2.3.46
PipeTransceiveRequest
PipeTransceiveResponse
PipeWaitRequest
The FSCTL_PIPE_WAIT Request requests that the server wait until either a time-out interval elapses, or an instance of the specified named pipe is available for connection.
PipeWaitResponse
QueryAllocRangesItem
QueryAllocRangesResult
QueryNetworkInterfaceInfoRequest
SetReparsePointRequest
Stores data for a reparse point.
SetReparsePointResponse
SocketAddrStorageV4
SocketAddrStorageV6
SrvCopyChunkCopyWrite
SrvCopychunkCopy
The Length of source/dest keys in SrvCopyChunk* FSCTLs contents. MS-SMB 2.2.31.1
SrvCopychunkItem
SrvCopychunkResponse
SrvEnumerateSnapshotsRequest
SrvEnumerateSnapshotsResponse
MS-SMB 2.2.7.2.2.1
SrvHashRetrieveFileBased
SrvHashRetrieveHashBased
SrvReadHashReq
SrvReadHashRes
SrvRequestResumeKey
SrvRequestResumeKeyRequest
SrvSnapshotArray
ValidateNegotiateInfoRequest
ValidateNegotiateInfoResponse

Enums

FsctlCodes
IoctlReqData
SocketAddrStorage
SrvHashRetrievalType

Traits

FsctlRequest
This is a helper trait that defines, for a certain FSCTL request type, the response type and their matching FSCTL code.
FsctlResponseContent
A trait that helps parsing FSCTL responses by matching the FSCTL code.
IoctlRequestContent
A trait that helps calculating the size of the buffer for IOCTL requests.

Type Aliases

NetworkInterfacesInfo