SMB2 IOCTL packet implementation
Structs
- File
Level Trim Range - MSDN
- File
Level Trim Request - File
Level Trim Response - MS-FSCC 2.3.14
- Ioctl
Buffer - Ioctl
Request - Ioctl
Request Flags - Ioctl
Response - LmrRequest
Resiliency Response - Network
Interface Capability - Network
Interface Info - Network
Resiliency Request - Sent to request resiliency for a specified open file. This request is not valid for the SMB 2.0.2 dialect.
- Offload
Read Request - MS-FSCC 2.3.41
- Offload
Read Response - MS-FSCC 2.3.42
- Pipe
Peek Request - Pipe
Peek Response - MS-FSCC 2.3.46
- Pipe
Transceive Request - Pipe
Transceive Response - Pipe
Wait Request - The FSCTL_PIPE_WAIT Request requests that the server wait until either a time-out interval elapses, or an instance of the specified named pipe is available for connection.
- Pipe
Wait Response - Query
Alloc Ranges Item - Query
Alloc Ranges Result - Query
Network Interface Info Request - SetReparse
Point Request - Stores data for a reparse point.
- SetReparse
Point Response - Socket
Addr Storage V4 - Socket
Addr Storage V6 - SrvCopy
Chunk Copy Write - SrvCopychunk
Copy - The Length of source/dest keys in SrvCopyChunk* FSCTLs contents. MS-SMB 2.2.31.1
- SrvCopychunk
Item - SrvCopychunk
Response - SrvEnumerate
Snapshots Request - SrvEnumerate
Snapshots Response - MS-SMB 2.2.7.2.2.1
- SrvHash
Retrieve File Based - SrvHash
Retrieve Hash Based - SrvRead
Hash Req - SrvRead
Hash Res - SrvRequest
Resume Key - SrvRequest
Resume KeyRequest - SrvSnapshot
Array - Validate
Negotiate Info Request - Validate
Negotiate Info Response
Enums
Traits
- Fsctl
Request - This is a helper trait that defines, for a certain FSCTL request type, the response type and their matching FSCTL code.
- Fsctl
Response Content - A trait that helps parsing FSCTL responses by matching the FSCTL code.
- Ioctl
Request Content - A trait that helps calculating the size of the buffer for IOCTL requests.