SrvHashRetrievalType

Enum SrvHashRetrievalType 

pub enum SrvHashRetrievalType {
    HashBased = 1,
    FileBased = 2,
}
Enum specifying the nature of the offset field in SRV_READ_HASH requests. Determines how the offset field should be interpreted for hash retrieval.

Reference: MS-SMB2 2.2.31.2

Variants



HashBased = 1

The offset field in the SRV_READ_HASH request is relative to the beginning of the Content Information File.



FileBased = 2

The offset field in the SRV_READ_HASH request is relative to the beginning of the file indicated by the FileId field in the IOCTL request. This value is only applicable for the SMB 3.x dialect family.