pub struct NetworkInterfaceCapability { /* private fields */ }Expand description
Capability flags for network interfaces indicating supported features. Used in the NetworkInterfaceInfo structure to specify interface capabilities.
Reference: MS-SMB2 2.2.32.5
Implementations
Sourceimpl NetworkInterfaceCapability
impl NetworkInterfaceCapability
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl NetworkInterfaceCapability
impl NetworkInterfaceCapability
Sourcepub fn rss(&self) -> <bool as Specifier>::InOut
pub fn rss(&self) -> <bool as Specifier>::InOut
Returns the value of rss. When set, specifies that the interface is RSS (Receive Side Scaling) capable.
Sourcepub fn rss_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn rss_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of rss.
#Errors
If the returned value contains an invalid bit pattern for rss. When set, specifies that the interface is RSS (Receive Side Scaling) capable.
Sourcepub fn with_rss(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_rss(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of rss set to the given value.
#Panics
If the given value is out of bounds for rss. When set, specifies that the interface is RSS (Receive Side Scaling) capable.
Sourcepub fn with_rss_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_rss_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of rss set to the given value.
#Errors
If the given value is out of bounds for rss. When set, specifies that the interface is RSS (Receive Side Scaling) capable.
Sourcepub fn set_rss(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_rss(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of rss to the given value.
#Panics
If the given value is out of bounds for rss. When set, specifies that the interface is RSS (Receive Side Scaling) capable.
Sourcepub fn set_rss_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_rss_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of rss to the given value.
#Errors
If the given value is out of bounds for rss. When set, specifies that the interface is RSS (Receive Side Scaling) capable.
Sourcepub fn rdma(&self) -> <bool as Specifier>::InOut
pub fn rdma(&self) -> <bool as Specifier>::InOut
Returns the value of rdma. When set, specifies that the interface is RDMA (Remote Direct Memory Access) capable.
Sourcepub fn rdma_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn rdma_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of rdma.
#Errors
If the returned value contains an invalid bit pattern for rdma. When set, specifies that the interface is RDMA (Remote Direct Memory Access) capable.
Sourcepub fn with_rdma(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_rdma(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of rdma set to the given value.
#Panics
If the given value is out of bounds for rdma. When set, specifies that the interface is RDMA (Remote Direct Memory Access) capable.
Sourcepub fn with_rdma_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_rdma_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of rdma set to the given value.
#Errors
If the given value is out of bounds for rdma. When set, specifies that the interface is RDMA (Remote Direct Memory Access) capable.
Sourcepub fn set_rdma(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_rdma(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of rdma to the given value.
#Panics
If the given value is out of bounds for rdma. When set, specifies that the interface is RDMA (Remote Direct Memory Access) capable.
Sourcepub fn set_rdma_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_rdma_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of rdma to the given value.
#Errors
If the given value is out of bounds for rdma. When set, specifies that the interface is RDMA (Remote Direct Memory Access) capable.