pub struct PipeWaitRequest {
pub timeout: u64,
pub timeout_specified: Boolean,
pub name: SizedWideString,
}Expand description
The FSCTL_PIPE_WAIT Request requests that the server wait until either a time-out interval elapses, or an instance of the specified named pipe is available for connection.
Fields
timeout: u64specifies the maximum amount of time, in units of 100 milliseconds, that the function can wait for an instance of the named pipe to be available.
timeout_specified: BooleanWhether the Timeout parameter will be ignored.
FALSE Indicates that the server MUST wait forever. Any value in timeout must be ignored.
name: SizedWideStringA Unicode string that contains the name of the named pipe. Name MUST not include the “\pipe", so if the operation was on \server\pipe\pipename, the name would be “pipename”.