pub struct SetReparsePointRequest {
pub reparse_tag: u32,
pub reparse_guid: Option<Guid>,
pub reparse_data: Vec<u8>,
}Expand description
Stores data for a reparse point.
Fields
reparse_tag: u32Contains the reparse point tag that uniquely identifies the owner of the reparse point.
reparse_guid: Option<Guid>Applicable only for reparse points that have a GUID. See MS-FSCC 2.1.2.3
reparse_data: Vec<u8>Reparse-specific data for the reparse point