pub struct SrvEnumerateSnapshotsResponse {
pub number_of_snap_shots: u32,
pub number_of_snap_shots_returned: u32,
pub snap_shots: MultiWSz,
}Expand description
Fields
number_of_snap_shots: u32The number of snapshots that the underlying object store contains of this file.
number_of_snap_shots_returned: u32This value MUST be the number of snapshots that are returned in this response. If this value is less than NumberofSnapshots, then there are more snapshots than were able to fit in this response.
snap_shots: MultiWSzA list of snapshots, described as strings, that take on the following form: @GMT-YYYY.MM.DD-HH.MM.SS