SrvReadHashReq

Struct SrvReadHashReq 

pub struct SrvReadHashReq {
    pub hash_version: u32,
    pub hash_retrieval_type: SrvHashRetrievalType,
}
Request packet for retrieving data from the Content Information File associated with a specified file. Sent in an SMB2 IOCTL Request using FSCTL_SRV_READ_HASH. The request is not valid for the SMB 2.0.2 dialect.

Reference: MS-SMB2 2.2.31.2

Fields

hash_version: u32

The version number of the algorithm used to create the Content Information. Must be set to version 1 (branch cache version 1) or version 2 (branch cache version 2). Version 2 is only applicable for the SMB 3.x dialect family.

hash_retrieval_type: SrvHashRetrievalType

Indicates the nature of the offset field and how it should be interpreted.