pub struct SrvReadHashReq {
pub hash_version: u32,
pub hash_retrieval_type: SrvHashRetrievalType,
}Fields
hash_version: u32Hash version MUST be 1 or 2
hash_retrieval_type: SrvHashRetrievalTypeTrait Implementations
Sourceimpl BinRead for SrvReadHashReq
impl BinRead for SrvReadHashReq
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl BinWrite for SrvReadHashReq
impl BinWrite for SrvReadHashReq
Sourcefn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<()>
fn write_options<W: Write + Seek>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<()>
Sourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming big-endian byte order. Read moreSourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming little-endian byte order. Read moreSourcefn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming native-endian byte order. Read moreSourcefn write_be_args<W>(
&self,
writer: &mut W,
args: Self::Args<'_>,
) -> Result<(), Error>
fn write_be_args<W>( &self, writer: &mut W, args: Self::Args<'_>, ) -> Result<(), Error>
Write
Self to the writer, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl Debug for SrvReadHashReq
impl Debug for SrvReadHashReq
Sourceimpl From<SrvReadHashReq> for IoctlReqData
impl From<SrvReadHashReq> for IoctlReqData
Sourcefn from(model: SrvReadHashReq) -> IoctlReqData
fn from(model: SrvReadHashReq) -> IoctlReqData
Converts to this type from the input type.
Sourceimpl FsctlRequest for SrvReadHashReq
impl FsctlRequest for SrvReadHashReq
const FSCTL_CODE: FsctlCodes = FsctlCodes::SrvReadHash
type Response = SrvReadHashRes
Sourceimpl IoctlRequestContent for SrvReadHashReq
impl IoctlRequestContent for SrvReadHashReq
Sourcefn get_bin_size(&self) -> u32
fn get_bin_size(&self) -> u32
Returns the size of the buffer for IOCTL requests – the size of the ENCODED data, in bytes.
Sourceimpl PartialEq for SrvReadHashReq
impl PartialEq for SrvReadHashReq
impl Eq for SrvReadHashReq
impl StructuralPartialEq for SrvReadHashReq