pub struct SrvRequestResumeKey {
pub resume_key: [u8; 24],
pub context: Vec<u8>,
}Expand description
Response packet containing a resume key for server-side copy operations. Returned by the server in an SMB2 IOCTL Response for FSCTL_SRV_REQUEST_RESUME_KEY request. The resume key can be used to uniquely identify the source file in subsequent copy operations.
Reference: MS-SMB2 2.2.32.3
Fields
resume_key: [u8; 24]A 24-byte resume key generated by the server that can be used by the client to uniquely identify the source file in FSCTL_SRV_COPYCHUNK or FSCTL_SRV_COPYCHUNK_WRITE requests. The resume key must be treated as an opaque structure.
context: Vec<u8>The context extended information. This should always be set to empty according to the specification.