LockFlag

Struct LockFlag 

pub struct LockFlag { /* private fields */ }
Lock flags describing how the range is being locked or unlocked. Valid combinations are: shared lock, exclusive lock, unlock, or any of shared/exclusive combined with fail_immediately.

Reference: MS-SMB2 2.2.26.1

Implementations

Source

impl LockFlag

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl LockFlag

pub const fn into_bytes(self) -> [u8; 4]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 4]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl LockFlag

pub fn shared(&self) -> <bool as Specifier>::InOut

Returns the value of shared. Range must be locked shared, allowing other opens to read or take shared locks. Other opens must not be allowed to write within the range.

pub fn shared_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of shared.

#Errors

If the returned value contains an invalid bit pattern for shared. Range must be locked shared, allowing other opens to read or take shared locks. Other opens must not be allowed to write within the range.

pub fn with_shared(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of shared set to the given value.

#Panics

If the given value is out of bounds for shared. Range must be locked shared, allowing other opens to read or take shared locks. Other opens must not be allowed to write within the range.

pub fn with_shared_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of shared set to the given value.

#Errors

If the given value is out of bounds for shared. Range must be locked shared, allowing other opens to read or take shared locks. Other opens must not be allowed to write within the range.

pub fn set_shared(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of shared to the given value.

#Panics

If the given value is out of bounds for shared. Range must be locked shared, allowing other opens to read or take shared locks. Other opens must not be allowed to write within the range.

pub fn set_shared_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of shared to the given value.

#Errors

If the given value is out of bounds for shared. Range must be locked shared, allowing other opens to read or take shared locks. Other opens must not be allowed to write within the range.

pub fn exclusive(&self) -> <bool as Specifier>::InOut

Returns the value of exclusive. Range must be locked exclusive, not allowing other opens to read, write, or lock within the range.

pub fn exclusive_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of exclusive.

#Errors

If the returned value contains an invalid bit pattern for exclusive. Range must be locked exclusive, not allowing other opens to read, write, or lock within the range.

pub fn with_exclusive(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of exclusive set to the given value.

#Panics

If the given value is out of bounds for exclusive. Range must be locked exclusive, not allowing other opens to read, write, or lock within the range.

pub fn with_exclusive_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of exclusive set to the given value.

#Errors

If the given value is out of bounds for exclusive. Range must be locked exclusive, not allowing other opens to read, write, or lock within the range.

pub fn set_exclusive(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of exclusive to the given value.

#Panics

If the given value is out of bounds for exclusive. Range must be locked exclusive, not allowing other opens to read, write, or lock within the range.

pub fn set_exclusive_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of exclusive to the given value.

#Errors

If the given value is out of bounds for exclusive. Range must be locked exclusive, not allowing other opens to read, write, or lock within the range.

pub fn unlock(&self) -> <bool as Specifier>::InOut

Returns the value of unlock. Range must be unlocked from a previous lock. Unlock range must be identical to lock range.

pub fn unlock_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of unlock.

#Errors

If the returned value contains an invalid bit pattern for unlock. Range must be unlocked from a previous lock. Unlock range must be identical to lock range.

pub fn with_unlock(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of unlock set to the given value.

#Panics

If the given value is out of bounds for unlock. Range must be unlocked from a previous lock. Unlock range must be identical to lock range.

pub fn with_unlock_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of unlock set to the given value.

#Errors

If the given value is out of bounds for unlock. Range must be unlocked from a previous lock. Unlock range must be identical to lock range.

pub fn set_unlock(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of unlock to the given value.

#Panics

If the given value is out of bounds for unlock. Range must be unlocked from a previous lock. Unlock range must be identical to lock range.

pub fn set_unlock_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of unlock to the given value.

#Errors

If the given value is out of bounds for unlock. Range must be unlocked from a previous lock. Unlock range must be identical to lock range.

pub fn fail_immediately(&self) -> <bool as Specifier>::InOut

Returns the value of fail_immediately. Lock operation must fail immediately if it conflicts with an existing lock, instead of waiting for the range to become available.

pub fn fail_immediately_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of fail_immediately.

#Errors

If the returned value contains an invalid bit pattern for fail_immediately. Lock operation must fail immediately if it conflicts with an existing lock, instead of waiting for the range to become available.

pub fn with_fail_immediately(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of fail_immediately set to the given value.

#Panics

If the given value is out of bounds for fail_immediately. Lock operation must fail immediately if it conflicts with an existing lock, instead of waiting for the range to become available.

pub fn with_fail_immediately_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of fail_immediately set to the given value.

#Errors

If the given value is out of bounds for fail_immediately. Lock operation must fail immediately if it conflicts with an existing lock, instead of waiting for the range to become available.

pub fn set_fail_immediately(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of fail_immediately to the given value.

#Panics

If the given value is out of bounds for fail_immediately. Lock operation must fail immediately if it conflicts with an existing lock, instead of waiting for the range to become available.

pub fn set_fail_immediately_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of fail_immediately to the given value.

#Errors

If the given value is out of bounds for fail_immediately. Lock operation must fail immediately if it conflicts with an existing lock, instead of waiting for the range to become available.