pub struct LockFlag { /* private fields */ }Implementations
Sourceimpl LockFlag
impl LockFlag
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl LockFlag
impl LockFlag
Returns the value of shared.
Returns the value of shared.
#Errors
If the returned value contains an invalid bit pattern for shared.
Returns a copy of the bitfield with the value of shared set to the given value.
#Panics
If the given value is out of bounds for shared.
Returns a copy of the bitfield with the value of shared set to the given value.
#Errors
If the given value is out of bounds for shared.
Sets the value of shared to the given value.
#Panics
If the given value is out of bounds for shared.
Sets the value of shared to the given value.
#Errors
If the given value is out of bounds for shared.
Sourcepub fn exclusive_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn exclusive_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of exclusive.
#Errors
If the returned value contains an invalid bit pattern for exclusive.
Sourcepub fn with_exclusive(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_exclusive(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of exclusive set to the given value.
#Panics
If the given value is out of bounds for exclusive.
Sourcepub fn with_exclusive_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_exclusive_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of exclusive set to the given value.
#Errors
If the given value is out of bounds for exclusive.
Sourcepub fn set_exclusive(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_exclusive(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of exclusive to the given value.
#Panics
If the given value is out of bounds for exclusive.
Sourcepub fn set_exclusive_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_exclusive_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of exclusive to the given value.
#Errors
If the given value is out of bounds for exclusive.
Sourcepub fn unlock_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn unlock_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of unlock.
#Errors
If the returned value contains an invalid bit pattern for unlock.
Sourcepub fn with_unlock(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_unlock(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of unlock set to the given value.
#Panics
If the given value is out of bounds for unlock.
Sourcepub fn with_unlock_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_unlock_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of unlock set to the given value.
#Errors
If the given value is out of bounds for unlock.
Sourcepub fn set_unlock(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_unlock(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of unlock to the given value.
#Panics
If the given value is out of bounds for unlock.
Sourcepub fn set_unlock_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_unlock_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of unlock to the given value.
#Errors
If the given value is out of bounds for unlock.
Sourcepub fn fail_immediately(&self) -> <bool as Specifier>::InOut
pub fn fail_immediately(&self) -> <bool as Specifier>::InOut
Returns the value of fail_immediately.
Sourcepub fn fail_immediately_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn fail_immediately_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of fail_immediately.
#Errors
If the returned value contains an invalid bit pattern for fail_immediately.
Sourcepub fn with_fail_immediately(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_fail_immediately(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of fail_immediately set to the given value.
#Panics
If the given value is out of bounds for fail_immediately.
Sourcepub fn with_fail_immediately_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_fail_immediately_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of fail_immediately set to the given value.
#Errors
If the given value is out of bounds for fail_immediately.
Sourcepub fn set_fail_immediately(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_fail_immediately(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of fail_immediately to the given value.
#Panics
If the given value is out of bounds for fail_immediately.
Sourcepub fn set_fail_immediately_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_fail_immediately_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of fail_immediately to the given value.
#Errors
If the given value is out of bounds for fail_immediately.