pub struct LockRequest {
pub lock_sequence: LockSequence,
pub file_id: FileId,
pub locks: Vec<LockElement>,
}Expand description
SMB2 LOCK Request packet used to lock or unlock portions of a file. Multiple segments of the file can be affected with a single request, but they all must be within the same file.
Reference: MS-SMB2 2.2.26
Fields
lock_sequence: LockSequenceLock sequence information for the request.
file_id: FileIdFile identifier on which to perform the byte range locks or unlocks.
locks: Vec<LockElement>Array of lock elements defining the ranges to be locked or unlocked.