query_info_data

Macro query_info_data 

macro_rules! query_info_data {
    ($name:ident $($info_type:ident: $content:ty, )+) => { ... };
}
Internal helper macro to easily generate fields & methods for QueryInfoData.

Builds:

  1. The enum with the specified name, with variants for each info type specified.
  2. A generic struct names Raw<name> to hold the raw data, with a method to convert it to the actual data.