macro_rules! query_info_data {
($name:ident $($info_type:ident: $content:ty, )+) => { ... };
}Expand description
Internal helper macro to easily generate fields & methods for QueryInfoData.
Builds:
- The enum with the specified name, with variants for each info type specified.
- A generic struct names
Raw<name>to hold the raw data, with a method to convert it to the actual data.