pub struct NotifyFilter { /* private fields */ }Implementations
Sourceimpl NotifyFilter
impl NotifyFilter
Sourceimpl NotifyFilter
impl NotifyFilter
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl NotifyFilter
impl NotifyFilter
Sourcepub fn file_name_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn file_name_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of file_name.
#Errors
If the returned value contains an invalid bit pattern for file_name.
Sourcepub fn with_file_name(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_file_name(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of file_name set to the given value.
#Panics
If the given value is out of bounds for file_name.
Sourcepub fn with_file_name_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_file_name_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of file_name set to the given value.
#Errors
If the given value is out of bounds for file_name.
Sourcepub fn set_file_name(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_file_name(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of file_name to the given value.
#Panics
If the given value is out of bounds for file_name.
Sourcepub fn set_file_name_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_file_name_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of file_name to the given value.
#Errors
If the given value is out of bounds for file_name.
Sourcepub fn dir_name_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn dir_name_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of dir_name.
#Errors
If the returned value contains an invalid bit pattern for dir_name.
Sourcepub fn with_dir_name(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_dir_name(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of dir_name set to the given value.
#Panics
If the given value is out of bounds for dir_name.
Sourcepub fn with_dir_name_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_dir_name_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of dir_name set to the given value.
#Errors
If the given value is out of bounds for dir_name.
Sourcepub fn set_dir_name(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_dir_name(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of dir_name to the given value.
#Panics
If the given value is out of bounds for dir_name.
Sourcepub fn set_dir_name_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_dir_name_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of dir_name to the given value.
#Errors
If the given value is out of bounds for dir_name.
Sourcepub fn attributes(&self) -> <bool as Specifier>::InOut
pub fn attributes(&self) -> <bool as Specifier>::InOut
Returns the value of attributes.
Sourcepub fn attributes_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn attributes_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of attributes.
#Errors
If the returned value contains an invalid bit pattern for attributes.
Sourcepub fn with_attributes(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_attributes(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of attributes set to the given value.
#Panics
If the given value is out of bounds for attributes.
Sourcepub fn with_attributes_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_attributes_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of attributes set to the given value.
#Errors
If the given value is out of bounds for attributes.
Sourcepub fn set_attributes(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_attributes(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of attributes to the given value.
#Panics
If the given value is out of bounds for attributes.
Sourcepub fn set_attributes_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_attributes_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of attributes to the given value.
#Errors
If the given value is out of bounds for attributes.
Sourcepub fn size_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn size_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of size.
#Errors
If the returned value contains an invalid bit pattern for size.
Sourcepub fn with_size(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_size(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of size set to the given value.
#Panics
If the given value is out of bounds for size.
Sourcepub fn with_size_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_size_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of size set to the given value.
#Errors
If the given value is out of bounds for size.
Sourcepub fn set_size(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_size(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of size to the given value.
#Panics
If the given value is out of bounds for size.
Sourcepub fn set_size_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_size_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of size to the given value.
#Errors
If the given value is out of bounds for size.
Sourcepub fn last_write(&self) -> <bool as Specifier>::InOut
pub fn last_write(&self) -> <bool as Specifier>::InOut
Returns the value of last_write.
Sourcepub fn last_write_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn last_write_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of last_write.
#Errors
If the returned value contains an invalid bit pattern for last_write.
Sourcepub fn with_last_write(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_last_write(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of last_write set to the given value.
#Panics
If the given value is out of bounds for last_write.
Sourcepub fn with_last_write_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_last_write_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of last_write set to the given value.
#Errors
If the given value is out of bounds for last_write.
Sourcepub fn set_last_write(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_last_write(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of last_write to the given value.
#Panics
If the given value is out of bounds for last_write.
Sourcepub fn set_last_write_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_last_write_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of last_write to the given value.
#Errors
If the given value is out of bounds for last_write.
Sourcepub fn last_access(&self) -> <bool as Specifier>::InOut
pub fn last_access(&self) -> <bool as Specifier>::InOut
Returns the value of last_access.
Sourcepub fn last_access_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn last_access_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of last_access.
#Errors
If the returned value contains an invalid bit pattern for last_access.
Sourcepub fn with_last_access(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_last_access(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of last_access set to the given value.
#Panics
If the given value is out of bounds for last_access.
Sourcepub fn with_last_access_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_last_access_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of last_access set to the given value.
#Errors
If the given value is out of bounds for last_access.
Sourcepub fn set_last_access(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_last_access(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of last_access to the given value.
#Panics
If the given value is out of bounds for last_access.
Sourcepub fn set_last_access_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_last_access_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of last_access to the given value.
#Errors
If the given value is out of bounds for last_access.
Sourcepub fn creation_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn creation_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of creation.
#Errors
If the returned value contains an invalid bit pattern for creation.
Sourcepub fn with_creation(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_creation(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of creation set to the given value.
#Panics
If the given value is out of bounds for creation.
Sourcepub fn with_creation_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_creation_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of creation set to the given value.
#Errors
If the given value is out of bounds for creation.
Sourcepub fn set_creation(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_creation(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of creation to the given value.
#Panics
If the given value is out of bounds for creation.
Sourcepub fn set_creation_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_creation_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of creation to the given value.
#Errors
If the given value is out of bounds for creation.
Sourcepub fn ea_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn ea_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of ea.
#Errors
If the returned value contains an invalid bit pattern for ea.
Sourcepub fn with_ea(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_ea(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of ea set to the given value.
#Panics
If the given value is out of bounds for ea.
Sourcepub fn with_ea_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_ea_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of ea set to the given value.
#Errors
If the given value is out of bounds for ea.
Sourcepub fn set_ea(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_ea(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of ea to the given value.
#Panics
If the given value is out of bounds for ea.
Sourcepub fn set_ea_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_ea_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of ea to the given value.
#Errors
If the given value is out of bounds for ea.
Sourcepub fn security_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn security_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of security.
#Errors
If the returned value contains an invalid bit pattern for security.
Sourcepub fn with_security(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_security(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of security set to the given value.
#Panics
If the given value is out of bounds for security.
Sourcepub fn with_security_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_security_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of security set to the given value.
#Errors
If the given value is out of bounds for security.
Sourcepub fn set_security(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_security(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of security to the given value.
#Panics
If the given value is out of bounds for security.
Sourcepub fn set_security_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_security_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of security to the given value.
#Errors
If the given value is out of bounds for security.
Sourcepub fn stream_name(&self) -> <bool as Specifier>::InOut
pub fn stream_name(&self) -> <bool as Specifier>::InOut
Returns the value of stream_name.
Sourcepub fn stream_name_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn stream_name_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of stream_name.
#Errors
If the returned value contains an invalid bit pattern for stream_name.
Sourcepub fn with_stream_name(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_stream_name(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of stream_name set to the given value.
#Panics
If the given value is out of bounds for stream_name.
Sourcepub fn with_stream_name_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_stream_name_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of stream_name set to the given value.
#Errors
If the given value is out of bounds for stream_name.
Sourcepub fn set_stream_name(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_stream_name(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of stream_name to the given value.
#Panics
If the given value is out of bounds for stream_name.
Sourcepub fn set_stream_name_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_stream_name_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of stream_name to the given value.
#Errors
If the given value is out of bounds for stream_name.
Sourcepub fn stream_size(&self) -> <bool as Specifier>::InOut
pub fn stream_size(&self) -> <bool as Specifier>::InOut
Returns the value of stream_size.
Sourcepub fn stream_size_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn stream_size_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of stream_size.
#Errors
If the returned value contains an invalid bit pattern for stream_size.
Sourcepub fn with_stream_size(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_stream_size(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of stream_size set to the given value.
#Panics
If the given value is out of bounds for stream_size.
Sourcepub fn with_stream_size_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_stream_size_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of stream_size set to the given value.
#Errors
If the given value is out of bounds for stream_size.
Sourcepub fn set_stream_size(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_stream_size(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of stream_size to the given value.
#Panics
If the given value is out of bounds for stream_size.
Sourcepub fn set_stream_size_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_stream_size_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of stream_size to the given value.
#Errors
If the given value is out of bounds for stream_size.
Sourcepub fn stream_write(&self) -> <bool as Specifier>::InOut
pub fn stream_write(&self) -> <bool as Specifier>::InOut
Returns the value of stream_write.
Sourcepub fn stream_write_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn stream_write_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of stream_write.
#Errors
If the returned value contains an invalid bit pattern for stream_write.
Sourcepub fn with_stream_write(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_stream_write(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of stream_write set to the given value.
#Panics
If the given value is out of bounds for stream_write.
Sourcepub fn with_stream_write_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_stream_write_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of stream_write set to the given value.
#Errors
If the given value is out of bounds for stream_write.
Sourcepub fn set_stream_write(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_stream_write(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of stream_write to the given value.
#Panics
If the given value is out of bounds for stream_write.
Sourcepub fn set_stream_write_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_stream_write_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of stream_write to the given value.
#Errors
If the given value is out of bounds for stream_write.