pub struct NotifyFlags { /* private fields */ }Implementations
Sourceimpl NotifyFlags
impl NotifyFlags
Sourceimpl NotifyFlags
impl NotifyFlags
Sourcepub const fn into_bytes(self) -> [u8; 2]
pub const fn into_bytes(self) -> [u8; 2]
Sourcepub const fn from_bytes(bytes: [u8; 2]) -> Self
pub const fn from_bytes(bytes: [u8; 2]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl NotifyFlags
impl NotifyFlags
Sourcepub fn watch_tree(&self) -> <bool as Specifier>::InOut
pub fn watch_tree(&self) -> <bool as Specifier>::InOut
Returns the value of watch_tree.
Sourcepub fn watch_tree_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn watch_tree_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of watch_tree.
#Errors
If the returned value contains an invalid bit pattern for watch_tree.
Sourcepub fn with_watch_tree(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_watch_tree(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of watch_tree set to the given value.
#Panics
If the given value is out of bounds for watch_tree.
Sourcepub fn with_watch_tree_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_watch_tree_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of watch_tree set to the given value.
#Errors
If the given value is out of bounds for watch_tree.
Sourcepub fn set_watch_tree(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_watch_tree(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of watch_tree to the given value.
#Panics
If the given value is out of bounds for watch_tree.
Sourcepub fn set_watch_tree_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_watch_tree_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of watch_tree to the given value.
#Errors
If the given value is out of bounds for watch_tree.