RequestContent

Enum RequestContent 

pub enum RequestContent {
Show 20 variants Negotiate(NegotiateRequest), SessionSetup(SessionSetupRequest), Logoff(LogoffRequest), TreeConnect(TreeConnectRequest), TreeDisconnect(TreeDisconnectRequest), Create(CreateRequest), Close(CloseRequest), Flush(FlushRequest), Read(ReadRequest), Write(WriteRequest), Lock(LockRequest), Ioctl(IoctlRequest), Echo(EchoRequest), QueryDirectory(QueryDirectoryRequest), ChangeNotify(ChangeNotifyRequest), QueryInfo(QueryInfoRequest), SetInfo(SetInfoRequest), Cancel(CancelRequest), OplockBreakAck(OplockBreakAck), LeaseBreakAck(LeaseBreakAck),
}
Contains all the variants for a plain SMB2 request message.

For example - read/write/create/close requests, etc.

Variants

Implementations

Source

impl RequestContent

pub fn associated_cmd(&self) -> Command

Get the command associated with this content.

Source

impl RequestContent

pub fn content_name(&self) -> &'static str

Returns the name of the content value.

pub fn to_negotiate(self) -> Result<NegotiateRequest, SmbMsgError>

Attempts to cast the current content type to [negotiate :: NegotiateRequest].

pub fn as_negotiate(&self) -> Result<&NegotiateRequest, SmbMsgError>

Attempts to cast the current content type to [negotiate :: NegotiateRequest].

pub fn as_mut_negotiate(&mut self) -> Result<&mut NegotiateRequest, SmbMsgError>

Attempts to cast the current content type to [negotiate :: NegotiateRequest].

pub fn to_sessionsetup(self) -> Result<SessionSetupRequest, SmbMsgError>

Attempts to cast the current content type to [session_setup :: SessionSetupRequest].

pub fn as_sessionsetup(&self) -> Result<&SessionSetupRequest, SmbMsgError>

Attempts to cast the current content type to [session_setup :: SessionSetupRequest].

pub fn as_mut_sessionsetup( &mut self, ) -> Result<&mut SessionSetupRequest, SmbMsgError>

Attempts to cast the current content type to [session_setup :: SessionSetupRequest].

pub fn to_logoff(self) -> Result<LogoffRequest, SmbMsgError>

Attempts to cast the current content type to [session_setup :: LogoffRequest].

pub fn as_logoff(&self) -> Result<&LogoffRequest, SmbMsgError>

Attempts to cast the current content type to [session_setup :: LogoffRequest].

pub fn as_mut_logoff(&mut self) -> Result<&mut LogoffRequest, SmbMsgError>

Attempts to cast the current content type to [session_setup :: LogoffRequest].

pub fn to_treeconnect(self) -> Result<TreeConnectRequest, SmbMsgError>

Attempts to cast the current content type to [tree_connect :: TreeConnectRequest].

pub fn as_treeconnect(&self) -> Result<&TreeConnectRequest, SmbMsgError>

Attempts to cast the current content type to [tree_connect :: TreeConnectRequest].

pub fn as_mut_treeconnect( &mut self, ) -> Result<&mut TreeConnectRequest, SmbMsgError>

Attempts to cast the current content type to [tree_connect :: TreeConnectRequest].

pub fn to_treedisconnect(self) -> Result<TreeDisconnectRequest, SmbMsgError>

Attempts to cast the current content type to [tree_connect :: TreeDisconnectRequest].

pub fn as_treedisconnect(&self) -> Result<&TreeDisconnectRequest, SmbMsgError>

Attempts to cast the current content type to [tree_connect :: TreeDisconnectRequest].

pub fn as_mut_treedisconnect( &mut self, ) -> Result<&mut TreeDisconnectRequest, SmbMsgError>

Attempts to cast the current content type to [tree_connect :: TreeDisconnectRequest].

pub fn to_create(self) -> Result<CreateRequest, SmbMsgError>

Attempts to cast the current content type to [create :: CreateRequest].

pub fn as_create(&self) -> Result<&CreateRequest, SmbMsgError>

Attempts to cast the current content type to [create :: CreateRequest].

pub fn as_mut_create(&mut self) -> Result<&mut CreateRequest, SmbMsgError>

Attempts to cast the current content type to [create :: CreateRequest].

pub fn to_close(self) -> Result<CloseRequest, SmbMsgError>

Attempts to cast the current content type to [create :: CloseRequest].

pub fn as_close(&self) -> Result<&CloseRequest, SmbMsgError>

Attempts to cast the current content type to [create :: CloseRequest].

pub fn as_mut_close(&mut self) -> Result<&mut CloseRequest, SmbMsgError>

Attempts to cast the current content type to [create :: CloseRequest].

pub fn to_flush(self) -> Result<FlushRequest, SmbMsgError>

Attempts to cast the current content type to [file :: FlushRequest].

pub fn as_flush(&self) -> Result<&FlushRequest, SmbMsgError>

Attempts to cast the current content type to [file :: FlushRequest].

pub fn as_mut_flush(&mut self) -> Result<&mut FlushRequest, SmbMsgError>

Attempts to cast the current content type to [file :: FlushRequest].

pub fn to_read(self) -> Result<ReadRequest, SmbMsgError>

Attempts to cast the current content type to [file :: ReadRequest].

pub fn as_read(&self) -> Result<&ReadRequest, SmbMsgError>

Attempts to cast the current content type to [file :: ReadRequest].

pub fn as_mut_read(&mut self) -> Result<&mut ReadRequest, SmbMsgError>

Attempts to cast the current content type to [file :: ReadRequest].

pub fn to_write(self) -> Result<WriteRequest, SmbMsgError>

Attempts to cast the current content type to [file :: WriteRequest].

pub fn as_write(&self) -> Result<&WriteRequest, SmbMsgError>

Attempts to cast the current content type to [file :: WriteRequest].

pub fn as_mut_write(&mut self) -> Result<&mut WriteRequest, SmbMsgError>

Attempts to cast the current content type to [file :: WriteRequest].

pub fn to_lock(self) -> Result<LockRequest, SmbMsgError>

Attempts to cast the current content type to [lock :: LockRequest].

pub fn as_lock(&self) -> Result<&LockRequest, SmbMsgError>

Attempts to cast the current content type to [lock :: LockRequest].

pub fn as_mut_lock(&mut self) -> Result<&mut LockRequest, SmbMsgError>

Attempts to cast the current content type to [lock :: LockRequest].

pub fn to_ioctl(self) -> Result<IoctlRequest, SmbMsgError>

Attempts to cast the current content type to [ioctl :: IoctlRequest].

pub fn as_ioctl(&self) -> Result<&IoctlRequest, SmbMsgError>

Attempts to cast the current content type to [ioctl :: IoctlRequest].

pub fn as_mut_ioctl(&mut self) -> Result<&mut IoctlRequest, SmbMsgError>

Attempts to cast the current content type to [ioctl :: IoctlRequest].

pub fn to_echo(self) -> Result<EchoRequest, SmbMsgError>

Attempts to cast the current content type to [echo :: EchoRequest].

pub fn as_echo(&self) -> Result<&EchoRequest, SmbMsgError>

Attempts to cast the current content type to [echo :: EchoRequest].

pub fn as_mut_echo(&mut self) -> Result<&mut EchoRequest, SmbMsgError>

Attempts to cast the current content type to [echo :: EchoRequest].

pub fn to_querydirectory(self) -> Result<QueryDirectoryRequest, SmbMsgError>

Attempts to cast the current content type to [query_dir :: QueryDirectoryRequest].

pub fn as_querydirectory(&self) -> Result<&QueryDirectoryRequest, SmbMsgError>

Attempts to cast the current content type to [query_dir :: QueryDirectoryRequest].

pub fn as_mut_querydirectory( &mut self, ) -> Result<&mut QueryDirectoryRequest, SmbMsgError>

Attempts to cast the current content type to [query_dir :: QueryDirectoryRequest].

pub fn to_changenotify(self) -> Result<ChangeNotifyRequest, SmbMsgError>

Attempts to cast the current content type to [notify :: ChangeNotifyRequest].

pub fn as_changenotify(&self) -> Result<&ChangeNotifyRequest, SmbMsgError>

Attempts to cast the current content type to [notify :: ChangeNotifyRequest].

pub fn as_mut_changenotify( &mut self, ) -> Result<&mut ChangeNotifyRequest, SmbMsgError>

Attempts to cast the current content type to [notify :: ChangeNotifyRequest].

pub fn to_queryinfo(self) -> Result<QueryInfoRequest, SmbMsgError>

Attempts to cast the current content type to [info :: QueryInfoRequest].

pub fn as_queryinfo(&self) -> Result<&QueryInfoRequest, SmbMsgError>

Attempts to cast the current content type to [info :: QueryInfoRequest].

pub fn as_mut_queryinfo(&mut self) -> Result<&mut QueryInfoRequest, SmbMsgError>

Attempts to cast the current content type to [info :: QueryInfoRequest].

pub fn to_setinfo(self) -> Result<SetInfoRequest, SmbMsgError>

Attempts to cast the current content type to [info :: SetInfoRequest].

pub fn as_setinfo(&self) -> Result<&SetInfoRequest, SmbMsgError>

Attempts to cast the current content type to [info :: SetInfoRequest].

pub fn as_mut_setinfo(&mut self) -> Result<&mut SetInfoRequest, SmbMsgError>

Attempts to cast the current content type to [info :: SetInfoRequest].

pub fn to_cancel(self) -> Result<CancelRequest, SmbMsgError>

Attempts to cast the current content type to [cancel :: CancelRequest].

pub fn as_cancel(&self) -> Result<&CancelRequest, SmbMsgError>

Attempts to cast the current content type to [cancel :: CancelRequest].

pub fn as_mut_cancel(&mut self) -> Result<&mut CancelRequest, SmbMsgError>

Attempts to cast the current content type to [cancel :: CancelRequest].

pub fn to_oplockbreakack(self) -> Result<OplockBreakAck, SmbMsgError>

Attempts to cast the current content type to [oplock :: OplockBreakAck].

pub fn as_oplockbreakack(&self) -> Result<&OplockBreakAck, SmbMsgError>

Attempts to cast the current content type to [oplock :: OplockBreakAck].

pub fn as_mut_oplockbreakack( &mut self, ) -> Result<&mut OplockBreakAck, SmbMsgError>

Attempts to cast the current content type to [oplock :: OplockBreakAck].

pub fn to_leasebreakack(self) -> Result<LeaseBreakAck, SmbMsgError>

Attempts to cast the current content type to [oplock :: LeaseBreakAck].

pub fn as_leasebreakack(&self) -> Result<&LeaseBreakAck, SmbMsgError>

Attempts to cast the current content type to [oplock :: LeaseBreakAck].

pub fn as_mut_leasebreakack( &mut self, ) -> Result<&mut LeaseBreakAck, SmbMsgError>

Attempts to cast the current content type to [oplock :: LeaseBreakAck].

Source

impl RequestContent

pub fn req_payload_size(&self) -> u32

If this is a request has a payload, it returns the size of it. Otherwise, it returns 0.

This method shall be used for calculating credits request & charge.

pub fn expected_resp_size(&self) -> u32

If this is a request that expects a response with size, it returns that expected size.

This method shall be used for calculating credits request & charge.