ResponseContent

Enum ResponseContent 

pub enum ResponseContent {
Show 23 variants Negotiate(NegotiateResponse), SessionSetup(SessionSetupResponse), Logoff(LogoffResponse), TreeConnect(TreeConnectResponse), TreeDisconnect(TreeDisconnectResponse), Create(CreateResponse), Close(CloseResponse), Flush(FlushResponse), Read(ReadResponse), Write(WriteResponse), Lock(LockResponse), Ioctl(IoctlResponse), Echo(EchoResponse), QueryDirectory(QueryDirectoryResponse), ChangeNotify(ChangeNotifyResponse), QueryInfo(QueryInfoResponse), SetInfo(SetInfoResponse), OplockBreakNotify(OplockBreakNotify), LeaseBreakNotify(LeaseBreakNotify), OplockBreak(OplockBreakResponse), LeaseBreak(LeaseBreakResponse), ServerToClientNotification(ServerToClientNotification), Error(ErrorResponse),
}

Variants

Implementations

Source

impl ResponseContent

pub fn associated_cmd(&self) -> Command

Get the command associated with this content.

Source

impl ResponseContent

pub fn content_name(&self) -> &'static str

Returns the name of the content value.

pub fn to_negotiate(self) -> Result<NegotiateResponse, SmbMsgError>

Attempts to cast the current content type to [negotiate :: NegotiateResponse].

pub fn as_negotiate(&self) -> Result<&NegotiateResponse, SmbMsgError>

Attempts to cast the current content type to [negotiate :: NegotiateResponse].

pub fn as_mut_negotiate( &mut self, ) -> Result<&mut NegotiateResponse, SmbMsgError>

Attempts to cast the current content type to [negotiate :: NegotiateResponse].

pub fn to_sessionsetup(self) -> Result<SessionSetupResponse, SmbMsgError>

Attempts to cast the current content type to [session_setup :: SessionSetupResponse].

pub fn as_sessionsetup(&self) -> Result<&SessionSetupResponse, SmbMsgError>

Attempts to cast the current content type to [session_setup :: SessionSetupResponse].

pub fn as_mut_sessionsetup( &mut self, ) -> Result<&mut SessionSetupResponse, SmbMsgError>

Attempts to cast the current content type to [session_setup :: SessionSetupResponse].

pub fn to_logoff(self) -> Result<LogoffResponse, SmbMsgError>

Attempts to cast the current content type to [session_setup :: LogoffResponse].

pub fn as_logoff(&self) -> Result<&LogoffResponse, SmbMsgError>

Attempts to cast the current content type to [session_setup :: LogoffResponse].

pub fn as_mut_logoff(&mut self) -> Result<&mut LogoffResponse, SmbMsgError>

Attempts to cast the current content type to [session_setup :: LogoffResponse].

pub fn to_treeconnect(self) -> Result<TreeConnectResponse, SmbMsgError>

Attempts to cast the current content type to [tree_connect :: TreeConnectResponse].

pub fn as_treeconnect(&self) -> Result<&TreeConnectResponse, SmbMsgError>

Attempts to cast the current content type to [tree_connect :: TreeConnectResponse].

pub fn as_mut_treeconnect( &mut self, ) -> Result<&mut TreeConnectResponse, SmbMsgError>

Attempts to cast the current content type to [tree_connect :: TreeConnectResponse].

pub fn to_treedisconnect(self) -> Result<TreeDisconnectResponse, SmbMsgError>

Attempts to cast the current content type to [tree_connect :: TreeDisconnectResponse].

pub fn as_treedisconnect(&self) -> Result<&TreeDisconnectResponse, SmbMsgError>

Attempts to cast the current content type to [tree_connect :: TreeDisconnectResponse].

pub fn as_mut_treedisconnect( &mut self, ) -> Result<&mut TreeDisconnectResponse, SmbMsgError>

Attempts to cast the current content type to [tree_connect :: TreeDisconnectResponse].

pub fn to_create(self) -> Result<CreateResponse, SmbMsgError>

Attempts to cast the current content type to [create :: CreateResponse].

pub fn as_create(&self) -> Result<&CreateResponse, SmbMsgError>

Attempts to cast the current content type to [create :: CreateResponse].

pub fn as_mut_create(&mut self) -> Result<&mut CreateResponse, SmbMsgError>

Attempts to cast the current content type to [create :: CreateResponse].

pub fn to_close(self) -> Result<CloseResponse, SmbMsgError>

Attempts to cast the current content type to [create :: CloseResponse].

pub fn as_close(&self) -> Result<&CloseResponse, SmbMsgError>

Attempts to cast the current content type to [create :: CloseResponse].

pub fn as_mut_close(&mut self) -> Result<&mut CloseResponse, SmbMsgError>

Attempts to cast the current content type to [create :: CloseResponse].

pub fn to_flush(self) -> Result<FlushResponse, SmbMsgError>

Attempts to cast the current content type to [file :: FlushResponse].

pub fn as_flush(&self) -> Result<&FlushResponse, SmbMsgError>

Attempts to cast the current content type to [file :: FlushResponse].

pub fn as_mut_flush(&mut self) -> Result<&mut FlushResponse, SmbMsgError>

Attempts to cast the current content type to [file :: FlushResponse].

pub fn to_read(self) -> Result<ReadResponse, SmbMsgError>

Attempts to cast the current content type to [file :: ReadResponse].

pub fn as_read(&self) -> Result<&ReadResponse, SmbMsgError>

Attempts to cast the current content type to [file :: ReadResponse].

pub fn as_mut_read(&mut self) -> Result<&mut ReadResponse, SmbMsgError>

Attempts to cast the current content type to [file :: ReadResponse].

pub fn to_write(self) -> Result<WriteResponse, SmbMsgError>

Attempts to cast the current content type to [file :: WriteResponse].

pub fn as_write(&self) -> Result<&WriteResponse, SmbMsgError>

Attempts to cast the current content type to [file :: WriteResponse].

pub fn as_mut_write(&mut self) -> Result<&mut WriteResponse, SmbMsgError>

Attempts to cast the current content type to [file :: WriteResponse].

pub fn to_lock(self) -> Result<LockResponse, SmbMsgError>

Attempts to cast the current content type to [lock :: LockResponse].

pub fn as_lock(&self) -> Result<&LockResponse, SmbMsgError>

Attempts to cast the current content type to [lock :: LockResponse].

pub fn as_mut_lock(&mut self) -> Result<&mut LockResponse, SmbMsgError>

Attempts to cast the current content type to [lock :: LockResponse].

pub fn to_ioctl(self) -> Result<IoctlResponse, SmbMsgError>

Attempts to cast the current content type to [ioctl :: IoctlResponse].

pub fn as_ioctl(&self) -> Result<&IoctlResponse, SmbMsgError>

Attempts to cast the current content type to [ioctl :: IoctlResponse].

pub fn as_mut_ioctl(&mut self) -> Result<&mut IoctlResponse, SmbMsgError>

Attempts to cast the current content type to [ioctl :: IoctlResponse].

pub fn to_echo(self) -> Result<EchoResponse, SmbMsgError>

Attempts to cast the current content type to [echo :: EchoResponse].

pub fn as_echo(&self) -> Result<&EchoResponse, SmbMsgError>

Attempts to cast the current content type to [echo :: EchoResponse].

pub fn as_mut_echo(&mut self) -> Result<&mut EchoResponse, SmbMsgError>

Attempts to cast the current content type to [echo :: EchoResponse].

pub fn to_querydirectory(self) -> Result<QueryDirectoryResponse, SmbMsgError>

Attempts to cast the current content type to [query_dir :: QueryDirectoryResponse].

pub fn as_querydirectory(&self) -> Result<&QueryDirectoryResponse, SmbMsgError>

Attempts to cast the current content type to [query_dir :: QueryDirectoryResponse].

pub fn as_mut_querydirectory( &mut self, ) -> Result<&mut QueryDirectoryResponse, SmbMsgError>

Attempts to cast the current content type to [query_dir :: QueryDirectoryResponse].

pub fn to_changenotify(self) -> Result<ChangeNotifyResponse, SmbMsgError>

Attempts to cast the current content type to [notify :: ChangeNotifyResponse].

pub fn as_changenotify(&self) -> Result<&ChangeNotifyResponse, SmbMsgError>

Attempts to cast the current content type to [notify :: ChangeNotifyResponse].

pub fn as_mut_changenotify( &mut self, ) -> Result<&mut ChangeNotifyResponse, SmbMsgError>

Attempts to cast the current content type to [notify :: ChangeNotifyResponse].

pub fn to_queryinfo(self) -> Result<QueryInfoResponse, SmbMsgError>

Attempts to cast the current content type to [info :: QueryInfoResponse].

pub fn as_queryinfo(&self) -> Result<&QueryInfoResponse, SmbMsgError>

Attempts to cast the current content type to [info :: QueryInfoResponse].

pub fn as_mut_queryinfo( &mut self, ) -> Result<&mut QueryInfoResponse, SmbMsgError>

Attempts to cast the current content type to [info :: QueryInfoResponse].

pub fn to_setinfo(self) -> Result<SetInfoResponse, SmbMsgError>

Attempts to cast the current content type to [info :: SetInfoResponse].

pub fn as_setinfo(&self) -> Result<&SetInfoResponse, SmbMsgError>

Attempts to cast the current content type to [info :: SetInfoResponse].

pub fn as_mut_setinfo(&mut self) -> Result<&mut SetInfoResponse, SmbMsgError>

Attempts to cast the current content type to [info :: SetInfoResponse].

pub fn to_oplockbreaknotify(self) -> Result<OplockBreakNotify, SmbMsgError>

Attempts to cast the current content type to [oplock :: OplockBreakNotify].

pub fn as_oplockbreaknotify(&self) -> Result<&OplockBreakNotify, SmbMsgError>

Attempts to cast the current content type to [oplock :: OplockBreakNotify].

pub fn as_mut_oplockbreaknotify( &mut self, ) -> Result<&mut OplockBreakNotify, SmbMsgError>

Attempts to cast the current content type to [oplock :: OplockBreakNotify].

pub fn to_leasebreaknotify(self) -> Result<LeaseBreakNotify, SmbMsgError>

Attempts to cast the current content type to [oplock :: LeaseBreakNotify].

pub fn as_leasebreaknotify(&self) -> Result<&LeaseBreakNotify, SmbMsgError>

Attempts to cast the current content type to [oplock :: LeaseBreakNotify].

pub fn as_mut_leasebreaknotify( &mut self, ) -> Result<&mut LeaseBreakNotify, SmbMsgError>

Attempts to cast the current content type to [oplock :: LeaseBreakNotify].

pub fn to_oplockbreak(self) -> Result<OplockBreakResponse, SmbMsgError>

Attempts to cast the current content type to [oplock :: OplockBreakResponse].

pub fn as_oplockbreak(&self) -> Result<&OplockBreakResponse, SmbMsgError>

Attempts to cast the current content type to [oplock :: OplockBreakResponse].

pub fn as_mut_oplockbreak( &mut self, ) -> Result<&mut OplockBreakResponse, SmbMsgError>

Attempts to cast the current content type to [oplock :: OplockBreakResponse].

pub fn to_leasebreak(self) -> Result<LeaseBreakResponse, SmbMsgError>

Attempts to cast the current content type to [oplock :: LeaseBreakResponse].

pub fn as_leasebreak(&self) -> Result<&LeaseBreakResponse, SmbMsgError>

Attempts to cast the current content type to [oplock :: LeaseBreakResponse].

pub fn as_mut_leasebreak( &mut self, ) -> Result<&mut LeaseBreakResponse, SmbMsgError>

Attempts to cast the current content type to [oplock :: LeaseBreakResponse].

pub fn to_servertoclientnotification( self, ) -> Result<ServerToClientNotification, SmbMsgError>

Attempts to cast the current content type to [notify :: ServerToClientNotification].

pub fn as_servertoclientnotification( &self, ) -> Result<&ServerToClientNotification, SmbMsgError>

Attempts to cast the current content type to [notify :: ServerToClientNotification].

pub fn as_mut_servertoclientnotification( &mut self, ) -> Result<&mut ServerToClientNotification, SmbMsgError>

Attempts to cast the current content type to [notify :: ServerToClientNotification].

pub fn to_error(self) -> Result<ErrorResponse, SmbMsgError>

Attempts to cast the current content type to [error :: ErrorResponse].

pub fn as_error(&self) -> Result<&ErrorResponse, SmbMsgError>

Attempts to cast the current content type to [error :: ErrorResponse].

pub fn as_mut_error(&mut self) -> Result<&mut ErrorResponse, SmbMsgError>

Attempts to cast the current content type to [error :: ErrorResponse].