pub struct QueryDirectoryRequest {
pub file_information_class: QueryDirectoryInfoClass,
pub flags: QueryDirectoryFlags,
pub file_index: u32,
pub file_id: FileId,
pub output_buffer_length: u32,
pub file_name: SizedWideString,
}Expand description
SMB2 QUERY_DIRECTORY Request packet for obtaining directory enumeration.
This request is sent by the client to obtain a directory enumeration on a directory open. The client specifies the type of information desired and can optionally provide a search pattern to filter the results.
Reference: MS-SMB2 section 2.2.33, page 10906442-294c-46d3-8515-c277efe1f752
Fields
file_information_class: QueryDirectoryInfoClassThe file information class describing the format that data must be returned in. Specifies which type of directory information structure should be used for each entry.
flags: QueryDirectoryFlagsFlags indicating how the query directory operation must be processed. Controls behavior such as restarting enumeration or returning single entries.
file_index: u32The byte offset within the directory to resume enumeration from. Must be supplied when INDEX_SPECIFIED flag is set, otherwise must be zero.
file_id: FileIdIdentifier of the directory on which to perform the enumeration. This is returned from an SMB2 Create Request to open a directory.
output_buffer_length: u32The maximum number of bytes the server is allowed to return in the response.
file_name: SizedWideStringUnicode search pattern for the request with wildcards and other conventions. Format is specified in MS-CIFS section 2.2.1.1.3.