pub struct QueryDirectoryResponse {
pub output_buffer: Vec<u8>,
}Expand description
SMB2 QUERY_DIRECTORY Response packet containing directory enumeration results.
This response is sent by a server in response to an SMB2 QUERY_DIRECTORY Request. It contains the directory enumeration data in the format specified by the FileInformationClass in the request.
Reference: MS-SMB2 section 2.2.34
Fields
output_buffer: Vec<u8>Directory enumeration data in the format specified by the FileInformationClass. Format is as specified in MS-FSCC section 2.4 for the specific file information class.
Implementations
Sourceimpl QueryDirectoryResponse
impl QueryDirectoryResponse
Sourcepub fn read_output<T>(&self) -> BinResult<Vec<T>>
pub fn read_output<T>(&self) -> BinResult<Vec<T>>
Reads and parses the output buffer as a vector of directory information entries.
See viable types for conversions in the smb-dtyp crate - QueryDirectoryInfoValue implementations.
This method parses the raw output buffer into strongly-typed directory information structures based on the type parameter T, which should match the FileInformationClass used in the original request.