pub struct SetupRequestFlags { /* private fields */ }Implementations
Sourceimpl SetupRequestFlags
impl SetupRequestFlags
Sourcepub const fn into_bytes(self) -> [u8; 1]
pub const fn into_bytes(self) -> [u8; 1]
Sourcepub const fn from_bytes(bytes: [u8; 1]) -> Self
pub const fn from_bytes(bytes: [u8; 1]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl SetupRequestFlags
impl SetupRequestFlags
Sourcepub fn binding_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn binding_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of binding.
#Errors
If the returned value contains an invalid bit pattern for binding.
Sourcepub fn with_binding(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_binding(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of binding set to the given value.
#Panics
If the given value is out of bounds for binding.
Sourcepub fn with_binding_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_binding_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of binding set to the given value.
#Errors
If the given value is out of bounds for binding.
Sourcepub fn set_binding(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_binding(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of binding to the given value.
#Panics
If the given value is out of bounds for binding.
Sourcepub fn set_binding_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_binding_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of binding to the given value.
#Errors
If the given value is out of bounds for binding.